@@ -37,7 +37,7 @@
 
 /* Assert there are as many real arguments as there are values
    (argument list ends with a NULL guard).  There is no execution
-   cost, since it will be statically evaluated to `assert (0)' or
+   cost, since it will be statically evalauted to `assert (0)' or
    `assert (1)'.  Unfortunately there is no -Wassert-0. */
 
 # undef ARRAY_CARDINALITY
