@@ -18,16 +18,8 @@
 
 /* Author: Akim Demaille <demaille@inf.enst.fr> */
 
-#ifndef _DARRAY_H_
-#define _DARRAY_H_
-
-#ifdef HAVE_CONFIG_H
-# include <config.h>
-#endif
-
-#include <stdio.h>
-
-#include "xsystypes.h"
+#ifndef DARRAY_H_
+# define DARRAY_H_
 
 /* Support of prototyping when possible */
 #ifndef PARAMS
@@ -38,7 +30,8 @@
 #  endif /* no PROTOTYPES */
 #endif
 
-enum da_growth {
+enum da_growth
+{
   da_steady,			/* i.e. you're responsible	*/
   da_linear,			/* i.e. 1 2 3 4...		*/
   da_geometrical		/* i.e. 1 2 4 8...		*/
@@ -48,11 +41,12 @@ typedef void (*da_map_func_t) PARAMS ((void *));
 typedef void (*da_maparg_func_t) PARAMS ((void *, void *));
 typedef void (*da_print_func_t) PARAMS ((const void *, FILE * stream));
 typedef int (*da_cmp_func_t) PARAMS ((const void * k1, const void * k2));
-typedef int (*da_cmp_arg_func_t) PARAMS ((const void * k1, 
+typedef int (*da_cmp_arg_func_t) PARAMS ((const void * k1,
 					  const void * k2,
 					  const void * arg));
 
-struct darray {
+struct darray
+{
   const char * name;
   size_t size;
   size_t original_size;		/* The size with which it has been created */
@@ -71,8 +65,8 @@ extern int da_exit_error;		/* exit value when encounters	*
  * Maintaining
  */
 struct darray *
-da_new PARAMS ((const char * name, size_t size, 
-		enum da_growth growth, size_t increment, 
+da_new PARAMS ((const char * name, size_t size,
+		enum da_growth growth, size_t increment,
 		da_print_func_t self_print,
 		da_cmp_func_t cmp));
 void da_free_content PARAMS ((struct darray * arr, da_map_func_t free_func));
@@ -107,7 +101,7 @@ int da_includes PARAMS ((struct darray * arr, const void * stuff));
  */
 void da_append PARAMS ((struct darray * arr, void * elem));
 void da_insert_at PARAMS ((struct darray * arr, void * elem, size_t where));
-void da_remove_at PARAMS ((struct darray * arr, 
+void da_remove_at PARAMS ((struct darray * arr,
 			   size_t where, da_map_func_t free_func));
 void da_concat PARAMS ((struct darray * arr, struct darray * arr2));
 void da_prefix PARAMS ((struct darray * arr, struct darray * arr2));
@@ -130,12 +124,12 @@ enum da_include_policy {
 /* Merge A2 in A1, according to the POLICY, and free not retained
  * items by FREE_FUNC if not NULL */
 void da_merge PARAMS ((struct darray * a1, struct darray * a2,
-		       da_map_func_t free_func, 
+		       da_map_func_t free_func,
 		       enum da_include_policy policy));
 
 
 void da_map PARAMS ((struct darray * arr, da_map_func_t func));
-void da_maparg PARAMS ((struct darray * arr, 
+void da_maparg PARAMS ((struct darray * arr,
 			da_maparg_func_t func, void * arg));
 
 /*
@@ -143,4 +137,6 @@ void da_maparg PARAMS ((struct darray * arr,
  */
 int da_str_cmp PARAMS ((const char * s1, const char * s2));
 void da_str_print PARAMS ((const char * s1, FILE * stream));
+void da_str_printnl PARAMS ((const char * s1, FILE * stream));
+
 #endif
