@@ -9,7 +9,7 @@
 
 /*
  * This file is part of a2ps.
- * 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
@@ -79,9 +79,9 @@ multivalued_entry_new (const char * type)
 static void
 multivalued_entry_free (struct multivalued_entry * entry)
 {
-  FREE (entry->key);
+  free (entry->key);
   string_htable_free (entry->entries);
-  FREE (entry);
+  free (entry);
 }
 
 /*
@@ -102,7 +102,7 @@ multivalued_entry_get (struct hash_table_s * table, const char * type)
  * Add a new multivalued_entry with TYPE, if necessary
  */
 static void
-multivalued_entry_add (struct hash_table_s * table, 
+multivalued_entry_add (struct hash_table_s * table,
 		       struct multivalued_entry * item)
 {
   struct multivalued_entry * old_item;
@@ -170,10 +170,10 @@ multivalued_table_new (void)
 {
   static struct hash_table_s * res;
 
-  res = ALLOC (hash_table, 1);
-  hash_init (res, 8, 
+  res = XMALLOC (hash_table, 1);
+  hash_init (res, 8,
 	     (hash_func_t) mv_key_hash_1,
-	     (hash_func_t) mv_key_hash_2, 
+	     (hash_func_t) mv_key_hash_2,
 	     (hash_cmp_func_t) mv_key_hash_cmp);
   return res;
 }
@@ -182,7 +182,7 @@ void
 multivalued_table_free (struct hash_table_s * table)
 {
   hash_free (table, (hash_map_func_t) multivalued_entry_free);
-  FREE (table);
+  free (table);
 }
 
 /************************************************************************
@@ -208,6 +208,7 @@ add_supplied_resource (a2ps_job * job, const char * key, const char * value)
   multivalued_entry_add_couple (job->status->supplied_resources, key, value);
 }
 
+#if 0
 /*
  * Returned the needed resource if it is known,
  * NULL otherwise
@@ -215,9 +216,10 @@ add_supplied_resource (a2ps_job * job, const char * key, const char * value)
 static const char *
 supplied_resource_get (a2ps_job * job, const char * key, const char * value)
 {
-  return multivalued_entry_get_sub_item (job->status->supplied_resources, 
+  return multivalued_entry_get_sub_item (job->status->supplied_resources,
 					 key, value);
 }
+#endif
 
 static void
 multivalued_entry_dump (FILE * stream, int first,
@@ -228,20 +230,20 @@ multivalued_entry_dump (FILE * stream, int first,
   int i;
 
   /* Get all the values in a malloc'd storage.
-   * We sort them because: 
+   * We sort them because:
    * 1. it looks better,
    * 2. fewer sources of differences in regression tests */
   values = (char **) string_htable_dump_sorted (entry->entries);
   for (i = 0 ; values[i] ; i++)
     if (first) {
       fprintf (stream, fmt_first, entry->key, values[i]);
-      first = FALSE;
+      first = false;
     } else {
       fprintf (stream, fmt_others, entry->key, values[i]);
     }
 
   /* Release mem */
-  FREE (values);
+  free (values);
 }
 
 /*
@@ -251,18 +253,18 @@ void
 dump_supplied_resources (FILE * stream, a2ps_job * job)
 {
   int i;
-  
+
   multivalued_entry ** list;
-  list = ((multivalued_entry **) 
+  list = ((multivalued_entry **)
 	  hash_dump (job->status->supplied_resources, NULL, NULL));
- 
+
   for (i = 0 ; list [i] ; i ++)
     /* i is used as a clue that it is the first */
     multivalued_entry_dump (stream, i == 0,
 			    "%%%%DocumentSuppliedResources: %s %s\n",
 			    "%%%%+ %s %s\n",
 			    list [i]);
-  FREE (list);
+  free (list);
 }
 
 /*
@@ -281,7 +283,7 @@ add_needed_resource (a2ps_job * job, const char * key, const char * value)
 static const char *
 needed_resource_get (a2ps_job * job, const char * key, const char * value)
 {
-  return multivalued_entry_get_sub_item (job->status->needed_resources, 
+  return multivalued_entry_get_sub_item (job->status->needed_resources,
 					 key, value);
 }
 
@@ -293,27 +295,27 @@ dump_needed_resources (FILE * stream, a2ps_job * job)
 {
   int i;
   int first = 1;
-  
+
   multivalued_entry ** list;
-  list = ((multivalued_entry **) 
+  list = ((multivalued_entry **)
 	  hash_dump (job->status->needed_resources, NULL, NULL));
- 
-  for (i = 0 ; list [i] ; i ++) 
+
+  for (i = 0 ; list [i] ; i ++)
     {
       /* Don't print the colors, because they have another section */
       if (strequ (list [i]-> key, "color")
 	  /* nor files, since they are yet included */
 	  || strequ (list [i]-> key, "file"))
 	continue;
-      
+
       multivalued_entry_dump (stream, first,
 			      "%%%%DocumentNeededResources: %s %s\n",
 			      "%%%%+ %s %s\n",
 			      list [i]);
-      first = FALSE;
+      first = false;
     }
-  
-  FREE (list);
+
+  free (list);
 }
 
 /*
@@ -341,14 +343,14 @@ dump_process_color (FILE * stream, a2ps_job * job)
     {
       int i;
       char ** colors = (char **) string_htable_dump_sorted (color_table);
-      
+
       if (*colors != NULL) {
 	fputs ("%%DocumentProcessColors: ", stream);
 	for (i = 0 ; colors [i] ; i++)
 	  fprintf (stream, "%s ", colors [i]);
 	putc ('\n', stream);
       }
-      FREE (colors);
+      free (colors);
     }
 }
 
@@ -387,7 +389,7 @@ char **
 required_fonts_get (a2ps_job * job)
 {
   struct string_htable * font_table;
-  font_table = 
+  font_table =
     multivalued_entry_get_sub_table (job->status->supplied_resources,
 				     "font");
 
@@ -404,7 +406,7 @@ required_fonts_get (a2ps_job * job)
  * Nevertheless, I still wait for somebody to tell me if this is
  * really needed (useful is sure, needed is not)
  */
-void 
+void
 dump_setup (FILE * stream, a2ps_job * job)
 {
   output_dump (job->status->setup, stream);
