@@ -18,32 +18,12 @@
 
 /* Author: Akim Demaille <demaille@inf.enst.fr> */
 
-#ifdef HAVE_CONFIG_H
-# include <config.h>
-#endif
-
+#include "system.h"
 #include "dstring.h"
-#include "xstring.h"
-#include "error.h"
-#include "xmalloc.h"
 #include "printlen.h"
 
-/* Include this last so that its definition of PARAMS is not the one
- * taken into account: there is a bug in OSF1 4.0 cc which makes it
- * necessary (!!!) to have the prototypes of this file (dstring.h) */
-#if ENABLE_NLS
-# include <libintl.h>
-# define _(Text) gettext (Text)
-#else
-# define _(Text) Text
-#endif
-
 #define DS_MARGIN	1024
 
-#ifndef EXIT_FAILURE
-# define EXIT_FAILURE 1
-#endif
-
 int ds_exit_error = EXIT_FAILURE;	/* exit value when encounters	*
 					 * an error 			*/
 
@@ -64,13 +44,13 @@ ds_new (size_t size,
     error (ds_exit_error, 0, "invalid increment for dynamic string: %d",
 	   increment);
 
-  res = ALLOC (struct dstring, 1);
+  res = XMALLOC (struct dstring, 1);
   res->len = 0;
   res->size = size;
   res->original_size = size;
   res->growth = growth;
   res->increment = increment;
-  res->content = MALLOC (size);
+  res->content = XMALLOC (char, size);
   res->content[0] = '\0';
 
   return res;
@@ -119,10 +99,11 @@ ds_print_stats (struct dstring * str, FILE * stream)
 void
 ds_resize (struct dstring *string, size_t size)
 {
-  if (string->len + 1 < size) {
-    string->size = size;
-    string->content = REMALLOC (string->content, size);
-  }
+  if (string->len + 1 < size)
+    {
+      string->size = size;
+      string->content = XREALLOC (string->content, char, size);
+    }
 }
 
 /*
@@ -143,7 +124,7 @@ ds_grow (struct dstring *string)
     string->size *= string->increment;
     break;
   }
-  string->content = REMALLOC (string->content, string->size);
+  string->content = XREALLOC (string->content, char, string->size);
 }
 
 /****************************************************************/
