@@ -181,7 +181,7 @@ load_main_encodings_map (struct a2ps_job * job)
       fprintf (stderr, "Read encoding.map:\n");
       pair_table_list_long (job->encodings_map, stderr);
     }
-  FREE (file);
+  free (file);
   return 1;
 }
 
@@ -192,7 +192,7 @@ static inline unsigned int *
 wx_new (void)
 {
   int i;
-  unsigned int * res = ALLOC (unsigned int, 256);
+  unsigned int *res = XMALLOC (unsigned int, 256);
 
   for (i = 0 ; i < 256 ; i++)
     res [i] = 0;
@@ -276,7 +276,7 @@ font_entry_new (const char * name, unsigned int * wx)
 {
   NEW (struct font_entry, res);
   res->key = xstrdup (name);
-  res->used = FALSE;
+  res->used = false;
   res->wx = wx;
   return res;
 }
@@ -287,8 +287,8 @@ font_entry_new (const char * name, unsigned int * wx)
 static inline void
 font_entry_free (struct font_entry * item)
 {
-  FREE (item->key);
-  FREE (item);
+  free (item->key);
+  free (item);
 }
 
 static void
@@ -309,7 +309,7 @@ font_table_new (void)
 {
   struct hash_table_s * res;
 
-  res = ALLOC (hash_table, 1);
+  res = XMALLOC (hash_table, 1);
   hash_init (res, 32,
 	     (hash_func_t) font_entry_hash_1,
 	     (hash_func_t) font_entry_hash_2,
@@ -321,7 +321,7 @@ static void
 font_table_free (struct hash_table_s * table)
 {
   hash_free (table, (hash_map_func_t) font_entry_free);
-  FREE (table);
+  free (table);
 }
 
 static void
@@ -336,7 +336,7 @@ font_table_self_print (struct hash_table_s * table, FILE * stream)
   for (i = 0 ; entries[i] ; i++)
     font_entry_self_print (entries [i], stream);
   putc ('\n', stream);
-  FREE (entries);
+  free (entries);
 }
 
 /*
@@ -380,7 +380,7 @@ font_entry_is_used (struct hash_table_s * table, const char * name)
 static void
 font_entry_set_used (struct hash_table_s * table, const char * name)
 {
-  font_entry_get (table, name)->used = TRUE;
+  font_entry_get (table, name)->used = true;
 }
 
 /************************************************************************/
@@ -450,15 +450,15 @@ encoding_free (struct encoding * encoding)
   XFREE (encoding->documentation);
 
   for (i = 0 ; i < 256 ; i++)
-    FREE (encoding->vector [i]);
+    free (encoding->vector [i]);
 
   pair_table_free (encoding->substitutes);
   da_free (encoding->font_names_used, (da_map_func_t) free);
   font_table_free (encoding->fonts);
 
   for (i = 0 ; base_faces [i] != -1 ; i++)
-    FREE (encoding->faces_wx [base_faces [i]]);
-  FREE (encoding);
+    free (encoding->faces_wx [base_faces [i]]);
+  free (encoding);
 }
 
 /*
@@ -640,8 +640,8 @@ load_encoding_description_file (a2ps_job * job,
 
     }
   fclose (stream);
-  FREE (buf);
-  FREE (fname);
+  free (buf);
+  free (fname);
 }
 
 /*
@@ -839,7 +839,7 @@ encodings_table_new (void)
 {
   struct hash_table_s * res;
 
-  res = ALLOC (hash_table, 1);
+  res = XMALLOC (hash_table, 1);
   hash_init (res, 32,
 	     (hash_func_t) encoding_hash_1,
 	     (hash_func_t) encoding_hash_2,
@@ -854,7 +854,7 @@ void
 encodings_table_free (struct hash_table_s * table)
 {
   hash_free (table, (hash_map_func_t) encoding_free);
-  FREE (table);
+  free (table);
 }
 
 /*
@@ -997,7 +997,7 @@ dump_encodings_setup (FILE * stream,
   for (i = 0 ; encodings [i] ; i++)
     dump_encoding_setup (stream, job, encodings [i]);
 
-  FREE (encodings);
+  free (encodings);
 }
 
 /************************************************************************/
