@@ -96,8 +96,8 @@ void list_texinfo_encodings_long PARAMS ((struct a2ps_job * job,
 struct pair_htable * encodings_map_new PARAMS ((void));
 void encodings_map_free PARAMS ((struct pair_htable * table));
 
-struct hash_table * encodings_table_new PARAMS ((void));
-void encodings_table_free PARAMS ((struct hash_table * table));
+struct hash_table_s * encodings_table_new PARAMS ((void));
+void encodings_table_free PARAMS ((struct hash_table_s * table));
 
 int load_main_encodings_map PARAMS ((struct a2ps_job * job));
 #endif
