@@ -143,11 +143,11 @@ void
 check_face_eo_font (struct a2ps_job * job)
 {
   int i;
-  int err = FALSE;
+  int err = false;
 
   for (i = 0 ; base_faces [i] != No_face ; i++)
     if (!job->face_eo_font [base_faces [i]]) {
-      err = TRUE;
+      err = true;
       fprintf (stderr, "%s: face `", program_name);
       face_self_print (base_faces [i], stderr);
       fprintf (stderr, "' (%d) has no specified font\n", base_faces [i]);
@@ -157,17 +157,17 @@ check_face_eo_font (struct a2ps_job * job)
 }
 
 /*
- * Return TRUE if the faces are known, FALSE otherwise
+ * Return true if the faces are known, false otherwise
  */
 int
 face_eo_font_is_set (struct a2ps_job * job)
 {
   enum face_e f;
-  int res = TRUE;
+  int res = true;
 
   for (f = First_face ; f <= Last_face ; f++)
     if (!job->face_eo_font [f])
-      res = FALSE;
+      res = false;
 
   return res;
 }
