@@ -21,6 +21,8 @@
 #include <config.h>
 #endif
 
+#include <stdio.h>
+
 #include <sys/types.h>
 
 #ifdef HAVE_UNISTD_H
@@ -66,16 +68,32 @@ extern int errno;
 # define _(Text) Text
 #endif
 
+#if HAVE_STDBOOL_H
+# include <stdbool.h>
+#else
+typedef enum {false = 0, true = 1} bool;
+#endif
+
 #include "error.h"
+#include "darray.h"
 #include "filtdir.h"
-#include "xmalloc.h"
 #include "xfnmatch.h"
 
-#include <stdio.h>
+/* Is NAME . or ..? */
+#define IS_NOTDOTDOT(Name)			\
+  (Name[0] != '.'				\
+   || (Name[1] != '\0'				\
+       && (Name[1] != '.' || Name[2] != '\0')))
+
+/*----------------------------------------------------------------.
+| Perform a call to FUN (FILE, DIR, ARG) on each FILE in DIR that |
+| statisfies a call to FILTER (FILE, DIR, FILTARG).               |
+`----------------------------------------------------------------*/
 
 void
-filterdir (const char *dir, struct darray * arr,
-	   int (*filter) (const char *))
+filterdir (const char *dir,
+	   filterdir_filter_t filter, void *filtarg,
+	   filterdir_fun_t fun, void *arg)
 {
   DIR *dirp;
   struct dirent *dp;
@@ -86,43 +104,10 @@ filterdir (const char *dir, struct darray * arr,
 /*    error (1, errno, _("cannot open directory `%s'"), dir);*/
 
   while ((dp = readdir (dirp)) != NULL)
-    {
-      /* Skip "." and ".." (some NFS filesystems' directories lack them). */
-      if ((dp->d_name[0] != '.'
-	   || (dp->d_name[1] != '\0'
-	       && (dp->d_name[1] != '.' || dp->d_name[2] != '\0')))
-	  && (!filter || (*filter) (dp->d_name)))
-	da_append (arr, xstrdup (dp->d_name));
-    }
-
-  if (CLOSEDIR (dirp))
-    error (1, errno, _("cannot close directory `%s'"), dir);
-}
-
-/*
- * Same, but the argument is a pattern
- */
-void
-filterdir_pattern (const char *dir, struct darray * arr,
-		   const char * pattern)
-{
-  DIR *dirp;
-  struct dirent *dp;
-
-  dirp = opendir (dir);
-  if (dirp == NULL)
-    return;
-/*    error (1, errno, _("cannot open directory `%s'"), dir);*/
-
-  while ((dp = readdir (dirp)) != NULL)
-    {
-      /* Skip "." and ".." (some NFS filesystems' directories lack them). */
-      if ((dp->d_name[0] != '.'
-	   || (dp->d_name[1] != '\0'
-	       && (dp->d_name[1] != '.' || dp->d_name[2] != '\0')))
-	  && !fnmatch (pattern, dp->d_name, 0))
-	da_append (arr, xstrdup (dp->d_name));
-    }
+    /* Skip "." and ".." (some NFS filesystems' directories lack them). */
+    if (IS_NOTDOTDOT (dp->d_name)
+	&& (!filter || (*filter) (dir, dp->d_name, filtarg)))
+      fun (dir, dp->d_name, arg);
 
   if (CLOSEDIR (dirp))
     error (1, errno, _("cannot close directory `%s'"), dir);
