@@ -1,14 +1,11 @@
 /*
- * fjobs.c
- *
- * Recording information about the file jobs
- * Copyright (c) 1988, 89, 90, 91, 92, 93 Miguel Santana
- * Copyright (c) 1995, 96, 97, 98 Akim Demaille, Miguel Santana
+ * fjobs.c -- Recording information about the file jobs
+ * Copyright (c) 1995-99 Akim Demaille, Miguel Santana
  */
 
 /*
  * This file is part of a2ps.
- * 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
@@ -25,41 +22,29 @@
  * Boston, MA 02111-1307, USA.
  */
 
-/*
- * $Id: fjobs.c,v 1.4 1998/03/02 08:56:49 demaille Exp $
- */
 #include "a2ps.h"
 #include "jobs.h"
 #include "fjobs.h"
 #include "routines.h"
 
-/* Temporary file names should start with a2_
- * Don't make it too big (think of MSDOS), though by definition
- * it must be less than 5 chars.
- */
-#define a2ps_file_prefix	"a2_"
-
-/*
- * From isdir.c
- */
-int isdir PARAMS ((char * path));
+typedef struct file_job fjob_t;
 
 /*
  * Creating/Removing a file_job named NAME, which is the NUM job,
  * which tmp file is in TMPDIR, and mod time is default to RUN_TM
- * 
+ *
  */
-struct file_job *
-_a2ps_file_job_new (uchar * name, int num, struct tm * run_tm)
+fjob_t *
+_a2ps_file_job_new (uchar *name, int num, struct tm *run_tm)
 {
-  NEW (struct file_job, res);
+  NEW (fjob_t, res);
 
   /* liba2ps.h must not try to read a file.  This is the job of its
      clients.  Hence, make sure, at least, to have reasonable values.  */
   res->name = name;
   res->delegation_tmpname = NULL;
   res->stdin_tmpname = NULL;
-  
+
   /* The type of the file is unknown */
   res->type = NULL;
 
@@ -67,7 +52,7 @@ _a2ps_file_job_new (uchar * name, int num, struct tm * run_tm)
 
   /* Set date to now */
   res->mod_tm = *run_tm;
-  
+
   /* If for some reason (is a dir, is not readable...), will
    * be later set to false */
   res->printable = true;
@@ -93,13 +78,39 @@ _a2ps_file_job_new (uchar * name, int num, struct tm * run_tm)
   return res;
 }
 
+/*
+ * Release a file_job
+ */
+void
+file_job_free (fjob_t *file_job)
+{
+  XFREE (file_job->delegation_tmpname);
+  XFREE (file_job->stdin_tmpname);
+  free (file_job);
+}
+
+void
+file_job_self_print (fjob_t *file, FILE *stream)
+{
+  fprintf (stream,
+	   "File `%s': Pages %d-%d (%d), Sheets %d-%d (%d)\n",
+	   file->name,
+	   file->first_page, file->last_page, file->pages,
+	   file->first_sheet, file->last_sheet, file->sheets);
+  fprintf (stream,
+	   "\tdel-tmp: `%s', stdin-tmp: `%s', is_toc: %d",
+	   UNNULL (file->delegation_tmpname),
+	   UNNULL (file->stdin_tmpname),
+	   file->is_toc);
+}
+
 /*
  * Synchronise the current file informations onto JOB
  */
 void
 file_job_synchronize_sheets (struct a2ps_job * job)
 {
-  struct file_job * file = CURRENT_FILE (job);
+  fjob_t * file = CURRENT_FILE (job);
 
   /* Set the number of sheets printed */
   if (!file->first_sheet)
@@ -116,7 +127,7 @@ file_job_synchronize_sheets (struct a2ps_job * job)
 void
 file_job_synchronize_pages (struct a2ps_job * job)
 {
-  struct file_job * file = CURRENT_FILE (job);
+  fjob_t * file = CURRENT_FILE (job);
 
   /* Set the number of pages/lines printed */
   if (!file->first_page)
@@ -131,29 +142,11 @@ file_job_synchronize_pages (struct a2ps_job * job)
   file->pages = file->last_page - file->first_page + 1;
 }
 
-/*
- * Usefull for debugging
- */
-void
-file_job_self_print (struct file_job * file, FILE * stream)
-{
-  fprintf (stream,
-	   "File `%s': Pages %d-%d (%d), Sheets %d-%d (%d)\n",
-	   file->name, 
-	   file->first_page, file->last_page, file->pages,
-	   file->first_sheet, file->last_sheet, file->sheets);
-  fprintf (stream,
-	   "\tdel-tmp: `%s', stdin-tmp: `%s', is_toc: %d",
-	   UNNULL (file->delegation_tmpname), 
-	   UNNULL (file->stdin_tmpname), 
-	   file->is_toc);
-}
-
 /*
  * Release the temp file associated to that file_job
  */
 void
-file_job_unlink_tmpfile (struct file_job * file)
+file_job_unlink_tmpfile (fjob_t * file)
 {
   if (file->delegation_tmpname)
     unlink (file->delegation_tmpname);
@@ -161,22 +154,11 @@ file_job_unlink_tmpfile (struct file_job * file)
     unlink (file->stdin_tmpname);
 }
 
-/*
- * Release a file_job
- */
-void
-file_job_free (struct file_job * file_job)
-{
-  XFREE (file_job->delegation_tmpname);
-  XFREE (file_job->stdin_tmpname);
-  FREE (file_job);
-}
-
 /*
  * Compare two files upon the name
  */
 int
-file_name_cmp (struct file_job * f1, struct file_job * f2)
+file_name_cmp (fjob_t *f1, fjob_t *f2)
 {
   return ustrcmp (f1->name, f2->name);
 }
