@@ -1,15 +1,11 @@
 /*
- * fjobs.h
- *
- * Recording information about the file jobs
- * Copyright (c) 1988, 89, 90, 91, 92, 93 Miguel Santana
- * Copyright (c) 1995, 96, 97, 98 Akim Demaille, Miguel Santana
- *
+ * fjobs.h -- Recording information about the file jobs
+ * copyright (c) 1995-99 Akim Demaille, Miguel Santana
  */
 
 /*
  * This file is part of a2ps.
- * 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
@@ -26,15 +22,12 @@
  * Boston, MA 02111-1307, USA.
  */
 
-/*
- * $Id: fjobs.h,v 1.2 1998/03/02 08:56:50 demaille Exp $
- */
-#ifndef _FJOBS_H_
-#define _FJOBS_H_
+#ifndef FJOBS_H_
+# define FJOBS_H_
 
 struct a2ps_job;
 
-/* 
+/*
  * Relative to the current file
  */
 struct file_job
@@ -51,11 +44,11 @@ struct file_job
   char *stdin_tmpname;
 
   const char * type;		/* i.e. ssh key, or UNPRINTABLE		*/
-  boolean is_toc;		/* Is this a toc, or a real file (used
+  bool is_toc;			/* Is this a toc, or a real file (used
 				 * when --pages=toc)			*/
   struct tm mod_tm;		/* Modif. info for the file 		*/
-  boolean printable;		/* Can this file be printed?		*/
-  boolean is_stdin;		/* Is this file named or given by stdin?*/
+  bool printable;		/* Can this file be printed?		*/
+  bool is_stdin;		/* Is this file named or given by stdin?*/
   int first_sheet;		/* num of the first sheet for this file	*/
   int last_sheet;
   int first_page;		/* Id. but pages			*/
@@ -69,7 +62,7 @@ struct file_job
 };
 
 
-/* In the output session JOB, create a new input session NAME */
+/* in the output session JOB, create a new input session NAME */
 struct file_job *
 _a2ps_file_job_new PARAMS ((uchar * name, int num, struct tm * run_tm));
 
@@ -80,4 +73,5 @@ void file_job_synchronize_pages PARAMS ((struct a2ps_job * job));
 void file_job_self_print PARAMS ((struct file_job * file, FILE * stream));
 void file_job_unlink_tmpfile PARAMS ((struct file_job * file));
 void file_job_free PARAMS ((struct file_job * file_job));
+
 #endif /* !defined (_FJOBS_H) */
