@@ -43,8 +43,8 @@ void fonts_map_free PARAMS ((struct pair_htable * table));
 int load_main_fonts_map PARAMS ((struct a2ps_job * job));
 
 
-struct hash_table * font_info_table_new PARAMS ((void));
-void font_info_table_free PARAMS ((struct hash_table * table));
+struct hash_table_s * font_info_table_new PARAMS ((void));
+void font_info_table_free PARAMS ((struct hash_table_s * table));
 void font_info_add PARAMS ((struct a2ps_job * job, const char * key));
 
 int font_exists PARAMS ((struct a2ps_job * job, const char * key));
