@@ -1,7 +1,5 @@
 /*
- * getnum.c
- *
- * Get number in a given interval, get length with units
+ * getnum.c -- Get number in a given interval, get length with units
  *
  * Copyright (c) 1988-1993 Miguel Santana
  * Copyright (c) 1995-1999 Akim Demaille, Miguel Santana
@@ -26,13 +24,22 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>   /* abort() is wanted */
 
 #ifndef EXIT_FAILURE
-#define  EXIT_FAILURE 1
+# define  EXIT_FAILURE 1
 #endif
 
+#include "argmatch.h"
+#include "error.h"
+#include "getnum.h"
+#include "quotearg.h"
+
 /* Take care of NLS matters.  */
 
 #if ENABLE_NLS
@@ -42,11 +49,6 @@
 # define _(Text) Text
 #endif
 
-#include "error.h"
-#include "getnum.h"
-#include "argmatch.h"
-#include "quotearg.h"
-
 /************************************************************************
  *	Get a length/integer in an interval				*
  ************************************************************************/
@@ -148,7 +150,9 @@ get_float_in_range (const char * option, const char * arg,
       break;
 
     default:
-      abort ();
+      error (EXIT_FAILURE, 0, _("invalid argument `%s' for `%s'"),
+	     quotearg (arg), option);
+      break;
     }
 
   /* Divide by the desired unit */
