@@ -1,7 +1,5 @@
 /*
- * getnum.h
- *
- * Get number in a given interval, get length with units
+ * getnum.h -- Get number in a given interval, get length with units
  *
  * Copyright (c) 1988, 89, 90, 91, 92, 93 Miguel Santana
  * Copyright (c) 1995, 96, 97, 98 Akim Demaille, Miguel Santana
@@ -9,7 +7,7 @@
 
 /*
  * This file is part of a2ps.
- * 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
@@ -26,12 +24,8 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#ifndef _GETNUM_H_
-#define _GETNUM_H_
-
-#if HAVE_CONFIG_H
-# include <config.h>
-#endif
+#ifndef GETNUM_H_
+#define GETNUM_H_
 
 #ifndef PARAMS
 # if PROTOTYPES || (defined (__STDC__) && __STDC__)
@@ -56,11 +50,11 @@ enum range_type_e
 
 int get_integer_in_range
 	PARAMS ((const char * option, const char * arg,
-		 int min, int max, 
+		 int min, int max,
 		 enum range_type_e range_type));
 
 float get_length
 	PARAMS ((const char * option, const char * arg,
 		 float min, float max,
 		 const char * unit, enum range_type_e range_type));
-#endif /* !_GETNUM_H_ */
+#endif /* !GETNUM_H_ */
