@@ -25,22 +25,19 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 #endif
 
 #include <stdio.h>
-#include "xsystypes.h"
+
+#if HAVE_SYS_TYPES_H
+# include <sys/types.h>
+#endif
 #include <assert.h>
 
-#ifdef TEST
-#define MALLOC(n) ((char *) malloc (sizeof (char) * (n)))
-#define REMALLOC(o, n) ((char *) realloc ((void *) (o), sizeof (char) * (n)))
-#define FREE(o)  free (o)
-#else
-#  include "xmalloc.h"
-#endif
+#include "xalloc.h"
 
 #include "getshline.h"
 
 /* Always add at least this many bytes when extending the buffer.  */
 #define MIN_CHUNK 64
-
+
 /* Read up to (and including) a TERMINATOR from STREAM into *LINEPTR
    + OFFSET (and null-terminate it). *LINEPTR is a pointer returned from
    malloc (or NULL), pointing to *N characters of space.  It is realloc'd
@@ -48,10 +45,10 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
    null terminator), or -1 on error or EOF.  */
 
 static int
-getshstr (int * firstline, int * lastline, 
+getshstr (int * firstline, int * lastline,
 	  char ** lineptr, size_t * n,
-	  FILE * stream, 
-	  char terminator, int terminator_quote, int commentor, 
+	  FILE * stream,
+	  char terminator, int terminator_quote, int commentor,
 	  size_t offset)
 {
   int nchars_avail;		/* Allocated but unused chars in *LINEPTR.  */
@@ -64,7 +61,7 @@ getshstr (int * firstline, int * lastline,
   if (!*lineptr)
     {
       *n = MIN_CHUNK;
-      *lineptr = MALLOC (*n);
+      *lineptr = XMALLOC (char, *n);
       if (!*lineptr)
 	return -1;
     }
@@ -81,12 +78,7 @@ getshstr (int * firstline, int * lastline,
       /* We always want at least one char left in the buffer, since we
 	 always (unless we get an error while reading the first char)
 	 NUL-terminate the line buffer.  */
-#ifdef TEST
-      fprintf (stderr, "First: %d %d\n",
-	       *n - nchars_avail, read_pos - *lineptr);
-#else
       assert(*n + *lineptr == read_pos + nchars_avail);
-#endif
       if (nchars_avail < 2)
 	{
 	  if (*n > MIN_CHUNK)
@@ -95,16 +87,11 @@ getshstr (int * firstline, int * lastline,
 	    *n += MIN_CHUNK;
 
 	  nchars_avail = *n + *lineptr - read_pos;
-	  *lineptr = REMALLOC (*lineptr, *n);
+	  *lineptr = XREALLOC (*lineptr, char, *n);
 	  if (!*lineptr)
 	    return -1;
 	  read_pos = *n - nchars_avail + *lineptr;
-#ifdef TEST
-	  fprintf (stderr, "Second: %d %d\n",
-		   *n - nchars_avail, read_pos - *lineptr);
-#else
 	  assert(*n + *lineptr == read_pos + nchars_avail);
-#endif
 	}
 
       if (c == EOF || ferror (stream))
@@ -115,10 +102,10 @@ getshstr (int * firstline, int * lastline,
 	  else
 	    break;
 	}
-      
+
       *read_pos++ = c;
       nchars_avail--;
-      
+
       if (c == terminator)
 	{
 	  /* The comment lines can not be continued by an
@@ -128,8 +115,8 @@ getshstr (int * firstline, int * lastline,
 	      /* We just read a blank line.  Then we are reading
 	       * a new first line */
 	      *firstline = *lastline + 1;
-	      return (getshstr (firstline, lastline, lineptr, n, stream, 
-				terminator, terminator_quote, commentor, 
+	      return (getshstr (firstline, lastline, lineptr, n, stream,
+				terminator, terminator_quote, commentor,
 				offset));
 	    }
 	  if ((read_pos - 2 <= *lineptr)
@@ -150,12 +137,12 @@ getshstr (int * firstline, int * lastline,
   ret = read_pos - (*lineptr + offset);
   return ret;
 }
-
+
 int
-getshline_numbered (int * firstline, int * lastline, 
+getshline_numbered (int * firstline, int * lastline,
 		    char ** lineptr, size_t * n, FILE * stream)
 {
-  return getshstr (firstline, lastline, lineptr, n, stream, 
+  return getshstr (firstline, lastline, lineptr, n, stream,
 		   '\n', '\\', '#', 0);
 }
 
@@ -163,18 +150,18 @@ int
 getshline (char ** lineptr, size_t * n, FILE * stream)
 {
   int firstline, lastline;
-  return getshstr (&firstline, &lastline, lineptr, n, stream, 
+  return getshstr (&firstline, &lastline, lineptr, n, stream,
 		   '\n', '\\', '#', 0);
 }
 
 
 int
-getshdelim_numbered (int * firstline, int * lastline, 
-		     char ** lineptr, size_t * n, 
+getshdelim_numbered (int * firstline, int * lastline,
+		     char ** lineptr, size_t * n,
 		     int delimiter, int delimiter_quote, int commentor,
 		     FILE * stream)
 {
-  return getshstr (firstline, lastline, lineptr, n, stream, 
+  return getshstr (firstline, lastline, lineptr, n, stream,
 		   delimiter, delimiter_quote, commentor, 0);
 }
 
@@ -184,10 +171,10 @@ getshdelim (char ** lineptr, size_t * n,
 	    FILE * stream)
 {
   int firstline, lastline;
-  return getshstr (&firstline, &lastline, lineptr, n, stream, 
+  return getshstr (&firstline, &lastline, lineptr, n, stream,
 		   delimiter, delimiter_quote, commentor, 0);
 }
-
+
 #ifdef TEST
 
 const char * program_name = "getsh";
@@ -200,19 +187,19 @@ main(int argc, char *argv[])
   int line_size = 0;
   FILE * file;
   int res;
-  
+
   if (argc < 2)
     exit (1);
   file = fopen (argv[1], "r");
   if (!file)
     exit (1);
 
-  while ((res = getshline_numbered (&firstline, &lastline, 
+  while ((res = getshline_numbered (&firstline, &lastline,
 				    &line_content, &line_size, file)) != -1)
       printf ("%3d-%3d:%s", firstline, lastline, line_content);
-  
 
-  FREE (line_content);
+
+  free (line_content);
   return 0;
 }
 #endif
