@@ -19,9 +19,13 @@
 
 #include <config.h>
 #include <stdio.h>
-#include "xstdlib.h"
+
+#if defined STDC_HEADERS || defined _LIBC || defined HAVE_STDLIB_H
+# include <stdlib.h>
+#endif
+
 #include "hashtab.h"
-#include "xmalloc.h"
+#include "xalloc.h"
 #include "error.h"
 
 static void hash_rehash PARAMS((struct hash_table_s* ht));
@@ -46,7 +50,7 @@ hash_init (struct hash_table_s* ht, unsigned long size,
   ht->ht_size = round_up_2 (size);
   if (ht->ht_size > (128 * 1024)) /* prevent size from getting out of hand */
     ht->ht_size /= 2;
-  ht->ht_vec = (void**) CALLOC (struct token *, ht->ht_size);
+  ht->ht_vec = (void**) XCALLOC (struct token *, ht->ht_size);
   ht->ht_capacity = ht->ht_size * 15 / 16; /* 93.75% loading factor */
   ht->ht_fill = 0;
   ht->ht_collisions = 0;
@@ -225,7 +229,7 @@ hash_rehash (struct hash_table_s* ht)
   ht->ht_size *= 2;
   ht->ht_rehashes++;
   ht->ht_capacity = ht->ht_size - (ht->ht_size >> 4);
-  ht->ht_vec = (void **) CALLOC (struct token *, ht->ht_size);
+  ht->ht_vec = (void **) XCALLOC (struct token *, ht->ht_size);
 
   for (ovp = old_vec; ovp < &old_vec[old_ht_size]; ovp++)
     {
@@ -261,7 +265,7 @@ hash_dump (struct hash_table_s *ht, void **vector_0, qsort_cmp_t compare)
   void **end = &ht->ht_vec[ht->ht_size];
 
   if (vector_0 == 0)
-    vector_0 = ALLOC (void *, ht->ht_fill + 1);
+    vector_0 = XMALLOC (void *, ht->ht_fill + 1);
   vector = vector_0;
 
   for (slot = ht->ht_vec; slot < end; slot++)
@@ -292,7 +296,7 @@ hash_dump_select (struct hash_table_s *ht, void **vector_0,
 
   if (vector_0 == 0)
     {
-      vector_0 = ALLOC (void *, ht->ht_fill + 1);
+      vector_0 = XMALLOC (void *, ht->ht_fill + 1);
       vector_0_malloced = 1;
     }
 
@@ -303,7 +307,7 @@ hash_dump_select (struct hash_table_s *ht, void **vector_0,
   vector_0 [fill] = 0;
 
   if (vector_0_malloced)
-    vector_0 = REALLOC (vector_0, void *, fill + 1);
+    vector_0 = XREALLOC (vector_0, void *, fill + 1);
 
   if (compare && fill > 1)
     qsort (vector_0, fill, sizeof (void *), compare);
@@ -323,7 +327,7 @@ hash_maparg (struct hash_table_s *ht, hash_maparg_func_t map,
   for (vector = vector_0 ; *vector ; vector++)
     (*map) (*vector, arg);
 
-  FREE (vector_0);
+  free (vector_0);
 }
 
 /* Round a given number up to the nearest power of 2. */
