@@ -34,25 +34,42 @@
 #  define PARAM_UNUSED
 #endif
 
-#ifndef HAVE_DECL_FPUTS
-int fputs ();
-#endif
-
 #include <stdio.h>
 
-#include <sys/types.h>
+#if HAVE_STRING_H
+# if !STDC_HEADERS && HAVE_MEMORY_H
+#  include <memory.h>
+# endif
+# include <string.h>
+#else
+# if HAVE_STRINGS_H
+#  include <strings.h>
+# endif
+#endif
+#if HAVE_STDLIB_H
+# include <stdlib.h>
+#endif
+
+#if HAVE_SYS_TYPES_H
+# include <sys/types.h>
+#endif
 
 #if HAVE_INTTYPES_H
 # include <inttypes.h>
 #endif
 
-#include "xmalloc.h"
+#if !HAVE_DECL_FPUTS
+extern void fputs ();
+#endif
+
+#if !HAVE_DECL_STRLEN
+extern int strlen ();
+#endif
+
+#include "xalloc.h"
 #include "tterm.h"
 #include "lister.h"
 
-#undef XMALLOC
-#define XMALLOC(t, n) ((t *) xmalloc (sizeof (t) * (n)))
-
 /* Information about filling a column.  */
 struct world
 {
