@@ -3,14 +3,14 @@
  *
  * madir direction
  *
- * Copyright (c) 1988, 89, 90, 91, 92, 93 Miguel Santana
- * Copyright (c) 1995, 96, 97, 98 Akim Demaille, Miguel Santana
+ * Copyright (c) 1988-1993 Miguel Santana
+ * Copyright (c) 1995-1999 Akim Demaille, Miguel Santana
  * $Id: madir.h,v 1.2 1998/08/06 16:53:49 demaille Exp $
  */
 
 /*
  * This file is part of a2ps.
- * 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
@@ -27,8 +27,8 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#ifndef _MADIR_H_
-#define _MADIR_H_ 1
+#ifndef MADIR_H_
+# define MADIR_H_ 1
 
 /* Should the virtual page go first to the left, or the bottom? */
 typedef enum madir_e
@@ -38,4 +38,4 @@ typedef enum madir_e
 
 madir_t madir_argmatch PARAMS ((const char * option, const char * arg));
 const char * madir_to_string PARAMS ((madir_t madir));
-#endif /* !defined (_MADIR_H_) */
+#endif /* !defined (MADIR_H_) */
