@@ -103,7 +103,7 @@ add_medium (struct a2ps_job * job,
 	   int w, int h,
 	   int llx, int lly, int urx, int ury)
 {
-  struct medium * a_medium = ALLOC (struct medium, 1);
+  struct medium * a_medium = XMALLOC (struct medium, 1);
 
   a_medium->name = xstrdup (name);
   a_medium->w = w;
@@ -122,8 +122,8 @@ add_medium (struct a2ps_job * job,
 static void
 hash_free_medium (struct medium * medium)
 {
-  FREE (medium->name);
-  FREE (medium);
+  free (medium->name);
+  free (medium);
 }
 
 /*
@@ -134,7 +134,7 @@ new_medium_table (void)
 {
   struct hash_table_s * res;
 
-  res = ALLOC (struct hash_table_s, 1);
+  res = XMALLOC (struct hash_table_s, 1);
   hash_init (res, 16,
 	     medium_hash_1, medium_hash_2, medium_hash_cmp);
 
@@ -148,7 +148,7 @@ void
 free_medium_table (struct hash_table_s * table)
 {
   hash_free (table, (hash_map_func_t) hash_free_medium);
-  FREE (table);
+  free (table);
 }
 
 /*
@@ -189,7 +189,7 @@ a2ps_get_medium_name (a2ps_job * job, const char * name)
 }
 
 /* Is libpaper used? */
-boolean
+bool
 a2ps_medium_libpaper_p (PARAM_UNUSED a2ps_job * job, const char * name)
 {
   return strequ (name, LIBPAPER_MEDIUM) ? true : false;
@@ -221,7 +221,7 @@ list_media_long (a2ps_job * job, FILE * stream)
 	     media[i]->urx, media[i]->ury);
   putc ('\n', stream);
 
-  FREE (media);
+  free (media);
 }
 
 /*
@@ -241,5 +241,5 @@ list_media_short (a2ps_job * job, FILE * stream)
 			  (lister_width_t) medium_name_len,
 			  (lister_print_t) medium_name_fputs);
 
-  FREE (media);
+  free (media);
 }
