@@ -65,7 +65,7 @@ struct medium * a2ps_get_medium PARAMS ((struct a2ps_job * job,
 const char  * a2ps_get_medium_name PARAMS ((struct a2ps_job * job, 
 					    const char *string));
 
-boolean a2ps_medium_libpaper_p PARAMS ((struct a2ps_job * job, 
+bool a2ps_medium_libpaper_p PARAMS ((struct a2ps_job * job, 
 					const char * name));
 
 void add_medium PARAMS ((struct a2ps_job * job,
