@@ -17,10 +17,20 @@
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 
-#include "message.h"
-#include "argmatch.h"
-#include "getnum.h"
+#if HAVE_CONFIG_H
+# include <config.h>
+#endif
 
+/* Support of prototyping when possible */
+#ifndef PARAMS
+#  if PROTOTYPES
+#    define PARAMS(protos) protos
+#  else /* no PROTOTYPES */
+#    define PARAMS(protos) ()
+#  endif /* no PROTOTYPES */
+#endif
+
+#include <stdio.h>
 #include <assert.h>
 #include <ctype.h>
 /* Jim Meyering writes:
@@ -41,6 +51,10 @@
 #endif
 #define ISDIGIT(c) (ISASCII (c) && isdigit   ((int) c))
 
+#if defined STDC_HEADERS || defined _LIBC || defined HAVE_STDLIB_H
+# include <stdlib.h>
+#endif
+
 /* We want strtok. */
 
 #ifdef HAVE_STRING_H
@@ -53,6 +67,9 @@
 char *memchr ();
 #endif
 
+#include "message.h"
+#include "argmatch.h"
+#include "getnum.h"
 
 /* The bigger, the more verbose.  Should be set by application */
 
@@ -74,20 +91,18 @@ int
 msg_verbosity_argmatch (const char *option, char *arg)
 {
   int res = 0;
-  char *token;
 
   ARGMATCH_ASSERT (_msg_verbosity_args, _msg_verbosity_types);
 
   if (ISDIGIT (*arg))
     {
       /* The verbosity is set through an integer value */
-      msg_verbosity =
-	get_integer_in_range (option, arg, 0, 0, range_min);
+      res = get_integer_in_range (option, arg, 0, 0, range_min);
     }
   else
     {
       /* Keywords are used to define verbosity level */
-      token = strtok (arg, verbosity_sep);
+      char *token = strtok (arg, verbosity_sep);
       do
 	{
 	  res |= XARGCASEMATCH (option, token,
