@@ -40,6 +40,7 @@
 #include "xobstack.h"
 #include "pair_ht.h"
 #include "prange.h"
+#include "title.h"
 
 #define KEY_FORBIDDEN_CHARS ":(){}"
 
@@ -69,7 +70,7 @@ macro_meta_sequence_table_free (struct pair_htable * table)
  * (Note, strdup is done so that no memory is shared with key and value)
  *
  */
-boolean
+bool
 macro_meta_sequence_add (struct a2ps_job * job,
 			 const char * key, const char * value)
 {
@@ -109,7 +110,7 @@ void
 macro_meta_sequences_list_long (struct a2ps_job * job,
 				FILE * stream)
 {
-  fprintf (stream, _("Known Variables"));
+  title (stream, '=', true, _("Known Variables"));
   putc ('\n', stream);
   pair_table_list_long (job->macro_meta_sequences, stream);
 }
@@ -160,7 +161,7 @@ macro_meta_sequences_list_long (struct a2ps_job * job,
      if (!next)								\
        error (1, 0, _("%s: missing `%c' for %s%c escape"),		\
 	      context_name, sep, esc, cat);				\
-     *next++ = NUL;							\
+     *next++ = '\0';							\
    } while (0)
 
 /*
@@ -305,7 +306,7 @@ grow_user_string_obstack (struct obstack * user_string_stack,
 	    if (!cp)
 	      error (1, errno,
 		     _("cannot get current working directory"));
-	    cp2 = ustrrchr (cp, DIR_SEP);
+	    cp2 = ustrrchr (cp, DIRECTORY_SEPARATOR);
 	    if (cp2)
 	      cp2++;
 	    else
@@ -629,7 +630,7 @@ grow_user_string_obstack (struct obstack * user_string_stack,
 	    break;
 
 	  case 'd':	/* `$d' directory part of the current file */
-	    cp = ustrrchr (file->name, DIR_SEP);
+	    cp = ustrrchr (file->name, DIRECTORY_SEPARATOR);
 	    if (cp) {
 	      ustrncpy (buf, file->name, cp - file->name);
 	      buf [cp - file->name] = '\0';
@@ -726,10 +727,10 @@ grow_user_string_obstack (struct obstack * user_string_stack,
 	    }
 	    break;
 
-	  case 'N':	/* `$N' input file name without suffix
-			 * nor directory */
+	  case 'N': /* `$N' input file name without suffix nor
+		       directory. */
 	    /* First, skip dirname */
-	    cp = ustrrchr (file->name, DIR_SEP);
+	    cp = ustrrchr (file->name, DIRECTORY_SEPARATOR);
 	    if (cp == NULL)
 	      cp =file->name;
 	    else
@@ -746,7 +747,7 @@ grow_user_string_obstack (struct obstack * user_string_stack,
 	    break;
 
 	  case 'n':	/* `$n' input file name without directory */
-	    cp = ustrrchr (file->name, DIR_SEP);
+	    cp = ustrrchr (file->name, DIRECTORY_SEPARATOR);
 	    if (cp == NULL)
 	      cp = file->name;
 	    else
@@ -1115,7 +1116,7 @@ grow_user_string_obstack (struct obstack * user_string_stack,
 		grow_user_string_obstack (user_string_stack,
 					  job, file,
 					  context_name, if_false);
-	      FREE (if_true);
+	      free (if_true);
 	    }
 	    break;
 
@@ -1234,7 +1235,7 @@ grow_user_string_obstack (struct obstack * user_string_stack,
 		       context_name, "#!", category, category);
 		break;
 	      }
-	      FREE (in);
+	      free (in);
 	    }
 	    break;
 
@@ -1244,7 +1245,7 @@ grow_user_string_obstack (struct obstack * user_string_stack,
 	      if (k < 0 || 9 < k)
 		error (1, 0, _("%s: unknown `%s' escape `%c' (%d)"),
 		       context_name, "#f", str [i], str [i]);
-	      tempname_ensure (job->tmp_filenames [k], job->common.tmpdir);
+	      tempname_ensure (job->tmp_filenames [k]);
 	      APPEND_STR (job->tmp_filenames [k]);
 	    }
 	    break;
@@ -1300,9 +1301,10 @@ grow_user_string_obstack (struct obstack * user_string_stack,
     }
 }
 
-/*
- * The exported function
- */
+
+/* The exported function.
+   GIGO principle: if STR is NULL, output too.  */
+
 uchar *
 expand_user_string (struct a2ps_job * job,
 		    struct file_job * file,
@@ -1320,6 +1322,9 @@ expand_user_string (struct a2ps_job * job,
       obstack_init (&user_string_stack);
     }
 
+  if (!str)
+    return NULL;
+
   message (msg_meta,
 	   (stderr, "Expanding of %s user string (`%s')\n",
 	    context_name, str));
