@@ -43,7 +43,7 @@ struct pair_htable * macro_meta_sequence_table_new PARAMS ((void));
 void macro_meta_sequence_table_free PARAMS ((struct pair_htable * table));
 
 /* Return true if valid definition, false otherwise */
-boolean macro_meta_sequence_add PARAMS ((struct a2ps_job * job,
+bool macro_meta_sequence_add PARAMS ((struct a2ps_job * job,
 					 const char * key,
 					 const char * value));
 void macro_meta_sequence_delete PARAMS ((struct a2ps_job * job,
