@@ -72,7 +72,6 @@ static struct option const long_options[] =
   {"help",		no_argument,		0, 'h'},
   {"guess",		no_argument,		0, 138},
   {"list", 		required_argument,	0, 145},
-  {"copyright", 	no_argument,		0, 174},
   {"version", 		no_argument,		0, 'V'},
   /* these ones are a courtesy for those who are used to enscript */
   {"list-options", 	no_argument,		0, 139},
@@ -165,7 +164,11 @@ static struct option const long_options[] =
   {"toc",		optional_argument,	0, 167},
   {"pages", 		optional_argument,	0, 'a'},
 
-  /* Free: 137, 150, 165, 168, 170, 171, 172 Next to use is: 175 */
+  {"which", 		no_argument,		0, 137},
+  {"glob", 		no_argument,		0, 150},
+
+
+  /* Free: 165, 168, 170, 171, 172 Next to use is: 174 */
   {NULL, 0, 0, 0}
 };
 
@@ -179,29 +182,29 @@ static struct option const long_options[] =
 /* Helping routines for the options' arguments				*/
 /************************************************************************/
 /*
- * What about the booleans
+ * What about the bools
  */
-static const char *const boolean_args[] =
+static const char *const bool_args[] =
 {
   "yes", "on", "1",
   "no", "off", "0",
   0
 };
 
-static const boolean boolean_types[] =
+static const bool bool_types[] =
 {
   true, true, true,
   false, false, false
 };
 
 /*
- * Return the boolean value
+ * Return the bool value
  */
-boolean
-a2ps_get_boolean (const char *option, const char *arg)
+bool
+a2ps_get_bool (const char *option, const char *arg)
 {
-  ARGMATCH_ASSERT (boolean_args, boolean_types);
-  return XARGCASEMATCH (option, arg, boolean_args, boolean_types);
+  ARGMATCH_ASSERT (bool_args, bool_types);
+  return XARGCASEMATCH (option, arg, bool_args, bool_types);
 }
 
 
@@ -298,7 +301,7 @@ a2ps_handle_options (a2ps_job * job, int argc, char *argv[])
 	  fprintf (stderr,
 		   _("Try `%s --help' for more information.\n"),
 		   program_invocation_name);
-	  exit (EXIT_BADARG);
+	  exit (EXIT_FAILURE);
 	}
 
       /* Store the pair. */
@@ -430,11 +433,12 @@ a2ps_handle_options (a2ps_job * job, int argc, char *argv[])
 	break;
 
       case 'c':				/* cut lines too large */
-	job->folding = FALSE;
+	job->folding = false;
 	break;
 
       case 151:				/* cut lines too large */
-	job->folding = a2ps_get_boolean ("--truncate-lines", optarg);
+	job->folding = (a2ps_get_bool ("--truncate-lines", optarg)
+			? false : true);
 	break;
 
       case 'C':				/* line numbering */
@@ -463,7 +467,7 @@ a2ps_handle_options (a2ps_job * job, int argc, char *argv[])
 	     otherwise (-SFeature:value) pass to libppd */
 	  if (*value)
 	    {
-	      *value = NUL;
+	      *value = '\0';
 	      value ++;
 	      if (*value)
 		setpagedevice (job, optarg, value);
@@ -495,27 +499,27 @@ a2ps_handle_options (a2ps_job * job, int argc, char *argv[])
       break;
 
       case 'i':				/* interpret control chars */
-	job->interpret = TRUE;
+	job->interpret = true;
 	break;
 
       case 155:				/* interpret control chars */
-	job->interpret = a2ps_get_boolean ("--interpret", optarg);
+	job->interpret = a2ps_get_bool ("--interpret", optarg);
 	break;
 
       case 'j':				/* surrounding border */
-	job->border = TRUE;
+	job->border = true;
 	break;
 
       case 156:				/* surrounding border */
-	job->border = a2ps_get_boolean ("--border", optarg);
+	job->border = a2ps_get_bool ("--border", optarg);
 	break;
 
       case 'k':				/* page prefeed */
-	job->page_prefeed = TRUE;
+	job->page_prefeed = true;
 	break;
 
       case 'K':				/* no page prefeed */
-	job->page_prefeed = FALSE;
+	job->page_prefeed = false;
 	break;
 
       case 'l':
@@ -604,12 +608,12 @@ a2ps_handle_options (a2ps_job * job, int argc, char *argv[])
 	    }
 	  else
 	    {
-	      *value = NUL;
+	      *value = '\0';
 	      value ++;
 	      if (*value == ':')
-		setstatusdict (job, optarg, value + 1, TRUE);
+		setstatusdict (job, optarg, value + 1, true);
 	      else
-		setstatusdict (job, optarg, value, FALSE);
+		setstatusdict (job, optarg, value, false);
 	    }
 	}
 	break;
@@ -678,7 +682,7 @@ a2ps_handle_options (a2ps_job * job, int argc, char *argv[])
 	break;
 
       case 136:				/* --print-anyway=bool */
-	job->print_binaries = a2ps_get_boolean ("--print-anyway", optarg);
+	job->print_binaries = a2ps_get_bool ("--print-anyway", optarg);
 	break;
 
       case 'D':				/* --define=key:value */
@@ -689,7 +693,7 @@ a2ps_handle_options (a2ps_job * job, int argc, char *argv[])
 	     then be empty (`--var=foo=' i.e. foo = "") which is not
 	     the same thing as --var=foo (i.e., undefine the var foo) */
 	  if (*value)
-	    *value++ = NUL;
+	    *value++ = '\0';
 	  else
 	    value = NULL;
 	  if (value)
@@ -731,7 +735,7 @@ a2ps_handle_options (a2ps_job * job, int argc, char *argv[])
 	break;
 
       case 146:				/* --debug */
-	job->debug = TRUE;
+	job->debug = true;
 	break;
 
       case 147:				/* --margin */
