@@ -117,7 +117,7 @@ pair_table_new (void)
 {
   struct hash_table_s * res;
 
-  res = ALLOC (struct hash_table_s, 1);
+  res = XMALLOC (struct hash_table_s, 1);
   hash_init (res, 8,
 	     (hash_func_t) pair_hash_1,
 	     (hash_func_t) pair_hash_2,
@@ -132,7 +132,7 @@ void
 pair_table_free (struct hash_table_s * table)
 {
   hash_free (table, (hash_map_func_t) pair_free);
-  FREE (table);
+  free (table);
 }
 
 /*
@@ -150,9 +150,9 @@ pair_add (struct hash_table_s * table,
 
   if (item) {
     if (item->value)
-      FREE (item->value);
+      free (item->value);
   } else {
-    item = ALLOC (struct pair, 1);
+    item = XMALLOC (struct pair, 1);
     item->key = xstrdup(key);
   }
 
@@ -225,7 +225,7 @@ pair_table_map (struct hash_table_s * table,
       }
   }
 
-  FREE (entries);
+  free (entries);
 }
 
 /*
@@ -243,7 +243,7 @@ pair_table_list_short (struct hash_table_s * table, FILE * stream)
 			  (void **) entries, (size_t) -1,
 			  (lister_width_t) pair_key_len,
 			  (lister_print_t) pair_key_fputs);
-  FREE (entries);
+  free (entries);
 }
 
 /*
@@ -259,12 +259,12 @@ pair_table_list_long (struct hash_table_s * table, FILE * stream)
 	       (hash_cmp_func_t) pair_hash_qcmp);
 
   for (i = 0 ; entries[i] ; i++)
-    fprintf (stream, "  %-10s = %s\n",
+    fprintf (stream, "%-16s = %s\n",
 	     entries[i]->key,
 	     entries[i]->value ? entries[i]->value : "<NULL>");
 
   putc ('\n', stream);
-  FREE (entries);
+  free (entries);
 }
 
 /*
@@ -285,7 +285,7 @@ pair_table_self_print (struct hash_table_s * table, FILE * stream)
 	     entries[i]->value ? entries[i]->value : "<NULL>");
 
   putc ('\n', stream);
-  FREE (entries);
+  free (entries);
 }
 
 #define GET_TOKEN(from) (strtok ((from), " \t\n"))
@@ -334,7 +334,7 @@ pair_table_load (struct hash_table_s * table, const char *file)
 	}
     }
 
-  FREE (buf);
+  free (buf);
   fclose (fp);
   return 1;
 }
