@@ -1,10 +1,8 @@
 /*
- * pathwalk.c
+ * pathwalk.c -- functions for ooking for files, reading files etc.
  *
- * functions for ooking for files, reading files etc.
  * Copyright (c) 1988, 89, 90, 91, 92, 93 Miguel Santana
  * Copyright (c) 1995, 96, 97, 98, 99 Akim Demaille, Miguel Santana
- * $Id: pathwalk.c,v 1.34 1998/03/03 15:51:21 demaille Exp $
  */
 
 /*
@@ -24,6 +22,10 @@
  * Boston, MA 02111-1307, USA.
  */
 
+/* I know this file would need a full rewrite, nevertheless, since
+   some day we should use kpathsea, it would be a waste of time.
+   There are other files to rewrite :). */
+
 #include "a2ps.h"
 #include "pathwalk.h"
 #include "darray.h"
@@ -33,19 +35,20 @@
 #include "lister.h"
 #include "strverscmp.h"
 #include "quotearg.h"
+#include "dirname.h"
 
-/*
- * Build in a alloca'ed zone the concat of DIR and FILE
- */
-#define apathconcat(_d_,_dir_,_file_)			\
+/*---------------------------------.
+| Alloca D to contain "DIR/FILE".  |
+`---------------------------------*/
+#define apathconcat(D,Dir,File)				\
    do {							\
-	char * _tmp1_ = (char *) (_dir_);		\
-	const char * _tmp2_ = (const char *) (_file_);	\
-	_d_ = ALLOCA (char, (strlen (_tmp1_) 		\
-			     + strlen (_tmp2_) + 2));	\
-	_tmp1_ = stpcpy (_d_, _tmp1_);			\
-        (*_tmp1_++) = DIR_SEP;				\
-        stpcpy (_tmp1_, _tmp2_);			\
+	char * tmp1 = (char *) (Dir);			\
+	const char * tmp2 = (const char *) (File);	\
+	D = ALLOCA (char, (strlen (tmp1) 		\
+			     + strlen (tmp2) + 2));	\
+	tmp1 = stpcpy (D, tmp1);			\
+        (*tmp1++) = DIRECTORY_SEPARATOR;		\
+        stpcpy (tmp1, tmp2);				\
    } while (0)
 
 /************************************************************************/
@@ -54,13 +57,13 @@
 static char **
 pw_internal_string_to_path (const char * path, char sep, int * length)
 {
-  char ** res = NULL;
+  char **res = NULL;
   int allocated = 5;	/* num of entries yet allocated in res	*/
   int entries = 0;
-  const char * cp, * cp2;
+  const char *cp, *cp2;
   int len;
 
-  res = CALLOC (char *, allocated);
+  res = XCALLOC (char *, allocated);
   for (cp = path; cp; cp = strchr (cp, sep))
     {
       if (cp != path)
@@ -72,31 +75,35 @@ pw_internal_string_to_path (const char * path, char sep, int * length)
       else
         len = strlen (cp);
 
-      if (len == 0) {
+      if (len == 0)
+	{
 	/* Skip empty entries */
         cp++;
         continue;
-      } else {
-	/* Make sure _not_ to include that last DIR_SEP */
-	if (cp [len] == DIR_SEP)
-	  len --;
-      }
+	}
+      else
+	{
+	  /* Make sure _not_ to include that last DIRECTORY_SEPARATOR */
+	  if (cp [len] == DIRECTORY_SEPARATOR)
+	    len --;
+	}
 
-      res [ entries ] = MALLOC (len + 1);
+      res [ entries ] = XMALLOC (char, len + 1);
       strncpy (res [entries],  cp, len);
       res [entries] [len] = '\0';
 
       entries++;
-      if (entries >= allocated) {
-	allocated *= 2;
-	res = REALLOC (res, char *, allocated);
-      }
+      if (entries >= allocated)
+	{
+	  allocated *= 2;
+	  res = XREALLOC (res, char *, allocated);
+	}
     }
   *length = entries;
 
   /* Make it null-terminated, and exactely that size */
   res [*length] = NULL;
-  res = REALLOC (res, char *, *length + 1);
+  res = XREALLOC (res, char *, *length + 1);
   return res;
 }
 
@@ -116,61 +123,65 @@ pw_path_length (char ** path)
   return res;
 }
 
-/*
- * Build a path as array from a PATH as string, given the separator
- * PATH is read only.
- */
+/*-----------------------------------------------------------------.
+| Build a path as array from a PATH as string, given the separator |
+| PATH is read only.                                               |
+`-----------------------------------------------------------------*/
+
 char **
-pw_string_to_path (const char * path, char sep)
+pw_string_to_path (const char * path)
 {
   int dummy;
-  return pw_internal_string_to_path (path, sep, &dummy);
+  return pw_internal_string_to_path (path, PATH_SEPARATOR, &dummy);
 }
 
 /*
  * Concat PATH2 to PATH1, and return the result.  Free PATH2
  */
+
 static inline char **
 pw_path_concat (char ** path1, int len1, char ** path2, int len2)
 {
   int i;
 
-  if (path2) {
-    path1 = REALLOC (path1, char *, len1 + len2 + 1);
-    for (i = 0 ; i <= len2 ; i++)
-      path1 [len1 + i] = path2 [i];
-    FREE (path2);
-  }
+  if (path2)
+    {
+      path1 = XREALLOC (path1, char *, len1 + len2 + 1);
+      for (i = 0 ; i <= len2 ; i++)
+	path1 [len1 + i] = path2 [i];
+      free (path2);
+    }
 
   return path1;
 }
 
-/*
- * Append a string-path DIR2 (separated by SEP) to PATH1
- */
+/*-------------------------------------.
+| Append a string-path DIR2 to PATH1.  |
+`-------------------------------------*/
+
 char **
-pw_append_string_to_path (char ** path1, const char * dir2, char sep)
+pw_append_string_to_path (char ** path1, const char * dir2)
 {
   int len1, len2;
   char ** path2;
 
   len1 = pw_path_length (path1);
-  path2 = pw_internal_string_to_path (dir2, sep, &len2);
+  path2 = pw_internal_string_to_path (dir2, PATH_SEPARATOR, &len2);
 
   return pw_path_concat (path1, len1, path2, len2);
 }
 
-/*
- * Prepend a string-path DIR2 (separated by SEP) to PATH1
- */
+/*--------------------------------------.
+| Prepend a string-path DIR2 to PATH1.  |
+`--------------------------------------*/
 char **
-pw_prepend_string_to_path (char ** path1, const char * dir2, char sep)
+pw_prepend_string_to_path (char ** path1, const char * dir2)
 {
   int len1, len2;
   char ** path2;
 
   len1 = pw_path_length (path1);
-  path2 = pw_internal_string_to_path (dir2, sep, &len2);
+  path2 = pw_internal_string_to_path (dir2, PATH_SEPARATOR, &len2);
 
   return pw_path_concat (path2, len2, path1, len1);
 }
@@ -184,7 +195,7 @@ pw_free_path (char ** path)
   int i;
   if (path)
     for (i = 0 ; path[i] ; i++)
-      FREE (path[i]);
+      free (path[i]);
   XFREE (path);
 }
 
@@ -198,10 +209,11 @@ pw_fprintf_path (FILE * stream, const char * format, char * const * path)
     }
 }
 
-/*
- * Return the index+1 in PATH of the directory that contains
- * the file concat(NAME, SUFFIX)
- */
+/*-------------------------------------------------------------------.
+| Return the index+1 in PATH of the directory that contains the file |
+| concat(NAME, SUFFIX).                                              |
+`-------------------------------------------------------------------*/
+
 static int
 pw_find_file_index (char * const * path,
 		    const char *name, const char *suffix)
@@ -215,12 +227,8 @@ pw_find_file_index (char * const * path,
   else
     filename = (char *) name;
 
-  if (msg_test (msg_pw))
-    {
-      message (msg_pw,
-	       (stderr, "Looking for `%s' in the path:\n", filename));
-      pw_fprintf_path (stderr, "\t-> %s\n", path);
-    }
+  message (msg_pw,
+	   (stderr, "pw: looking for `%s'\n", filename));
 
   if (path)
     for (i = 0 ; path [i] ; i ++)
@@ -229,18 +237,24 @@ pw_find_file_index (char * const * path,
 	if (stat (fullpath, &stat_st) == 0)
 	  {
 	    /* File exists */
-	    message (msg_pw, (stderr, "success in %s\n", path[i]));
+	    message (msg_pw, (stderr, "pw: success in %s\n", path[i]));
 	    return i + 1;
 	  }
       }
 
-  message (msg_pw, (stderr, "failure\n"));
+  if (msg_test (msg_pw))
+    {
+      fprintf  (stderr, "pw: did not find `%s' in path\n", filename);
+      pw_fprintf_path (stderr, "pw:  %s\n", path);
+    }
+
   return 0;
 }
 
-/*
- * Return non 0 if the file exists
- */
+/*--------------------------------.
+| Return non 0 if the file exists |
+`--------------------------------*/
+
 int
 pw_file_exists_p (char * const * path,
 		    const char *name, const char * suffix)
@@ -248,10 +262,11 @@ pw_file_exists_p (char * const * path,
   return pw_find_file_index (path, name, suffix);
 }
 
-/*
- * Return the malloc'd full path of existing file
- * named concat(NAME, SUFFIX)
- */
+/*------------------------------------------------------------------.
+| Return the malloc'd full path of existing file named concat(NAME, |
+| SUFFIX).                                                          |
+`------------------------------------------------------------------*/
+
 static inline char *
 _pw_find_file (char * const * path,
 	       const char * name, const char * suffix)
@@ -266,13 +281,19 @@ _pw_find_file (char * const * path,
       /* Return a malloc'ed full file name */
       if (suffix)
 	{
-	  res = MALLOC (strlen (path[i-1]) + 2
-			+ strlen (name) + strlen (suffix));
-	  sprintf (res, "%s%c%s%s", path [i-1], DIR_SEP, name, suffix);
-	} else {
-	  res = MALLOC (strlen (path[i-1]) + 2
-			+ strlen (name));
-	  sprintf (res, "%s%c%s", path [i-1], DIR_SEP, name);
+	  res = XMALLOC (char,
+			 strlen (path[i-1]) + 2
+			 + strlen (name) + strlen (suffix));
+	  sprintf (res, "%s%c%s%s", path [i-1], DIRECTORY_SEPARATOR,
+		   name, suffix);
+	}
+      else
+	{
+	  res = XMALLOC (char,
+			 strlen (path[i-1]) + 2
+			 + strlen (name));
+	  sprintf (res, "%s%c%s", path [i-1], DIRECTORY_SEPARATOR,
+		   name);
 	}
       return res;
     }
@@ -320,7 +341,7 @@ xpw_find_included_file (char * const *path,
   char *res;
   struct stat statbuf;
 
-  if (*name == DIR_SEP)
+  if (*name == DIRECTORY_SEPARATOR)
     /* Path is absolute */
     dir = NULL;
   else
@@ -331,7 +352,8 @@ xpw_find_included_file (char * const *path,
 		       + strlen (name)
 		       + (suffix ? strlen (suffix) : 0)
 		       + 2));
-  sprintf (res, "%s%c%s%s", dir, DIR_SEP, name, suffix ? suffix : "");
+  sprintf (res, "%s%c%s%s", dir, DIRECTORY_SEPARATOR,
+	   name, suffix ? suffix : "");
   XFREE (dir);
   if (stat (res, &statbuf) == 0)
     return xstrdup (res);
@@ -352,7 +374,8 @@ pw_paste_file (char * const * path,
   FILE * fp;
   int line = 0;
 
-  message (msg_pw, (stderr, "Pasting `%s%s'\n", name, suffix ? suffix : ""));
+  message (msg_pw,
+	   (stderr, "pw: pasting `%s%s'\n", name, suffix ? suffix : ""));
 
   fullpath = _pw_find_file (path, name, suffix);
 
@@ -378,42 +401,83 @@ pw_paste_file (char * const * path,
   while ((fgets (buf, sizeof (buf), fp)))
     {
       line++;
-      if (strnequ (buf, INCL_TAG, strlen (INCL_TAG))) {
-	char * file = buf + strlen (INCL_TAG);
-	file = strtok (file, " \n\t");
-	message (msg_pw,
-		 (stderr,
-		  "Including file '%s' upon request given in '%s':%d\n",
-		  file, fullpath, line));
-	if (!pw_paste_file (path, file, NULL))
-	  error_at_line (1, errno, fullpath, line,
-			 _("cannot find file `%s'"), quotearg (file));
-	continue;
-      }
+      if (strnequ (buf, INCL_TAG, strlen (INCL_TAG)))
+	{
+	  char * file = buf + strlen (INCL_TAG);
+	  file = strtok (file, " \n\t");
+	  message (msg_pw,
+		   (stderr,
+		    "pw: including file '%s' upon request given in '%s':%d\n",
+		    file, fullpath, line));
+	  if (!pw_paste_file (path, file, NULL))
+	    error_at_line (1, errno, fullpath, line,
+			   _("cannot find file `%s'"), quotearg (file));
+	  continue;
+	}
       fputs (buf, stdout);
     }
 
   fclose (fp);
-  FREE (fullpath);
+  free (fullpath);
   return 1;
 }
 
-/*
- * Call glob on PATTERN in each dir of PATH.
- * Return a malloc'd char ** (char * malloc'ed too)
- */
+/* Helping functions for pw_glob. */
+
+static bool
+pw_filter_fnmatch (PARAM_UNUSED const char * dir, const char *file,
+		   const char *pattern)
+{
+  return !fnmatch (pattern, file, 0);
+}
+
+static void
+pw_filter_da_append (PARAM_UNUSED const char * dir, const char *file,
+		     struct darray *da)
+{
+  da_append (da, xstrdup (file));
+}
+
+static void
+pw_filter_print (const char * dir, const char *file, FILE *stream)
+{
+  fprintf (stream, "%s%c%s\n", dir, DIRECTORY_SEPARATOR, file);
+}
+
+static void
+pw_filterdir (char * const * path,
+	      filterdir_filter_t filter, void *filtarg,
+	      filterdir_fun_t fun, void *arg)
+{
+  for (/* Nothing */ ; *path ; path++)
+    filterdir (*path, filter, filtarg, fun, arg);
+}
+
+
+/*------------------------------------------------------------------.
+| Call glob on PATTERN in each dir of PATH.  Return a malloc'd char |
+| ** (char * malloc'ed too).                                        |
+`------------------------------------------------------------------*/
+
 struct darray *
 pw_glob (char * const * path, const char * pattern)
 {
   struct darray * res;
 
+  if (msg_test (msg_pw))
+    {
+      fprintf  (stderr, "pw: globbing `%s'\n", pattern);
+      pw_fprintf_path (stderr, "\t-> %s\n", path);
+    }
+
   res = da_new ("Dir entries", 20,
 		da_geometrical, 2,
 		(da_print_func_t) da_str_print,
 		(da_cmp_func_t) strverscmp);
 
-  for (/* Nothing */ ; *path ; path++)
-    filterdir_pattern (*path, res, pattern);
+  pw_filterdir (path,
+		(filterdir_filter_t) pw_filter_fnmatch, (void *) pattern,
+		(filterdir_fun_t) pw_filter_da_append, res);
 
   da_qsort (res);
   da_unique (res, (da_map_func_t) free);
@@ -421,19 +485,29 @@ pw_glob (char * const * path, const char * pattern)
   return res;
 }
 
+void
+pw_glob_print (char * const * path, const char * pattern, FILE *stream)
+{
+  pw_filterdir (path,
+		(filterdir_filter_t) pw_filter_fnmatch, (void *) pattern,
+		(filterdir_fun_t) pw_filter_print, stream);
+}
+
 /*
  * Cut the suffix of a string (i.e. cut at last `.')
  */
+
 static void
 da_str_cut_suffix (char * string)
 {
   *strrchr (string, '.') = '\0';
 }
 
-/*
- * Return malloc'd array of malloc'ed char *
- * of the prefix part of the file having SUFFIX as suffix in PATH
- */
+/*----------------------------------------------------------------.
+| Return malloc'd array of malloc'ed char * of the prefix part of |
+| the file having SUFFIX as suffix in PATH.                       |
+`----------------------------------------------------------------*/
+
 struct darray *
 pw_glob_on_suffix (char * const * path, const char * suffix)
 {
