@@ -70,4 +70,4 @@ void _a2ps_ppd_list_long PARAMS ((char * const * path, FILE * stream));
 struct ppd * a2ps_ppd_parse
    PARAMS ((const char * filename, char * const *path));
 
-#endif /* !defined(_PPD_H) */
+#endif /* !defined(PPD_H_) */
