@@ -51,7 +51,7 @@ struct interval
 static struct interval *
 interval_new (int min, int max)
 {
-  struct interval * res = ALLOC (struct interval, 1);
+  struct interval * res = XMALLOC (struct interval, 1);
   res->min = min;
   res->max = max;
   return res;
@@ -127,12 +127,12 @@ interval_applies_above (struct interval * interval, int offset)
 {
   if (interval->min <= offset && interval->max == 0)
     /* offset \in [min,-]: all should be printed */
-    return FALSE;
+    return false;
 /*
   if (interval->min <= offset && offset <= interval->max)
-    return FALSE;
+    return false;
   */
-  return TRUE;
+  return true;
 }
 
 /************************************************************************/
@@ -141,7 +141,7 @@ interval_applies_above (struct interval * interval, int offset)
 /************************************************************************/
 struct page_range {
   struct darray * intervals;	/* list of the intervals to print	*/
-  boolean toc;			/* if true, only the toc is printed	*/
+  bool toc;			/* if true, only the toc is printed	*/
 };
 
 /*
@@ -164,7 +164,7 @@ void
 page_range_free (struct page_range * page_range)
 {
   da_free (page_range->intervals, (da_map_func_t) free);
-  FREE (page_range);
+  free (page_range);
 }
 
 /*
@@ -200,10 +200,10 @@ add_pages_interval (struct a2ps_job * job, int min, int max)
    * otherwise, max := size
    */
   if (max && (max < min))
-    return FALSE;
+    return false;
 
   da_append (job->page_range->intervals, interval_new (min, max));
-  return TRUE;
+  return true;
 }
 
 /*
@@ -215,7 +215,7 @@ void
 page_range_to_buffer (struct page_range * page_range, uchar * buf, int offset)
 {
   size_t i;
-  int put_a_comma = FALSE;
+  int put_a_comma = false;
   struct interval ** intervals =
     (struct interval **) page_range->intervals->content;
 
@@ -225,7 +225,7 @@ page_range_to_buffer (struct page_range * page_range, uchar * buf, int offset)
 	if (put_a_comma)
 	  *buf++ = ',';
 	buf = interval_to_buffer (intervals [i], buf, offset);
-	put_a_comma = TRUE;
+	put_a_comma = true;
       }
 }
 
@@ -242,15 +242,15 @@ page_range_applies_above (struct page_range * page_range, int offset)
     (struct interval **) page_range->intervals->content;
 
   if (page_range->intervals->len == 0)
-    return FALSE;
+    return false;
 
   for (i = 0 ; i < page_range->intervals->len ; i++)
     if (intervals [i]->min < offset
 	&& intervals [i]->max == 0)
       /* offset \in [min,-]: all should be printed */
-      return FALSE;
+      return false;
 
-  return TRUE;
+  return true;
 }
 
 /************************************************************************/
@@ -334,7 +334,7 @@ report_pages_to_print (struct a2ps_job * job, FILE * stream)
 }
 
 /*
- * Return TRUE if the page PAGE_NUM is to be printed
+ * Return true if the page PAGE_NUM is to be printed
  */
 int
 print_page (struct a2ps_job * job, int page_num)
@@ -347,16 +347,16 @@ print_page (struct a2ps_job * job, int page_num)
    * of having JOB to see if the current file is the toc.
    * It is not very clean, but it's really simple */
   if (job->page_range->toc && CURRENT_FILE (job)->is_toc)
-    return TRUE;
+    return true;
 
   /* If no page range where ever specified (not even toc), then
    * any page is to be printed */
   if (job->page_range->intervals->len == 0 && !job->page_range->toc)
-    return TRUE;
+    return true;
 
   for (i = 0 ; i < job->page_range->intervals->len  ; i++)
     if (interval_is_in (intervals [i], page_num))
-      return TRUE;
+      return true;
 
-  return FALSE;
+  return false;
 }
