@@ -157,13 +157,14 @@ printer_free (struct printer * printer)
 static void
 printer_self_print (struct printer * printer, FILE * stream)
 {
+  fputs ("- ", stream);
   fputs (printer->key, stream);
   if (printer->ppdkey)
     fprintf (stream, " (PPD: %s)", printer->ppdkey);
+  putc ('\n', stream);
 
   if (printer->command)
-    fprintf (stream, "\n\t%s", printer->command);
-  putc ('\n', stream);
+    fprintf (stream, "  %s\n", printer->command);
 }
 
 
@@ -193,7 +194,7 @@ static inline void
 printer_table_free (struct printer_table * table)
 {
   hash_free (table, (hash_map_func_t) printer_free);
-  FREE (table);
+  free (table);
 }
 
 /* Return the printer corresponding to KEY in TABLE if exist,
@@ -228,33 +229,6 @@ printer_table_add (struct printer_table * table,
   hash_insert (table, printer);
 }
 
-/* Resolves Default and Unknown printers.  */
-static inline struct printer *
-printer_table_get (struct printer_table *table, const char *key)
-{
-  struct printer * item;
-
-  /* Is this the default printer? */
-  if (IS_EMPTY (key))
-    {
-      item = printer_table_find (table, DEFAULT_PRINTER);
-      if (!item)
-	error (1, 0, _("no default command for option `-d'"));
-      return item;
-    }
-
-  /* Is this a known printer? */
-  item = printer_table_find (table, key);
-  if (item)
-    return item;
-
-  /* It is the unknown printer. */
-  item = printer_table_find (table, UNKNOWN_PRINTER);
-  if (!item)
-    error (1, 0, _("no default command for unknown printer `%s'"), key);
-  return item;
-}
-
 /*
  * Report content (short form)
  */
@@ -276,7 +250,7 @@ printer_table_short_self_print (struct printer_table * table, FILE * stream)
 			  (lister_width_t) printer_key_len,
 			  (lister_print_t) printer_key_fputs);
 
-  FREE (entries);
+  free (entries);
 }
 
 /*
@@ -310,11 +284,11 @@ struct a2ps_printers_s
   /* Selected destination.  */
 
   /* FLAGS values correspond to the choice of the user. */
-  boolean flag_output_is_printer;	/* ? -P : -o. */
+  bool flag_output_is_printer;	/* ? -P : -o. */
   char *flag_output_name;		/* Arg to -P or -o. */
 
   /* These values correspond to what has really happened. */
-  boolean output_is_file;	/* -o, or -P on a saving printer. */
+  bool output_is_file;	/* -o, or -P on a saving printer. */
   /* If OUTPUT_IS_FILE, the file name, else the printer name. */
   char *output_name;
 };
@@ -372,7 +346,7 @@ a2ps_printers_free (struct a2ps_printers_s * printers)
   XFREE (printers->flag_output_name);
   XFREE (printers->output_name);
 
-  FREE (printers);
+  free (printers);
 }
 
 
@@ -412,7 +386,17 @@ a2ps_printers_command_get (struct a2ps_printers_s *printers,
 
   /* If key is empty, it's the default printer (user used `-d'). */
   if (!key)
-    return printers->default_printer.command;
+    {
+      if (!printers->default_printer.command)
+	/* TRANS: The first `%s' is typically the name of the printer
+	   (default or unknown), while the last two strings expand
+	   into the options that caused the message (i.e., "-d" "" in
+	   the case of the default printer).  */
+	error (1, 0,
+	       _("no command for the `%s' (%s%s)"),
+	       DEFAULT_PRINTER, "-d", "");
+      return printers->default_printer.command;
+    }
 
   /* The printer has name: user used `-P'. */
   printer = printer_table_find (printers->printers, key);
@@ -423,13 +407,19 @@ a2ps_printers_command_get (struct a2ps_printers_s *printers,
 
   /* Printer is either unknown or has no command (used when Printer:
      introduces only the PPD). */
+  if (!printers->unknown_printer.command)
+    {
+      error (1, 0,
+	     _("no command for the `%s' (%s%s)"),
+	     UNKNOWN_PRINTER, "-P ", key);
+    }
   return printers->unknown_printer.command;
 }
 
 /* Make a standard message upon the destination.  Mallocs the
    result.  If FILE_P, NAME is a file name, else a printer name. */
 static uchar*
-destination_to_string (const char *name, boolean file_p)
+destination_to_string (const char *name, bool file_p)
 {
   uchar *res;
 
@@ -444,7 +434,7 @@ destination_to_string (const char *name, boolean file_p)
       char *format = (file_p
 		      ? _("saved into the file `%s'")
 		      : _("sent to the printer `%s'"));
-      res = ALLOC (uchar, strlen (format) + strlen (name));
+      res = XMALLOC (uchar, strlen (format) + strlen (name));
       sprintf ((char *) res, format, name);
     }
   return res;
@@ -503,7 +493,7 @@ a2ps_printers_finalize (struct a2ps_printers_s * printers)
 /*
  * Record a printer defined by the config line "Printer:"
  */
-boolean
+bool
 a2ps_printers_add (struct a2ps_printers_s * printers,
 		   const char * key, char * definition)
 {
@@ -578,7 +568,7 @@ a2ps_printers_request_ppdkey_set (struct a2ps_printers_s * printers,
 void
 a2ps_printers_flag_output_set (struct a2ps_printers_s * printers,
 			       const char * flag_output_name,
-			       boolean is_printer)
+			       bool is_printer)
 {
   printers->flag_output_is_printer = is_printer;
 
@@ -598,7 +588,7 @@ a2ps_printers_flag_output_name_get (struct a2ps_printers_s * printers)
   return (const char *) printers->flag_output_name;
 }
 
-boolean
+bool
 a2ps_printers_flag_output_is_printer_get (struct a2ps_printers_s * printers)
 {
   return printers->flag_output_is_printer;
@@ -655,25 +645,28 @@ a2ps_open_output_stream (struct a2ps_job * job)
 {
   struct a2ps_printers_s *printers = job->printers;
 
-  /* Open the destination */
+  /* Open the destination. */
+
   if (!printers->flag_output_is_printer)
     {
       /* -o (can be stdout) */
       job->output_stream = stream_wopen_backup (printers->flag_output_name,
-						TRUE,
+						true,
 						job->backup_type);
-      /* flag_output_name can be NULL. */
+      /* FLAG_OUTPUT_NAME can be NULL. */
       xstrcpy (printers->output_name, printers->flag_output_name);
       printers->output_is_file = true;
     }
   else
     {
+      /* -P (or -d if NAME is NULL. */
       const char *name;
       const char *command, *printer_cmd;
 
       /* Open an output stream onto PRINTER */
       printer_cmd = a2ps_printers_command_get (printers,
 					       printers->flag_output_name);
+
       /* Expand the metaseq before */
       command = (char *) expand_user_string (job, FIRST_FILE (job),
 					     (uchar *) "output command",
