@@ -86,7 +86,7 @@ void a2ps_printers_request_ppdkey_set
    PARAMS ((struct a2ps_printers_s * printers,
 	    const char * key));
 
-boolean a2ps_printers_add
+bool a2ps_printers_add
    PARAMS ((struct a2ps_printers_s * printers,
 	    const char * key, char * definition));
 
@@ -100,10 +100,10 @@ int a2ps_printers_font_known_p
  */
 void a2ps_printers_flag_output_set
     PARAMS ((struct a2ps_printers_s * printers,
-	     const char * output_name, boolean is_printer));
+	     const char * output_name, bool is_printer));
 const char * a2ps_printers_flag_output_name_get
     PARAMS ((struct a2ps_printers_s * printers));
-boolean a2ps_printers_flag_output_is_printer_get
+bool a2ps_printers_flag_output_is_printer_get
     PARAMS ((struct a2ps_printers_s * printers));
 
 #endif /* !defined (PRINTERS_H_) */
