@@ -21,15 +21,9 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
   before use it!
 */
 
-#ifdef HAVE_CONFIG_H
-# include <config.h>
-#endif
-
+#include "system.h"
 #include "printlen.h"
 
-#include <stdio.h>
-#include <xstring.h>
-
 
 unsigned long strtoul ();
 
