@@ -112,7 +112,7 @@ prologue_print_signature (struct a2ps_job * job,
   FILE * fp;
   char * filename;
   char * buf = NULL;
-  int done = FALSE;
+  int done = false;
   int firstline = 0, lastline = 0;
   size_t bufsiz = 0;
   char buf2[BUFSIZ];
@@ -144,14 +144,14 @@ prologue_print_signature (struct a2ps_job * job,
 	  if (!strprefix (END_DOC_TAG, buf2))
 	    error (1, 0, filename, firstline,
 		   _("missing argument for `%s'"), "`Documentation'");
-	  done = TRUE;
+	  done = true;
 	}
     }
   putc ('\n', stream);
 
   free (buf);
   fclose (fp);
-  FREE (filename);
+  free (filename);
 }
 
 /*
@@ -258,15 +258,9 @@ dump_prolog_comments (FILE * stream, struct a2ps_job * job)
   fputs ("%%EndComments\n", stream);
 
   /* This is mostly useful wrt users who are not able to say exactely
-   * what they did. */
-  if (job->debug) {
-    fputs ((char *) expand_user_string (job, CURRENT_FILE (job),
-			     (const uchar *) "Debugging info",
-			     (const uchar *) "%%%V was called with #!$|| |\n"),
-	   stream);
-    if (ps_comment_hook)
-      ps_comment_hook (job, stream);
-  }
+     what they did.  */
+  if (ps_comment_hook)
+    ps_comment_hook (job, stream);
 }
 
 /*
@@ -325,28 +319,29 @@ output_document_setup (a2ps_job * job)
 
   /* Complete the prolog with static variables */
   output (jdiv, "%% Initialize page description variables.\n");
-  switch (job->orientation) {
-  case portrait:
-    /* FIXME: prendre en compte les marges */
-    output (jdiv, "/sh %d def\n", job->medium->h);
-    output (jdiv, "/sw %d def\n", job->medium->w);
-    output (jdiv, "/llx %d def\n", job->medium->llx);
-    output (jdiv, "/urx %d def\n", job->medium->urx - job->margin);
-    output (jdiv, "/ury %d def\n", job->medium->ury);
-    output (jdiv, "/lly %d def\n", job->medium->lly);
-    break;
+  switch (job->orientation)
+    {
+    case portrait:
+      /* FIXME: prendre en compte les marges */
+      output (jdiv, "/sh %d def\n", job->medium->h);
+      output (jdiv, "/sw %d def\n", job->medium->w);
+      output (jdiv, "/llx %d def\n", job->medium->llx);
+      output (jdiv, "/urx %d def\n", job->medium->urx - job->margin);
+      output (jdiv, "/ury %d def\n", job->medium->ury);
+      output (jdiv, "/lly %d def\n", job->medium->lly);
+      break;
 
-  case landscape:
-    output (jdiv, "/sh %d def\n", job->medium->w);
-    output (jdiv, "/sw %d def\n", job->medium->h);
-    output (jdiv, "/llx %d def\n", job->medium->lly);
-    output (jdiv, "/urx %d def\n", job->medium->ury);
-    output (jdiv, "/ury %d def\n",
-	    job->medium->w - job->medium->llx);
-    output (jdiv, "/lly %d def\n",
-	    job->medium->w - job->medium->urx + job->margin);
-    break;
-  }
+    case landscape:
+      output (jdiv, "/sh %d def\n", job->medium->w);
+      output (jdiv, "/sw %d def\n", job->medium->h);
+      output (jdiv, "/llx %d def\n", job->medium->lly);
+      output (jdiv, "/urx %d def\n", job->medium->ury);
+      output (jdiv, "/ury %d def\n",
+	      job->medium->w - job->medium->llx);
+      output (jdiv, "/lly %d def\n",
+	      job->medium->w - job->medium->urx + job->margin);
+      break;
+    }
 
   /* Misceleanous PostScript variables */
   output (jdiv, "/#copies %d def\n", job->copies);
@@ -479,9 +474,11 @@ end_document (a2ps_job * job)
 {
   page_flush (job);
   output (jdiv, "\n%%%%Trailer\n");
+
   if (job->page_prefeed)
     output (jdiv, "false page_prefeed\n");
-  /* Close a2ps dict */
+
+  /* Close a2ps dict. */
   output (jdiv, "end\n");
   output (jdiv, "%%%%EOF\n");
 }
@@ -607,7 +604,7 @@ ps_end (a2ps_job * job)
 /* Make sure that the output is really processed.  It
    * could have been closed by a page range selection, but
    * the trailer must be dumped */
-  output_to_void (job->divertion, FALSE);
+  output_to_void (job->divertion, false);
 
   /* Close the postscript file */
   end_document (job);
