@@ -230,7 +230,7 @@ output_marker (a2ps_job * job, const char * kind, uchar * marker)
       output_delayed_int (jdiv, &job->total_files);
       break;
     default:
-      *buf = NUL;
+      *buf = '\0';
       ps_escape_char (job, cp[i], buf);
       output (jdiv, (char *) buf);
       break;
@@ -289,7 +289,7 @@ ps_internal_switch_encoding (a2ps_job * job, struct encoding * enc)
       set_encoding (job, enc);
     }
     /* Make sure to re-declare the font */
-    job->status->face_declared = FALSE;
+    job->status->face_declared = false;
   }
 }
 
@@ -358,7 +358,7 @@ page_begin (a2ps_job * job)
   if (!output_is_to_void (jdiv))
     {
       output (jdiv, "%%%%Page: (");
-      job->status->page_label = ALLOC (uchar *, 1);
+      job->status->page_label = XMALLOC (uchar *, 1);
       output_delayed_string (jdiv, job->status->page_label);
       output (jdiv, ") %d\n", job->sheets);
     }
@@ -394,15 +394,16 @@ page_begin (a2ps_job * job)
   ps_set_encoding (job, job->requested_encoding);
 
   /* water marks (only once per sheet) */
-  if (!IS_EMPTY(job->water)) {
-    output_char (jdiv, '(');
-    output_marker (job, "water mark", job->water);
-    output (jdiv,
-	    ") %4.2f water\n",
-	    ((float) atan2 ((double) job->medium->w - job->margin,
-			    (double) job->medium->h)
-	     / 3.14159265 * 180));
-  }
+  if (!IS_EMPTY(job->water))
+    {
+      output_char (jdiv, '(');
+      output_marker (job, "water mark", job->water);
+      output (jdiv,
+	      ") %4.2f water\n",
+	      ((float) atan2 ((double) job->medium->w - job->margin,
+			      (double) job->medium->h)
+	       / 3.14159265 * 180));
+    }
 
   /* Move to the lower left point of the drawable area */
   output (jdiv, "gsave\n");
@@ -490,10 +491,10 @@ virtual_begin (a2ps_job * job)
   job->pages++;
 
   if (print_page (job, job->pages)) {
-    output_to_void (jdiv, FALSE);
+    output_to_void (jdiv, false);
     job->virtual++;
   } else {
-    output_to_void (jdiv, TRUE);
+    output_to_void (jdiv, true);
   }
 
   /* We test to one, since it has just been incremented above */
@@ -595,7 +596,7 @@ void
 page_flush (a2ps_job * job)
 {
   /* Everything that follows _must_ be dumped */
-  output_to_void (job->divertion, FALSE);
+  output_to_void (job->divertion, false);
 
   /* If the sheet has not been printed, flush it */
   if (job->virtual != 0)
@@ -668,7 +669,7 @@ end_of_line (struct a2ps_job * job)
 {
   if (!job->status->face_declared) {
     output (jdiv, ") %s n\n", face_eo_ps (job->status->face));
-    job->status->face_declared = TRUE;
+    job->status->face_declared = true;
   } else
     output (jdiv, ") N\n");
   job->status->line++;
@@ -687,12 +688,13 @@ end_of_line (struct a2ps_job * job)
 static inline void
 fold_line (struct a2ps_job * job, enum face_e new_face)
 {
+  job->lines_folded++;
   end_of_line (job);
   if (page_full)
     {
       virtual_end (job);
       virtual_begin (job);
-      job->status->face_declared = FALSE ;
+      job->status->face_declared = false ;
     }
   if (job->numbering)
     {
@@ -735,7 +737,7 @@ ps_print_char (a2ps_job * job, int c, enum face_e new_face)
       && (c != encodings[job->encoding].new_line))*/
       && (c != '\n'))
     return;
-  job->status->is_in_cut = FALSE;
+  job->status->is_in_cut = false;
 
   /* Start a new line ? */
   if (job->status->start_line)
@@ -744,11 +746,11 @@ ps_print_char (a2ps_job * job, int c, enum face_e new_face)
 	{
 	  /* only if there is something to print! */
 	  virtual_begin (job);
-	  job->status->start_page = FALSE ;
+	  job->status->start_page = false ;
 	  /* This is the first line of a new page, hence we need (page
 	   * independance) to repeat the current font */
 	  job->status->face = new_face;
-	  job->status->face_declared = FALSE;
+	  job->status->face_declared = false;
 
 	  if (job->numbering)
 	    {
@@ -783,7 +785,7 @@ ps_print_char (a2ps_job * job, int c, enum face_e new_face)
 	      job->status->face = new_face;
 	    }
 	}
-      job->status->start_line = FALSE;
+      job->status->start_line = false;
     }
 
   /*
@@ -802,7 +804,7 @@ ps_print_char (a2ps_job * job, int c, enum face_e new_face)
     if (!job->status->start_line)
       {
 	end_of_line (job);
-	job->status->start_line = TRUE;
+	job->status->start_line = true;
       }
     /* start a new page ? */
     if (job->status->start_page)
@@ -811,7 +813,7 @@ ps_print_char (a2ps_job * job, int c, enum face_e new_face)
       }
     /* Close current page and begin another */
     virtual_end (job);
-    job->status->start_page = TRUE;
+    job->status->start_page = true;
     break;
 
   case '\n':
@@ -824,12 +826,12 @@ ps_print_char (a2ps_job * job, int c, enum face_e new_face)
       goto print;
 #endif
     (CURRENT_FILE (job))->lines++;
-    job->status->start_line = TRUE;
+    job->status->start_line = true;
     end_of_line (job);
 
     if (page_full) {
       virtual_end (job);
-      job->status->start_page = TRUE ;
+      job->status->start_page = true ;
     }
     break;
 
@@ -844,7 +846,7 @@ ps_print_char (a2ps_job * job, int c, enum face_e new_face)
       else
 	output (jdiv, ") S\n(");
       job->status->face = new_face;
-      job->status->face_declared = FALSE;
+      job->status->face_declared = false;
     }
 
     /* Tabs are interpreted  but we want to go to the same
@@ -858,14 +860,14 @@ ps_print_char (a2ps_job * job, int c, enum face_e new_face)
       if (job->folding) {
 	fold_line (job, new_face);
       } else {
-	job->status->is_in_cut = TRUE;
+	job->status->is_in_cut = true;
 	return;
       }
     }
     /* Make sure that the font is given */
     if (!job->status->face_declared) {
       output (jdiv, ") %s", face_eo_ps(job->status->face));
-      job->status->face_declared = TRUE;
+      job->status->face_declared = true;
     } else
       output (jdiv, ") S");
     output (jdiv, " %d T (", job->status->column);
@@ -884,7 +886,7 @@ ps_print_char (a2ps_job * job, int c, enum face_e new_face)
     else
       output (jdiv, ") S\n(");
     job->status->face = new_face;
-    job->status->face_declared = FALSE;
+    job->status->face_declared = false;
   }
 
       nchars = ps_escape_char (job, c, buf);
@@ -896,7 +898,7 @@ ps_print_char (a2ps_job * job, int c, enum face_e new_face)
 	  job->status->column = nchars;
 	  job->status->wx = char_WX (job, c);
 	} else {
-	  job->status->is_in_cut = TRUE;
+	  job->status->is_in_cut = true;
 	  return;
 	}
       }
