@@ -42,9 +42,9 @@ string_to_array (uchar arr[256], const uchar * string)
   int c;
 
   for (c = 0 ; c < 256 ; c++)
-    arr [c] = FALSE;
+    arr [c] = false;
   for ( /* nothing */ ; *string ; string ++)
-    arr [*string] = TRUE;
+    arr [*string] = true;
 }
 
 /*
@@ -59,46 +59,53 @@ ustrccat (uchar * string, uchar c)
 }
 
 /*
- * return TRUE iff there are no upper case chars
+ * return true iff there are no upper case chars
  */
 int
 is_strlower (const uchar * string)
 {
-  for (/* skip */; *string != NUL; string++)
+  for (/* skip */; *string != '\0'; string++)
     if (isupper(*string))
-      return FALSE;
-  return TRUE;
+      return false;
+  return true;
 }
 
-/*
- * Change the value of STRING into lower case
- */
-static inline char *
-_strnlower (char * string, size_t len)
+/* Copy the LEN first characters of SRC into DST in lower case.
+   DST[LEN] is set to \0.  */
+
+static inline uchar *
+_strncpylc (uchar *dst, const uchar *src, size_t len)
 {
   size_t i;
-  for (i=0 ; i < len ; i++)
-    string [i] = tolower (string [i]);
-  return string;
+  for (i = 0 ; i < len ; i++)
+    dst[i] = tolower (src[i]);
+  dst[len] = '\0';
+  return dst;
 }
 
-char *
-strnlower (char * string, size_t len)
+uchar *
+strnlower (uchar *string, size_t len)
 {
-  return _strnlower (string, len);
+  return _strncpylc (string, string, len);
 }
 
-char *
-strlower (char * string)
+uchar *
+strlower (uchar *string)
 {
-  return _strnlower (string, strlen (string));
+  return _strncpylc (string, string, strlen (string));
+}
+
+uchar *
+strcpylc (uchar *dst, const uchar *src)
+{
+  return _strncpylc (dst, src, strlen (src));
 }
 
 /*
  * Count the number of occurrence of C in S
  */
 int
-strcnt (uchar * s, uchar c)
+strcnt (uchar *s, uchar c)
 {
   int res;
   for (res = 0 ; *s ; s++)
