@@ -1,10 +1,6 @@
 /*
- * routines.h
- *
- * general use routines
- * Copyright (c) 1988-1993 Miguel Santana
+ * routines.h -- general use routines
  * Copyright (c) 1995-1999 Akim Demaille, Miguel Santana
- * $Id$
  */
 
 /*
@@ -27,8 +23,7 @@
  */
 
 #ifndef _ROUTINES_H_
-#define _ROUTINES_H_
-#include "xalloca.h"
+# define _ROUTINES_H_
 
 /*
  * From xgetcwd.c
@@ -40,8 +35,8 @@ char *xgetcwd PARAMS ((void));
  */
 char *xgethostname PARAMS ((void));
 
-char * stpcpy PARAMS ((char * dest, const char * src));
-char * stpncpy PARAMS ((char * dest, const char * src, size_t n));
+char *stpcpy PARAMS ((char * dest, const char * src));
+char *stpncpy PARAMS ((char * dest, const char * src, size_t n));
 
 /*
  * unsigned char variation of usual functions on strings
@@ -50,7 +45,7 @@ char * stpncpy PARAMS ((char * dest, const char * src, size_t n));
 	(strcat((char *)(x), (const char *)(y)))
 
 #define ustrncat(x,y,n)	\
-	do {strncat(((char *)x), (const char *) y, n); } while (0)
+	(strncat(((char *)x), (const char *) y, n))
 
 #define ustrcpy(x,y) 					\
 	(strcpy((char *)(x), (const char *)(y)))
@@ -143,7 +138,7 @@ char * stpncpy PARAMS ((char * dest, const char * src, size_t n));
     char * __strcut_cp;				\
     __strcut_cp = strchr (_string_, _char_);	\
     if (__strcut_cp)				\
-      *__strcut_cp = NUL;			\
+      *__strcut_cp = '\0';			\
   } while (0)
 
 #define ustrcut(_ustring_, _uchar_)	\
@@ -157,7 +152,7 @@ char * stpncpy PARAMS ((char * dest, const char * src, size_t n));
     char * __strrcut_cp;			\
     __strrcut_cp = strrchr (_string_, _char_);	\
     if (__strrcut_cp)				\
-      *__strrcut_cp = NUL;			\
+      *__strrcut_cp = '\0';			\
   } while (0)
 
 #define ustrrcut(_ustring_, _uchar_)	\
@@ -211,13 +206,13 @@ char * stpncpy PARAMS ((char * dest, const char * src, size_t n));
   do { int __len = strlen((const char *)s);		\
        *(s+__len) = c;					\
        *(s+__len+1) = '\0'; 				\
-  } while (FALSE)
+  } while (false)
 
 
 #define IS_BETWEEN(x, min, max) (((min) <= (x)) && ((x) <= (max)))
 
 #define IS_EMPTY(s1)	\
-	(((const char *) (s1) == NULL) || (*(s1) == NUL))
+	(((const char *) (s1) == NULL) || (*(s1) == '\0'))
 #define UNNULL(s1)	\
  ((((void const *) s1) == NULL) ? (const char *) "" : (const char *) (s1))
 #define ustrequ(s1, s2) (!ustrcmp(s1, s2))
@@ -226,8 +221,9 @@ char * stpncpy PARAMS ((char * dest, const char * src, size_t n));
 /* Functions on strings */
 void string_to_array PARAMS ((uchar arr[256], const uchar * string));
 int is_strlower PARAMS((const uchar * string));
-char * strnlower PARAMS ((char * string, size_t len));
-char * strlower PARAMS ((char * string));
+uchar *strnlower PARAMS ((uchar * string, size_t len));
+uchar *strlower PARAMS ((uchar * string));
+uchar *strcpylc PARAMS ((uchar *dst, const uchar *src));
 
 void ustrccat PARAMS((uchar * string, uchar c));
 int strcnt PARAMS((uchar * s, uchar c));
@@ -257,9 +253,9 @@ FILE * xrpopen PARAMS ((const char * command));
 FILE * xwpopen PARAMS ((const char * command));
 
 /* If _STR_ is not defined, give it a tempname in _TMPDIR_ */
-#define tempname_ensure(_str_, _tmpdir_)			\
-do {								\
-  (_str_) = (_str_) ? (_str_) : tempnam (_tmpdir_, "a2_");	\
+#define tempname_ensure(Str)				\
+do {							\
+  (Str) = (Str) ? (Str) : tempnam (NULL, "a2_");	\
 } while (0)
 
 #endif
