@@ -24,7 +24,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 #endif
 
 #ifndef PARAMS
-# if defined (__GNUC__) || __STDC__
+# if PROTOTYPES || (defined (__STDC__) && __STDC__)
 #  define PARAMS(args) args
 # else
 #  define PARAMS(args) ()
