@@ -1,4 +1,4 @@
-/* Copyright (C) 1991,92,93,94,95,96,97,98 Free Software Foundation, Inc.
+/* Copyright (C) 1991,92,93,94,95,96,97,98,99 Free Software Foundation, Inc.
 
    NOTE: The canonical source of this file is maintained with the GNU C Library.
    Bugs can be reported to bug-glibc@prep.ai.mit.edu.
@@ -10,8 +10,8 @@
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Library General Public License for more details.
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
@@ -100,7 +100,7 @@ extern char *tzname[];
 #endif
 
 #ifndef __P
-# if defined (__GNUC__) || (defined (__STDC__) && __STDC__)
+# if defined __GNUC__ || (defined __STDC__ && __STDC__)
 #  define __P(args) args
 # else
 #  define __P(args) ()
@@ -493,7 +493,7 @@ my_strftime (char *s, size_t maxsize, const char *format, const struct tm *tp
 	case '%':
 	  break;
 
-	case '\a': case '\b': case '\t': case '\n':
+	case '\b': case '\t': case '\n':
 	case '\v': case '\f': case '\r':
 	case ' ': case '!': case '"': case '#': case '&': case'\'':
 	case '(': case ')': case '*': case '+': case ',': case '-':
@@ -511,10 +511,11 @@ my_strftime (char *s, size_t maxsize, const char *format, const struct tm *tp
 	case 'r': case 's': case 't': case 'u': case 'v': case 'w':
 	case 'x': case 'y': case 'z': case '{': case '|': case '}':
 	case '~':
-	  /* The C Standard requires these 98 characters (plus '%') to
+	  /* The C Standard requires these 97 characters (plus '%', '\a') to
 	     be in the basic execution character set.  None of these
 	     characters can start a multibyte sequence, so they need
-	     not be analyzed further.  */
+	     not be analyzed further.  Some old compilers object to
+	     '\a', so don't bother optimizing for it.  */
 	  add (1, *p = *f);
 	  continue;
 
@@ -1025,7 +1026,6 @@ my_strftime (char *s, size_t maxsize, const char *format, const struct tm *tp
 	  add (1, *p = '\t');
 	  break;
 
-	case 'f':
 	case 'u':		/* POSIX.2 extension.  */
 	  DO_NUMBER (1, (tp->tm_wday - 1 + 7) % 7 + 1);
 
@@ -1220,7 +1220,7 @@ my_strftime (char *s, size_t maxsize, const char *format, const struct tm *tp
 	}
     }
 
-  if (p && i < maxsize)
+  if (p && maxsize != 0)
     *p = '\0';
   return i;
 }
