@@ -16,13 +16,45 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-/* 
+/*
  * Note:
  * very strong inspiration was taken in error.[ch] by
  * David MacKenzie <djm@gnu.ai.mit.edu>
  */
 
 /* Get prototypes for the functions defined here.  */
+#if HAVE_CONFIG_H
+# include <config.h>
+#endif
+
+#include <stdio.h>
+
+#if HAVE_VPRINTF || HAVE_DOPRNT || _LIBC
+# if __STDC__
+#  include <stdarg.h>
+#  define VA_START(args, lastarg) va_start(args, lastarg)
+# else
+#  include <varargs.h>
+#  define VA_START(args, lastarg) va_start(args)
+# endif
+#else
+# define va_alist a1, a2, a3, a4, a5, a6, a7, a8
+# define va_dcl char *a1, *a2, *a3, *a4, *a5, *a6, *a7, *a8;
+#endif
+
+# ifndef __attribute__
+/* This feature is available in gcc versions 2.5 and later.  */
+#  if __GNUC__ < 2 || (__GNUC__ == 2 && __GNUC_MINOR__ < 5) || __STRICT_ANSI__
+#   define __attribute__(Spec) /* empty */
+#  endif
+/* The __-protected variants of `format' and `printf' attributes
+   are accepted by gcc versions 2.6.4 (effectively 2.7) and later.  */
+#  if __GNUC__ < 2 || (__GNUC__ == 2 && __GNUC_MINOR__ < 7)
+#   define __format__ format
+#   define __printf__ printf
+#  endif
+# endif
+
 #include "title.h"
 #include "printlen.h"
 
@@ -46,10 +78,10 @@ title (stream, c, center_p, format, va_alist)
 #ifdef VA_START
   va_list args;
 #endif
-  
+
 #ifdef VA_START
   VA_START (args, format);
-  
+
   len = vprintflen (format, args);
   if (format [strlen (format) - 1] == '\n')
     len --;
@@ -77,6 +109,6 @@ title (stream, c, center_p, format, va_alist)
   for (/* nothing */ ; len ; len --)
     putc (c, stream);
   putc ('\n', stream);
-  
+
   fflush (stream);
 }
