@@ -16,7 +16,7 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-/* 
+/*
  * Note:
  * very strong inspiration was taken in error.[ch] by
  * David MacKenzie <djm@gnu.ai.mit.edu>
@@ -25,22 +25,15 @@
 #ifndef _TITLE_H_
 #define _TITLE_H_
 
-#if HAVE_CONFIG_H
-# include <config.h>
-#endif
-
-#include <stdio.h>
-
-#include "xstdarg.h"
-
 # if defined (__STDC__) && __STDC__
 
 /* Print the title TITLE, which is a printf-style
-   format string with optional args if msg_level is bigger than 
+   format string with optional args if msg_level is bigger than
    title_verbosity.*/
 
-extern void title (FILE * stream, char c, const char *format, ...)
-     __attribute__ ((__format__ (__printf__, 3, 4)));
+extern void title (FILE * stream, char c, int center_p,
+		   const char *format, ...)
+     __attribute__ ((__format__ (__printf__, 4, 5)));
 
 # else
 void title ();
