@@ -15,7 +15,17 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-#include "xstrdup.h"
+#if HAVE_CONFIG_H
+# include <config.h>
+#endif
+
+#ifndef PARAMS
+# if defined PROTOTYPES || (defined __STDC__ && __STDC__)
+#  define PARAMS(Args) Args
+# else
+#  define PARAMS(Args) ()
+# endif
+#endif
 
 #if STDC_HEADERS || HAVE_STRING_H
 # include <string.h>
@@ -25,7 +35,7 @@
 
 #include <sys/types.h>
 
-extern void *xmalloc PARAMS ((size_t s));
+char *xmalloc PARAMS ((size_t n));
 
 /* Return a newly allocated copy of STRING.  */
 
@@ -34,3 +44,21 @@ xstrdup (const char *string)
 {
   return strcpy (xmalloc (strlen (string) + 1), string);
 }
+
+/* Return a newly allocated copy of STRING copying at most N
+   characters.  The string is always terminated, and thus is at most
+   N + 1 chars long.  */
+
+char *
+xstrndup (const char *string, size_t n)
+{
+  size_t len = strlen (string);
+  char *res;
+  if (n < len)
+    len = n;
+
+  res = xmalloc (len + 1);
+  strncpy (res, string, len);
+  res[len] = '\0';
+  return res;
+}
