@@ -18,19 +18,26 @@
 
 /* Author: Akim Demaille <demaille@inf.enst.fr> */
 
-#ifndef _XSTRRPL_H_
-#define _XSTRRPL_H_
+#ifndef XSTRRPL_H_
+# define XSTRRPL_H_ 1
+
+# ifndef PARAMS
+#  if defined PROTOTYPES || (defined __STDC__ && __STDC__)
+#   define PARAMS(Args) Args
+#  else
+#   define PARAMS(Args) ()
+#  endif
+# endif
+
+char * xstrrpl PARAMS ((const char * string, const char * subst[][2]));
+void strrpl PARAMS ((char ** string, const char * subst[][2]));
 
 # if defined (__STDC__) && __STDC__
-extern char * xstrrpl (const char * string, const char * subst[][2]);
-extern void strrpl (char ** string, const char * subst[][2]);
 extern char * xvstrrpl (const char * string, ...);
 extern void vstrrpl (char ** string, ...);
 # else
-char * xstrrpl ();
-void strrpl ();
 char * xvstrrpl ();
 void vstrrpl ();
 # endif
 
-#endif
+#endif /* !XSTRRPL_H_ */
