@@ -40,3 +40,5 @@
 #define yygindex ppdyygindex
 #define yytable	 ppdyytable
 #define yycheck	 ppdyycheck
+#define yyname   ppdyyname
+#define yyrule   ppdyyrule
