@@ -2,7 +2,7 @@
  * buffer.c - read line by line with conversion of EOL types
  *
  * Copyright (c) 1988-1993 Miguel Santana
- * Copyright (c) 1995-1999 Akim Demaille, Miguel Santana
+ * Copyright (c) 1995-2000 Akim Demaille, Miguel Santana
  */
 
 /*
@@ -24,10 +24,6 @@
  * Boston, MA 02111-1307, USA.
  */
 
-/*
- * $Id: buffer.c,v 1.77 1998/08/27 09:44:44 demaille Exp $
- */
-
 /* FIXME: There is a case where the behavior is probably wrong: mixed
    string/stream buffers.  It may happen that the last char of the
    string part be a '\n' (or '\r') and buffer wants to see the next
@@ -36,6 +32,9 @@
 
    Currently it does not fetch that next char. */
 
+/* Length of the sample presented to file(1). */
+#define SAMPLE_SIZE 4096
+
 #include "a2ps.h"
 #include "routines.h"
 #include "argmatch.h"
@@ -74,7 +73,7 @@ eol_to_string (enum eol_e eol)
 }
 
 /*
- * What about the booleans
+ * What about the bools
  */
 static const char *const eol_args[] =
 {
@@ -111,7 +110,7 @@ static inline void
 buffer_internal_set (buffer_t * buffer,
 		     FILE * stream,
 		     const uchar * buf, size_t bufsize,
-		     boolean pipe_p, enum eol_e eol)
+		     bool pipe_p, enum eol_e eol)
 {
   buffer->buf = buf;
   buffer->bufsize = bufsize;
@@ -194,13 +193,13 @@ buffer_release (buffer_t * buffer)
 {
   /* VALUE is malloc'd only if BUFFER->LOWER_CASE */
   if (buffer->lower_case)
-    FREE (buffer->value);
+    free (buffer->value);
   /* I don't know how this one should be used */
   /*  obstack_free (&buffer->obstack, NULL); */
 }
 
 void
-buffer_set_lower_case (buffer_t * buffer, boolean sensitive)
+buffer_set_lower_case (buffer_t * buffer, bool sensitive)
 {
   buffer->lower_case = sensitive;
 }
@@ -211,7 +210,7 @@ buffer_set_lower_case (buffer_t * buffer, boolean sensitive)
  *         false if EOF was met before
  */
 
-static inline boolean
+static inline bool
 buffer_stream_get_line (buffer_t * buffer)
 {
   register int c, d;
@@ -308,7 +307,7 @@ buffer_stream_get_line (buffer_t * buffer)
  *         false if EOF (i.e. offset >= bufsize) was met before
  */
 
-static inline boolean
+static inline bool
 buffer_string_get_line (buffer_t * buffer)
 {
   register int c, d;
@@ -402,7 +401,7 @@ buffer_string_get_line (buffer_t * buffer)
 void
 buffer_get (buffer_t * buffer)
 {
-  boolean line_ended_p = false;	/* the line read finishes by eol */
+  bool line_ended_p = false;	/* the line read finishes by eol */
 
   /* If there is something to read from the buffered string, fetch it */
   if (buffer->buf && buffer->bufoffset < buffer->bufsize)
@@ -440,7 +439,7 @@ buffer_get (buffer_t * buffer)
 	buffer->allocsize = buffer->len + 1;
 
       buffer->value =
-	REALLOC (buffer->value, uchar, buffer->allocsize);
+	XREALLOC (buffer->value, uchar, buffer->allocsize);
 
       for (i = 0; i <= buffer->len; i++)
 	buffer->value[i] = tolower (buffer->content[i]);
@@ -463,11 +462,10 @@ void
 buffer_sample_get (buffer_t * buffer, const char *filename)
 {
   /* I think that most file(1) just use the 512 first bytes */
-#define SAMPLE_SIZE 512
   FILE *out = xwfopen (filename);
   size_t cur = 0;
   int c;
-  char *sample_buffer = MALLOC (SAMPLE_SIZE);
+  char *sample_buffer = XMALLOC (char, SAMPLE_SIZE);
 
   for (; (cur < SAMPLE_SIZE) && ((c = sgetc (buffer)) != EOF); cur++)
     {
