@@ -1,11 +1,7 @@
 /*
- * generate.c
+ * generate.c -- Input files and pretty printing.
  *
- * Interface between input, and output routines.  Called by main loop.
- *
- * Copyright (c) 1988, 89, 90, 91, 92, 93 Miguel Santana
- * Copyright (c) 1995, 96, 97, 98, 99 Akim Demaille, Miguel Santana
- * $Id: generate.c,v 1.28 1998/03/05 14:15:15 demaille Exp $
+ * Copyright (c) 1995-99 Akim Demaille, Miguel Santana
  */
 
 /*
@@ -27,10 +23,6 @@
  * Boston, MA 02111-1307, USA.
  */
 
-/*
- * $Id: generate.c,v 1.28 1998/03/05 14:15:15 demaille Exp $
- */
-
 #include "main.h"
 
 extern int isdir PARAMS ((const char *path));
@@ -74,14 +66,14 @@ input_new (uchar * name)
   file_job = CURRENT_FILE (job);
 
   /* Retrieve file modification date and hour */
-  if (IS_EMPTY(name) || strequ (name, "-"))
+  if (IS_EMPTY(name) || ustrequ (name, "-"))
     {
       file_job->is_stdin = true;
       file_job->name = job->stdin_filename;
       /* Create the buffer in charge of stdin */
       buffer_stream_set (res, stdin, end_of_line);
       /* Ask it to make a sample of the file. */
-      tempname_ensure (sample_tmpname, job->common.tmpdir);
+      tempname_ensure (sample_tmpname);
       buffer_sample_get (res, sample_tmpname);
     }
   else
@@ -93,20 +85,21 @@ input_new (uchar * name)
       /* Printing a file given by its path */
       if (isdir ((char *) name))
 	{
-	  error (0, 0, _("`%s' is a directory"), quotearg (name));
+	  error (0, 0, _("`%s' is a directory"), quotearg ((char *) name));
 	  file_job->printable = false;
 	}
 
       file_job->name = (uchar *) name;
       if ((input_stream = fopen ((char *) name, "r")) == NULL)
 	{
-	  error (0, errno, _("cannot open file `%s'"), quotearg (name));
+	  error (0, errno,
+		 _("cannot open file `%s'"), quotearg ((char *) name));
 	  file_job->printable = false;
 	}
       else if (stat ((char *) name, &statbuf) == -1)
 	{
 	  error (0, errno, _("cannot get informations on file `%s'"),
-		 quotearg (name));
+		 quotearg ((char *) name));
 	  file_job->printable = false;
 	}
       else
@@ -144,12 +137,12 @@ input_new (uchar * name)
 }
 
 static void
-end_input (buffer_t * buffer)
+input_end (buffer_t * buffer)
 {
   if (buffer->stream && buffer->stream!= stdin)
     fclose (buffer->stream);
   buffer_release (buffer);
-  FREE (buffer);
+  free (buffer);
 
   a2ps_close_input_session (job);
 }
@@ -223,7 +216,21 @@ msg_job_pages_printed (a2ps_job * Job)
     message (msg_report1,
 	     (stderr, _("[Total: %d pages on %d sheets] %s\n"),
 	      Job-> pages, sheets, ucp));
-  FREE (ucp);
+
+  /* Report the number of lines that were too long. */
+  if (macro_meta_sequence_get (Job, "cfg.wrapped")
+      && Job->lines_folded)
+    {
+      if (Job->lines_folded == 1)
+	message (msg_report1,
+		 (stderr, _("[1 line wrapped]\n")));
+      else
+	message (msg_report1,
+		 (stderr, _("[%d lines wrapped]\n"),
+		  Job->lines_folded));
+    }
+
+  free (ucp);
 }
 /*
  * Total printed
@@ -245,7 +252,7 @@ print_toc (const uchar * name, const uchar * value, int * native_jobs)
   a2ps_open_input_session (job, xustrdup (name));
   /* But it is not a regular file: we need to be able to know
    * that it is indeed a toc, so that --pages=toc can be honored */
-  CURRENT_FILE (job)->is_toc = TRUE;
+  CURRENT_FILE (job)->is_toc = true;
 
   austrcpy (toc_content,
 	    expand_user_string (job, CURRENT_FILE (job),
@@ -262,7 +269,7 @@ print_toc (const uchar * name, const uchar * value, int * native_jobs)
 /*
  * Called by the main loop.
  * The file to print is the last of the darray job->jobs.
- * Return TRUE if was a success, FALSE otherwise
+ * Return true if was a success, false otherwise
  */
 void
 print (uchar * filename, int * native_jobs, int * delegated_jobs)
@@ -299,60 +306,63 @@ print (uchar * filename, int * native_jobs, int * delegated_jobs)
   /*
    * Then do it
    */
-  switch (style_kind) {
-  case delegate:
-    /* In ps generation, we must begin a new page */
-    page_flush (job);
-    sprintf (buf, _("%s, delegated to %s"),
-	     file_job->type, contract->name);
-    if (subcontract (file_job, input_buffer, contract)) {
-      (*delegated_jobs)++;
-      msg_file_pages_printed (job, buf);
-    } else
-      message (msg_report2, (stderr, _("[%s (%s): failed.  Ignored]\n"),
-			     file_job->name, buf));
-    break;
+  switch (style_kind)
+    {
+    case delegate:
+      /* In ps generation, we must begin a new page */
+      page_flush (job);
+      sprintf (buf, _("%s, delegated to %s"),
+	       file_job->type, contract->name);
+      if (subcontract (file_job, input_buffer, contract))
+	{
+	  (*delegated_jobs)++;
+	  msg_file_pages_printed (job, buf);
+	}
+      else
+	message (msg_report2, (stderr, _("[%s (%s): failed.  Ignored]\n"),
+			       file_job->name, buf));
+      break;
 
-  case unprintable:
-    /* The job will not be processed correctly */
-    message (msg_report2,
-	     (stderr,
-	      _("[%s (unprintable): ignored]\n"), file_job->name));
-    break;
+    case unprintable:
+      /* The job will not be processed correctly */
+      message (msg_report2,
+	       (stderr,
+		_("[%s (unprintable): ignored]\n"), file_job->name));
+      break;
 
-  case binary:
-    if (job->print_binaries)
-      goto plain_print;
+    case binary:
+      if (job->print_binaries)
+	goto plain_print;
 
-    message (msg_report2,
-	     (stderr,
-	      _("[%s (binary): ignored]\n"), file_job->name));
-    break;
+      message (msg_report2,
+	       (stderr,
+		_("[%s (binary): ignored]\n"), file_job->name));
+      break;
 
-  case sshparser:
-    /* If highlight_level == none, don't */
-    if (highlight_level == 0)
-      goto plain_print;
-    sheet = get_style_sheet (file_job->type);
-    if (!sheet)
-      goto plain_print;
+    case sshparser:
+      /* If highlight_level == none, don't */
+      if (highlight_level == 0)
+	goto plain_print;
+      sheet = get_style_sheet (file_job->type);
+      if (!sheet)
+	goto plain_print;
 
-    buffer_set_lower_case (input_buffer,
-			   sheet->sensitiveness == case_insensitive);
-    ssh_print_postscript (job, input_buffer, sheet);
-    msg_file_pages_printed (job, (const char *) sheet->name);
-    (*native_jobs)++;
-    break;
+      buffer_set_lower_case (input_buffer,
+			     sheet->sensitiveness == case_insensitive);
+      ssh_print_postscript (job, input_buffer, sheet);
+      msg_file_pages_printed (job, (const char *) sheet->name);
+      (*native_jobs)++;
+      break;
 
-  plain_print:
-  case no_style:
-    plain_print_postscript (job, input_buffer);
-    msg_file_pages_printed (job, _("plain"));
-    (*native_jobs)++;
-    break;
-  }
+    plain_print:
+    case no_style:
+      plain_print_postscript (job, input_buffer);
+      msg_file_pages_printed (job, _("plain"));
+      (*native_jobs)++;
+      break;
+    }
 
-  end_input (input_buffer);
+  input_end (input_buffer);
 }
 
 /*
