@@ -1,15 +1,12 @@
 /*
- * generate.h
+ * generate.h -- Input files and pretty printing.
  *
- * routines of input, and formatting according to the styles
- * Copyright (c) 1988, 89, 90, 91, 92, 93 Miguel Santana
- * Copyright (c) 1995, 96, 97, 98 Akim Demaille, Miguel Santana
- * $Id: generate.h,v 1.4 1998/01/15 15:03:01 demaille Exp $
+ * Copyright (c) 1995-99 Akim Demaille, Miguel Santana
  */
 
 /*
  * This file is part of a2ps.
- * 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
@@ -26,11 +23,8 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#ifndef _GENERATE_H_
-#define _GENERATE_H_
-#include "jobs.h"
-#include "ssheet.h"
-#include "select.h"
+#ifndef GENERATE_H_
+# define GENERATE_H_
 
 void print PARAMS ((uchar * name, int * native_jobs, int * delegated_jobs));
 void print_toc PARAMS ((const uchar * name, const uchar * value,
@@ -40,4 +34,5 @@ void msg_job_pages_printed PARAMS ((a2ps_job * job));
 void msg_nothing_printed PARAMS ((void));
 
 void guess PARAMS ((uchar * name));
-#endif /* not defined(_GENERATE_H_) */
+
+#endif /* not defined(GENERATE_H_) */
