@@ -1,9 +1,8 @@
 /*
- * main.c
+ * main.c -- main loop, and interface with user
  *
- * main loop, and interface with user
- * Copyright (c) 1988, 89, 90, 91, 92, 93 Miguel Santana
- * Copyright (c) 1995, 96, 97, 98, 99 Akim Demaille, Miguel Santana
+ * Copyright (c) 1988-1993 Miguel Santana
+ * Copyright (c) 1995-2000 Akim Demaille, Miguel Santana
  */
 
 /*
@@ -25,11 +24,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-/*
- * $Id: main.c 1.4.1.1.1.1.1.7.1.3.1.5.1.2 Wed, 30 Dec 1998 20:24:20 +0100 demaille $
- */
 
-
 /************************************************************************/
 /*                                                                      */
 /*                      I n c l u d e   f i l e s                       */
@@ -59,6 +54,11 @@
 #include "lexps.h"
 #include <signal.h>
 #include "signame.h"
+#include "long-options.h"
+#include "version-etc.h"
+
+/* From basename.c */
+char *base_name PARAMS ((const char *path));
 
 /************************************************************************/
 /*                                                                      */
@@ -74,7 +74,9 @@ enum behavior
     b_guess,		/* do as file(1) does: return the ssh file name */
     b_help,
     b_version,
-    b_copyright,
+    b_expand,		/* Expand the strings given as arguments. */
+    b_which,		/* Look for the args in the path, and report. */
+    b_glob,		/* Same, but with globbing. */
     b_list_options,
     b_list_features,
     b_list_media,
@@ -106,10 +108,24 @@ const char *program_invocation_name;
 
 a2ps_job *job = NULL;
 
+
 /* Syntax table for regex. */
 
 char *re_syntax_table = NULL;
-#define RE_SYNTAX_A2PS (RE_SYNTAX_EMACS | RE_CHAR_CLASSES | RE_INTERVALS)
+
+#define RE_SYNTAX_A2PS \
+  (/* Allow char classes. */					\
+    RE_CHAR_CLASSES						\
+  /* Be picky. */						\
+  | RE_CONTEXT_INVALID_OPS					\
+  /* Allow intervals with `{' and `}', forbid invalid ranges. */\
+  | RE_INTERVALS | RE_NO_BK_BRACES | RE_NO_EMPTY_RANGES		\
+  /* `(' and `)' are the grouping operators. */			\
+  | RE_NO_BK_PARENS						\
+  /* `|' is the alternation. */					\
+  | RE_NO_BK_VBAR)
+
+
 /************************************************************************/
 /*      Related to the config files                                     */
 /************************************************************************/
@@ -121,7 +137,7 @@ struct hash_table_s *delegation_table;
 /*
  * Content of sheets.map
  */
-struct darray *sheets_map = NULL;	/* Content of sheets.map        */
+struct darray *sheets_map = NULL;
 
 /*
  * Hash table of the sheet yet read
@@ -134,7 +150,7 @@ struct hash_table_s *style_sheets = NULL;
 /*
  * Delegate files to other applications.
  */
-boolean delegate_p = true;
+bool delegate_p = true;
 
 /*
  * --toc[=format], generate a table of content
@@ -256,10 +272,10 @@ static const char *const behavior_args[] =
   "ppd",
   "version", "release",
   "help", "usage",
-  "copyright",
-  "ps",				/* Just for the case somebody
-				 * drop --list=something in his/her
-				 * a2psrc. (That would be real dumb */
+  "expand",
+  "which", "find",
+  "glob",
+  "ps",
   NULL
 };
 
@@ -282,76 +298,31 @@ static const enum behavior behavior_types[] =
   b_list_ppd,
   b_version, b_version,
   b_help, b_help,
-  b_copyright,
+  b_expand,
+  b_which, b_which,
+  b_glob,
   b_ps
 };
 
 /************************************************************************/
 /*                              Interface                               */
 /************************************************************************/
-static void
-copyright (FILE * stream)
-{
-  /* TRANS: Please try not to guess the translation.  Go and see
-   * in already translated GNU programs (e.g. the most recent
-   * versions of GNU recode) for `legal' translations. */
-  fputs (_("\
-This program is free software; you can redistribute it and/or modify\n\
-it under the terms of the GNU General Public License as published by\n\
-the Free Software Foundation; either version 2, or (at your option)\n\
-any later version.\n\
-\n\
-This program is distributed in the hope that it will be useful,\n\
-but WITHOUT ANY WARRANTY; without even the implied warranty of\n\
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n\
-GNU General Public License for more details.\n\
-\n\
-You should have received a copy of the GNU General Public License\n\
-along with this program; if not, write to the Free Software Foundation,\n\
-Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.\n"),
-	 stream);
-}
 
-/* Output version, a short copyright notice, and authors.
-   Meant for --version. */
+/*------------------------------------------------------------------.
+| Print information depending on the installation.  It is also used |
+| to store useful information in the output to help us debuging the |
+| users :).                                                         |
+`------------------------------------------------------------------*/
 
 static void
-version (FILE * stream)
+list_options (struct a2ps_job *a_job, FILE *stream)
 {
-  fprintf (stream,
-	   "GNU %s %s\n", PACKAGE, VERSION);
+#if 0
+  /* This is just so that gettext knows I use those two strings. */
+  static char *yes = N_("yes");
+  static char *no  = N_("no");
+#endif
 
-  /* TRANS: If your charset supports the character (c) (which is  in
-     ISO Latin 1), please use it! */
-  fputs (_("\
-\n\
-Copyright (c) 1988, 89, 90, 91, 92, 93 Miguel Santana\n\
-Copyright (c) 1995, 96, 97, 98, 99 Akim Demaille, Miguel Santana\n"),
-	 stream);
-  fputs (_("\
-This is free software; see the source for copying conditions.  There is NO\n\
-warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"),
-	 stream);
-
-  /* TRANS: Don't forget to add something about your own translation, e.g.
-     Written by <Akim.Demaille@inf.enst.fr> and <Miguel.Santana@st.com>
-     Translated by <me@here>
-     News, updates and documentation: visit http://www.inf.enst.fr/~demaille/a2ps/
-     Send comments about translation to me@my.email */
-  fputs (_("\n\
-Written by <Akim.Demaille@inf.enst.fr> and <Miguel.Santana@st.com>\n\
-News, updates and documentation: visit http://www.inf.enst.fr/~demaille/a2ps/\n"),
-	 stream);
-}
-
-/*
- * Print information depending on the installation.
- * It is also used to store useful information in the output
- * to help us debuging the users :).
- */
-static void
-list_options (struct a2ps_job *a_job, FILE * stream)
-{
 #define bool_to_string(bool) ((bool) ? _("yes") : _("no"))
   uchar buf[256], buf2[256];
   const char *cp = NULL;
@@ -461,7 +432,7 @@ list_options (struct a2ps_job *a_job, FILE * stream)
    */
   if (IS_EMPTY (style_request))
     /* TRANS: a2ps -E --list=options.  Warning, this answer is also
-     * used for the PPD file.  Make it compatible with both. */
+       used for the PPD file.  Make it compatible with both.  */
     ustrcpy (buf, _("selected automatically"));
   else
     ustrcpy (buf, style_request);
@@ -511,12 +482,11 @@ list_options (struct a2ps_job *a_job, FILE * stream)
   backup suffix   = %s\n"),
 	   ucp, cp, simple_backup_suffix);
   putc ('\n', stream);
-  FREE (ucp);
+  free (ucp);
 
   /*
    * PostScript report.
-   * TRANS: to be aligned with `statusdict definitions ='
-   * and with `page prefeed ='
+   * TRANS: to be aligned with `page prefeed ='
    */
   cp = a2ps_printers_request_ppdkey_get (a_job->printers);
   title (stream, '-', false, _("PostScript:\n"));
@@ -556,59 +526,75 @@ list_options (struct a2ps_job *a_job, FILE * stream)
   fprintf (stream, _("\
   verbosity level     = %d\n\
   file command        = %s\n\
-  temporary directory = %s\n\
   library path        = \n"),
 	   msg_verbosity,
-	   UNNULL (a_job->file_command),
-	   UNNULL (a_job->common.tmpdir));
+	   UNNULL (a_job->file_command));
   pw_fprintf_path (stream, "\t%s\n", a_job->common.path);
 }
 
-/*
- * This is used in psgen to push into the PostScript
- * the report of the state of a2ps when it produced the file.
- * I'm tired of fighting with users who don't really say everything
- * on the state of their a2ps when something goes wrong.
- * Now I can ask a ps file generated with --debug, and
- * got everything I need.
- */
+
+/*------------------------------------------------------------------.
+| This is used in psgen to push into the PostScript the report of   |
+| the state of a2ps when it produced the file.  I'm tired of        |
+| fighting with users who don't really say everything on the state  |
+| of their a2ps when something goes wrong.  Now I can ask a ps file |
+| generated with --debug, and got everything I need.                |
+`------------------------------------------------------------------*/
+
 static void
-list_options_with_prefix (struct a2ps_job *a_job, FILE * stream)
+spy_user (struct a2ps_job *a_job, FILE * stream)
 {
 #define PREFIX "% "
-  FILE *tmp_file;
-  char *tmp_filename;
+  FILE *spy;
+  char *spyname;
   char buf[BUFSIZ];
 
   /* Use one of the temp file names so that cleanup can be correctly
      done. */
-  tempname_ensure (job->tmp_filenames[0], job->common.tmpdir);
-  tmp_filename = job->tmp_filenames[0];
-  tmp_file = fopen (tmp_filename, "w");
-  if (!tmp_file)
-    error (1, errno, _("cannot open file `%s'"), quotearg (tmp_filename));
+  tempname_ensure (job->tmp_filenames[0]);
+  spyname = job->tmp_filenames[0];
+  spy = fopen (spyname, "w");
+  if (!spy)
+    error (1, errno, _("cannot open file `%s'"), quotearg (spyname));
 
-  list_options (a_job, tmp_file);
-  fclose (tmp_file);
 
-  fopen (tmp_filename, "r");
-  if (!tmp_file)
-    error (1, errno, _("cannot open file `%s'"), quotearg (tmp_filename));
+  /* Well, this is the information I've been fighting with some users
+     to get them exact...  I hate doing that, but I need to save part
+     of my time.  */
+  fputs ("SPY-BEGIN\n", spy);
+  fputs ((char *) expand_user_string (job, CURRENT_FILE (job),
+				      (const uchar *) "Debugging info",
+				      (const uchar *) "%V was called with #!$|| |\n\n"),
+	 spy);
 
-  while (fgets (buf, sizeof (buf), tmp_file))
+  list_options (a_job, spy);
+  putc ('\n', spy);
+  macro_meta_sequences_list_long (a_job, spy);
+  fputs ("SPY-END\n", spy);
+
+  /* Yes, I know, there are certainly better means.  Just teach them
+     to me...  */
+  fclose (spy);
+  fopen (spyname, "r");
+  if (!spy)
+    error (1, errno, _("cannot open file `%s'"), quotearg (spyname));
+
+  while (fgets (buf, sizeof (buf), spy))
     {
       fputs (PREFIX, stream);
       fputs (buf, stream);
     }
   fputs (PREFIX, stream);
   putc ('\n', stream);
-  fclose (tmp_file);
-  unlink (tmp_filename);
+  fclose (spy);
+  unlink (spyname);
 }
 
-/*
- * Print information depending on the installation.
- */
+
+/*--------------------------------------------------.
+| Print information depending on the installation.  |
+`--------------------------------------------------*/
+
 static void
 list_features (struct a2ps_job *a_job, FILE * stream)
 {
@@ -648,76 +634,86 @@ list_features (struct a2ps_job *a_job, FILE * stream)
   macro_meta_sequences_list_short (a_job, stream);
 }
 
-/*
- * Print a usage message.
- */
+/*------------------------.
+| Print a usage message.  |
+`------------------------*/
+
+#define sfputs(String)	fputs (String, stream)
+#define sputc(Char)	putc (Char, stream)
+
 static void
-usage (FILE * stream)
+usage (int status)
 {
+  /* Currently, there seem to be no use in being able to use another
+     stream than STDOUT.  */
+  FILE *stream = stdout;
+
   fprintf (stream, _("\
-Usage: %s [OPTIONS]... FILES...\n\
-   or: %s [OPTIONS]...\n\
-To print FILES, or to print the standard input.\n\
+Usage: %s [OPTION]... [FILE]...\n\
+\n\
+Convert FILE(s) or standard input to PostScript.\n\
+\n\
 Mandatory arguments to long options are mandatory for short options too.\n\
 Long options marked with * require a yes/no argument, corresponding\n\
 short options stand for `yes'.\n"),
-	   program_invocation_name, program_invocation_name);
+	   program_invocation_name);
 
   /*
    * Does not print, and exits with success
    */
-  putc ('\n', stream);
-  fputs (_("Tasks (exit successfully):\n"), stream);
-  /* TRANS: for helptoman to work better, please make sure that the
-   * paragraph TOPIC be indented the same way (with a space at the
-   * beginning of continued lines) */
-  fputs (_("\
-  -V, --version              display version\n\
-  --help                     display this help\n\
-  --copyright                display Copyright and copying conditions\n\
-  --guess                    display guessed types of FILES\n\
-  --list=TOPIC               display a report on TOPIC\n\
-\n\
-TOPIC can be any non-ambiguous abbreviation of:\n\
- * `defaults': default settings and parameters,\n\
- * `features': short list of supported media, encodings, style sheets etc.\n\
- * `delegations', `encodings', `variables', `media',\n\
-   `ppd', `printers', `prologues', `style-sheets', `user-options': \n\
-   detailed list.\n"),
-	 stream);
+  sputc ('\n');
+  sfputs (_("Tasks:\n"));
+  sfputs (_("\
+  --version        display version\n\
+  --help           display this help\n\
+  --guess          report guessed types of FILES\n\
+  --which          report the full path of library files named FILES\n\
+  --glob           report the full path of library files matching FILES\n\
+  --list=defaults  display default settings and parameters\n\
+  --list=TOPIC     detailed list on TOPIC (delegations, encodings, features,\n\
+                   variables, media, ppd, printers, prologues, style-sheets,\n\
+                   user-options)\n"));
+  sputc ('\n');
+  sfputs (_("\
+After having performed the task, exit successfully.  Detailed lists may\n\
+provide additional help on specific features.\n"));
 
   /*
    * Applies to the whole behavior
    */
-  putc ('\n', stream);
-  fputs (_("Global:\n"), stream);
-  fputs (_("\
+  sputc ('\n');
+  sfputs (_("Global:\n"));
+  sfputs (_("\
   -q, --quiet, --silent      be really quiet\n\
   -v, --verbose[=LEVEL]      set verbosity on, or to LEVEL\n\
   -=, --user-option=OPTION   use the user defined shortcut OPTION\n\
       --debug                enable debugging features\n\
-  -D, --define=KEY[:VALUE]   unset variable KEY or set to VALUE\n"),
-	 stream);
+  -D, --define=KEY[:VALUE]   unset variable KEY or set to VALUE\n"));
 
-  putc ('\n', stream);
-  fputs (_("Sheets:\n"), stream);
-  fputs (_("\
+  sputc ('\n');
+  sfputs (_("Sheets:\n"));
+  sfputs (_("\
   -M, --medium=NAME      use output medium NAME\n\
   -r, --landscape        print in landscape mode\n\
   -R, --portrait         print in portrait mode\n\
-      --columns=NUM      number of columns per sheet (NUM > 0)\n\
-      --rows=NUM         number of rows per sheet (NUM > 0)\n\
+      --columns=NUM      number of columns per sheet\n\
+      --rows=NUM         number of rows per sheet\n\
       --major=DIRECTION  first fill (DIRECTION=) rows, or columns\n\
   -1, -2, ..., -9        predefined font sizes and layouts for 1.. 9 virtuals\n\
   -A, --file-align=MODE  align separate files according to MODE (fill, rank\n\
                          page, sheet, or a number)\n\
   -j, --borders*         print borders around columns\n\
-      --margin[=NUM]     define an interior margin of size NUM\n"),
-	 stream);
+      --margin[=NUM]     define an interior margin of size NUM\n"));
+  sputc ('\n');
+  sfputs (_("\
+The options -1.. -9 affect several primitive parameters to set up predefined\n\
+layouts with 80 columns.  Therefore the order matters: `-R -f40 -2' is\n\
+equivalent to `-2'.  To modify the layout, use `-2Rf40', or compose primitive\n\
+options (`--columns', `--font-size' etc.).\n"));
 
-  putc ('\n', stream);
-  fputs (_("Virtual pages:\n"), stream);
-  fputs (_("\
+  sputc ('\n');
+  sfputs (_("Virtual pages:\n"));
+  sfputs (_("\
       --line-numbers=NUM     precede each NUM lines with its line number\n\
   -C                         alias for --line-numbers=5\n\
   -f, --font-size=SIZE       use font SIZE (float) for the body text\n\
@@ -725,26 +721,28 @@ TOPIC can be any non-ambiguous abbreviation of:\n\
   -l, --chars-per-line=NUM   scale the font to print NUM columns per virtual\n\
   -m, --catman               process FILE as a man page (same as -L66)\n\
   -T, --tabsize=NUM          set tabulator size to NUM\n\
-  --non-printable-format=FMT specify how non-printable chars are printed\n"),
-	 stream);
+  --non-printable-format=FMT specify how non-printable chars are printed\n"));
 
-  putc ('\n', stream);
-  fputs (_("Headings:\n"), stream);
+  sputc ('\n');
+  sfputs (_("Headings:\n"));
   /* xgettext:no-c-format */
-  fputs (_("\
-  -B, --no-header            no page headers at all\n\
-  -b, --header[=TEXT]        set page header\n\
-  -u, --underlay[=TEXT]      print TEXT under every page\n\
-  --center-title[=TEXT]      set page title to TITLE\n\
-  --left-title[=TEXT]        set left and right page title to TEXT\n\
+  sfputs (_("\
+  -B, --no-header        no page headers at all\n\
+  -b, --header[=TEXT]    set page header\n\
+  -u, --underlay[=TEXT]  print TEXT under every page\n\
+  --center-title[=TEXT]  set page title to TITLE\n\
+  --left-title[=TEXT]    set left and right page title to TEXT\n\
   --right-title[=TEXT]\n\
-  --left-footer[=TEXT]       set sheet footers to TEXT\n\
-  --footer[=TEXT]            TEXT may use special $ and % escapes\n\
-  --right-footer[=TEXT]\n"), stream);
+  --left-footer[=TEXT]   set sheet footers to TEXT\n\
+  --footer[=TEXT]\n\
+  --right-footer[=TEXT]\n"));
+  sputc ('\n');
+  sfputs (_("\
+The TEXTs may use special escapes.\n"));
 
-  putc ('\n', stream);
-  fputs (_("Input:\n"), stream);
-  fputs (_("\
+  sputc ('\n');
+  sfputs (_("Input:\n"));
+  sfputs (_("\
   -a, --pages[=RANGE]        select the pages to print\n\
   -c, --truncate-lines*      cut long lines\n\
   -i, --interpret*           interpret tab, bs and ff chars\n\
@@ -754,33 +752,35 @@ TOPIC can be any non-ambiguous abbreviation of:\n\
       --stdin=NAME           set the name of the input file stdin\n\
       --print-anyway*        force binary printing\n\
   -Z, --delegate*            delegate files to another application\n\
-      --toc[=TEXT]           generate a table of content\n"),
-	 stream);
+      --toc[=TEXT]           generate a table of content\n"));
+  sputc ('\n');
+  sfputs (_("\
+When delegations are enabled, a2ps may use other applications to handle the\n\
+processing of files that should not be printed as raw information, e.g., HTML\n\
+PostScript, PDF etc.\n"));
 
-  putc ('\n', stream);
-  fputs (_("Pretty-printing:\n"), stream);
-  fputs (_("\
+  sputc ('\n');
+  sfputs (_("Pretty-printing:\n"));
+  sfputs (_("\
   -E, --pretty-print[=LANG]  enable pretty-printing (set style to LANG)\n\
   --highlight-level=LEVEL    set pretty printing highlight LEVEL\n\
                              LEVEL can be none, normal or heavy\n\
   -g                         alias for --highlight-level=heavy\n\
-  --strip-level=NUM          level of comments stripping\n"),
-	 stream);
+  --strip-level=NUM          level of comments stripping\n"));
 
-  putc ('\n', stream);
-  fputs (_("Output:\n"), stream);
-  fputs (_("\
+  sputc ('\n');
+  sfputs (_("Output:\n"));
+  sfputs (_("\
   -o, --output=FILE          leave output to file FILE.  If FILE is `-',\n\
                              leave output to stdout.\n\
   --version-control=WORD     override the usual version control\n\
   --suffix=SUFFIX            override the usual backup suffix\n\
   -P, --printer=NAME         send output to printer NAME\n\
-  -d                         send output to the default printer\n"),
-	 stream);
+  -d                         send output to the default printer\n"));
 
-  putc ('\n', stream);
-  fputs (_("PostScript:\n"), stream);
-  fputs (_("\
+  sputc ('\n');
+  sfputs (_("PostScript:\n"));
+  sfputs (_("\
       --prologue=FILE        include FILE.pro as PostScript prologue\n\
       --ppd[=KEY]            automatic PPD selection or set to KEY\n\
   -n, --copies=NUM           print NUM copies of each page\n\
@@ -789,22 +789,45 @@ TOPIC can be any non-ambiguous abbreviation of:\n\
   -S, --setpagedevice=K[:V]  pass a page device definition to output\n\
       --statusdict=K[:[:]V]  pass a statusdict definition to the output\n\
   -k, --page-prefeed         enable page prefeed\n\
-  -K, --no-page-prefeed      disable page prefeed\n"),
-	 stream);
+  -K, --no-page-prefeed      disable page prefeed\n"));
 
-  putc ('\n', stream);
-  /* TRANS: This is the second place where you are invited to drop
-   * a mail to report translation problems. Eg.:
-   Report bugs to <a2ps-bugs@gnu.org>
-   Report translation problems to <me@there> */
-  fputs (_("Report bugs to <bug-a2ps@gnu.org>\n"),
-	 stream);
+
+  /* A short documentation. */
+  sputc ('\n');
+  sfputs (_("\
+By default a2ps is tuned to do what you want to, so trust it.  To pretty\n\
+print the content of the `src' directory and a table of content, and send the\n\
+result to the printer `lw',\n\
+\n\
+    $ a2ps -P lw --toc src/*\n\
+\n\
+To process the files `sample.ps' and `sample.html' and display the result,\n\
+\n\
+    $ a2ps -P display sample.ps sample.html\n\
+\n\
+To process a mailbox in 4 up,\n\
+\n\
+    $ a2ps -=mail -4 mailbox\n\
+\n\
+To print as a booklet on the default printer, which is Duplex capable,\n\
+\n\
+    $ a2ps -=book paper.dvi.gz -d\n"));
+
+  /* Finally, some addresses. */
+  sputc ('\n');
+  sfputs (_("\
+News, updates and documentation: visit http://www.inf.enst.fr/~demaille/a2ps/.\n"));
+  sfputs (_("Report bugs to <bug-a2ps@gnu.org>.\n"));
+
+  exit (status);
 }
 
-/*
- * Handle the options that a2ps understands (not liba2ps)
- * Return 1 for success
- */
+
+/*----------------------------------------------------------------.
+| Handle the options that a2ps understands (not liba2ps) Return 1 |
+| for success                                                     |
+`----------------------------------------------------------------*/
+
 static int
 handle_a2ps_option (int option, char *optional_arg)
 {
@@ -820,7 +843,7 @@ handle_a2ps_option (int option, char *optional_arg)
 
     case 154:			/* Symbol translation */
       highlight_level =
-	a2ps_get_boolean ("--graphic-symbols", optional_arg);
+	a2ps_get_bool ("--graphic-symbols", optional_arg);
       break;
 
     case 173:			/* Level of high lighting */
@@ -844,6 +867,14 @@ handle_a2ps_option (int option, char *optional_arg)
       behavior = b_guess;
       break;
 
+    case 137:
+      behavior = b_which;
+      break;
+
+    case 150:
+      behavior = b_glob;
+      break;
+
     case 139:
       behavior = b_list_options;
       break;
@@ -861,7 +892,7 @@ handle_a2ps_option (int option, char *optional_arg)
       break;
 
     case 160:			/* --delegate=BOOL */
-      delegate_p = a2ps_get_boolean ("--delegate", optional_arg);
+      delegate_p = a2ps_get_bool ("--delegate", optional_arg);
       break;
 
     case 161:			/* --list-media */
@@ -881,10 +912,6 @@ handle_a2ps_option (int option, char *optional_arg)
       end_of_line = option_string_to_eol ("--end-of-line", optional_arg);
       break;
 
-    case 174:			/* --copyright  */
-      behavior = b_copyright;
-      break;
-
     default:
       return 0;
     }
@@ -906,16 +933,28 @@ main (int argc, char *argv[])
 #endif
 
   /* Name under which this program was called. */
-  program_name = strrchr (argv[0], DIR_SEP);
-  if (program_name == NULL)
-    program_name = argv[0];
-  else
-    {
-      *program_name = NUL;
-      program_name++;
-      argv[0] = program_name;
-    }
+  program_name = base_name (argv[0]);
   program_invocation_name = xstrdup (program_name);
+  version_etc_copyright = N_("\
+Copyright (c) 1988-1993 Miguel Santana\n\
+Copyright (c) 1995-2000 Akim Demaille, Miguel Santana");
+
+  /* Set the NLS on */
+  setlocale (LC_TIME, "");
+#ifdef HAVE_LC_MESSAGES
+  setlocale (LC_MESSAGES, "");
+#endif
+  setlocale (LC_CTYPE, "");
+
+  bindtextdomain (PACKAGE, LOCALEDIR);
+  textdomain (PACKAGE);
+
+  /* People don't want initializations when they just request a --help
+     or --version. */
+  parse_long_options (argc, argv,
+		      NULL, GNU_PACKAGE, VERSION,
+		      "Akim Demaille, Miguel Santana",
+		      usage);
 
   /* Catch the exits and signals to cleanup the mess.
 
@@ -946,9 +985,6 @@ main (int argc, char *argv[])
   /* Hook when reading the options */
   handle_option_hook = handle_a2ps_option;
 
-  /* Hook after having generated the PostScript comments */
-  ps_comment_hook = list_options_with_prefix;
-
   /* Prepare to receive in the hash table of the delegations */
   delegation_table = delegation_table_new ();
 
@@ -983,6 +1019,11 @@ main (int argc, char *argv[])
   /* Once a2ps.cfg is read, finish the building of a2ps_job */
   a2ps_job_finalize (job);
 
+  /* If we are debugging, then install a hook called after having
+     generated the PostScript comments. */
+  if (job->debug)
+    ps_comment_hook = spy_user;
+
   /* Attach the arguments to the JOB */
   job->argv = argv;
   job->argc = argc;
@@ -999,16 +1040,49 @@ main (int argc, char *argv[])
 	guess (UNULL);
       break;
 
+      /* FIXME: for expand, which, and glob, should we give an error
+         when no arguments are given? */
+
+    case b_expand:
+      /* Expand the strings given as arguments. */
+      for (; argn < argc; argn++)
+	{
+	  fputs (expand_user_string (job, FIRST_FILE (job),
+				     "--list=expand", (uchar *) argv[argn]),
+		 stdout);
+	  putc ('\n', stdout);
+	}
+      break;
+
+    case b_which:
+      /* Look for the arguments in the library, and report the full
+         paths. */
+      for (; argn < argc; argn++)
+	{
+	  char *cp;
+	  cp = pw_find_file (job->common.path, (uchar *) argv[argn], NULL);
+	  if (cp)
+	    {
+	      fputs (cp, stdout);
+	      putc ('\n', stdout);
+	    }
+	}
+      break;
+
+    case b_glob:
+      /* Glob the arguments in the library, and report the full
+         paths. */
+      for (; argn < argc; argn++)
+	pw_glob_print (job->common.path, (uchar *) argv[argn], stdout);
+      break;
+
     case b_version:
-      version (stdout);
+      version_etc (stdout, NULL, GNU_PACKAGE, VERSION,
+		   "Akim Demaille, Miguel Santana");
       break;
 
     case b_help:
-      usage (stdout);
-      break;
-
-    case b_copyright:
-      copyright (stdout);
+      usage (0);
       break;
 
     case b_list_options:
@@ -1124,6 +1198,10 @@ main (int argc, char *argv[])
 	  }
       }
       break;
+
+    default:
+      /* A case has not been recognized. */
+      abort ();
     }
 
   a2ps_job_free (job);
