@@ -1,42 +1,41 @@
 
 /*  A Bison parser, made from parsessh.y
- by  GNU Bison version 1.25
-  */
+    by GNU Bison version 1.28  */
 
 #define YYBISON 1  /* Identify Bison output.  */
 
-#define	tSTYLE	258
-#define	tIS	259
-#define	tEND	260
-#define	tKEYWORDS	261
-#define	tARE	262
-#define	tIN	263
-#define	tOPERATORS	264
-#define	tSEQUENCES	265
-#define	tFIRST	266
-#define	tSECOND	267
-#define	tALPHABET	268
-#define	tALPHABETS	269
-#define	tDOCUMENTATION	270
-#define	tEXCEPTIONS	271
-#define	tCASE	272
-#define	tCSTRING	273
-#define	tCCHAR	274
-#define	tOPTIONAL	275
-#define	tCLOSERS	276
-#define	tWRITTEN	277
-#define	tBY	278
-#define	tVERSION	279
-#define	tREQUIRES	280
-#define	tA2PS	281
-#define	tANCESTORS	282
-#define	tFACE	283
-#define	tFFLAGS	284
-#define	tSTRING	285
-#define	tLATEXSYMBOL	286
-#define	tREGEX	287
-#define	tSENSITIVENESS	288
-#define	tBACK_REF	289
+#define	tSTYLE	257
+#define	tIS	258
+#define	tEND	259
+#define	tKEYWORDS	260
+#define	tARE	261
+#define	tIN	262
+#define	tOPERATORS	263
+#define	tSEQUENCES	264
+#define	tFIRST	265
+#define	tSECOND	266
+#define	tALPHABET	267
+#define	tALPHABETS	268
+#define	tDOCUMENTATION	269
+#define	tEXCEPTIONS	270
+#define	tCASE	271
+#define	tCSTRING	272
+#define	tCCHAR	273
+#define	tOPTIONAL	274
+#define	tCLOSERS	275
+#define	tWRITTEN	276
+#define	tBY	277
+#define	tVERSION	278
+#define	tREQUIRES	279
+#define	tA2PS	280
+#define	tANCESTORS	281
+#define	tFACE	282
+#define	tFFLAGS	283
+#define	tSTRING	284
+#define	tLATEXSYMBOL	285
+#define	tREGEX	286
+#define	tSENSITIVENESS	287
+#define	tBACK_REF	288
 
 #line 1 "parsessh.y"
  /* -*- c -*- */
@@ -85,12 +84,12 @@
 #define YYPRINT(file, type, value)   yyprint (file, type, value)
 
 /* We need to use the same `const' as bison, to avoid the following
- * prototypes to diverge from the function declarartions */
+   prototypes to diverge from the function declarations */
 #undef const
 #ifndef __cplusplus
-#ifndef __STDC__
-#define const
-#endif
+# ifndef __STDC__
+#  define const
+# endif
 #endif
 
 /* Comes from the parser */
@@ -99,7 +98,7 @@ extern int sshlineno;
 /* Comes from the caller */
 extern FILE * sshin;
 extern struct a2ps_job * job;
-const char * sshfilename;
+extern const char * sshfilename;
 
 /* Local prototypes */
 void yyerror PARAMS ((const char *msg));
@@ -153,7 +152,7 @@ typedef union
 #define	YYFLAG		-32768
 #define	YYNTBASE	39
 
-#define YYTRANSLATE(x) ((unsigned)(x) <= 289 ? yytranslate[x] : 68)
+#define YYTRANSLATE(x) ((unsigned)(x) <= 288 ? yytranslate[x] : 68)
 
 static const char yytranslate[] = {     0,
      2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
@@ -181,10 +180,10 @@ static const char yytranslate[] = {     0,
      2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
      2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
      2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
-     2,     2,     2,     2,     2,     1,     2,     3,     4,     5,
-     6,     7,     8,     9,    10,    11,    12,    13,    14,    15,
-    16,    17,    18,    19,    20,    21,    22,    23,    24,    25,
-    26,    27,    28,    29,    30,    31,    32,    33,    34
+     2,     2,     2,     2,     2,     1,     3,     4,     5,     6,
+     7,     8,     9,    10,    11,    12,    13,    14,    15,    16,
+    17,    18,    19,    20,    21,    22,    23,    24,    25,    26,
+    27,    28,    29,    30,    31,    32,    33,    34
 };
 
 #if YYDEBUG != 0
@@ -246,12 +245,12 @@ static const short yyrline[] = { 0,
    196,   204,   211,   218,   221,   224,   227,   230,   244,   246,
    248,   251,   252,   267,   269,   271,   276,   283,   291,   298,
    305,   310,   321,   329,   334,   338,   342,   346,   350,   356,
-   362,   373,   379,   386,   395,   401,   406,   412,   426,   430,
-   435,   446,   450,   456,   462,   467,   472,   483,   488,   494,
-   503,   507,   513,   520,   526,   531,   542,   547,   552,   561,
-   564,   570,   589,   601,   608,   615,   622,   629,   636,   643,
-   650,   658,   664,   671,   675,   681,   690,   696,   702,   709,
-   714
+   362,   373,   379,   386,   395,   401,   406,   412,   426,   431,
+   437,   449,   453,   459,   465,   470,   475,   486,   492,   499,
+   509,   513,   519,   526,   532,   537,   548,   554,   560,   570,
+   573,   579,   598,   610,   618,   626,   634,   642,   650,   658,
+   666,   674,   681,   689,   693,   699,   709,   715,   721,   728,
+   733
 };
 #endif
 
@@ -409,7 +408,8 @@ static const short yycheck[] = {    29,
      0,    16,     0,    40,   102,   107,    98,    15,   116
 };
 /* -*-C-*-  Note some compilers choke on comments on `#line' lines.  */
-#line 3 "/usr/local/share/bison.simple"
+#line 3 "/usr/share/misc/bison.simple"
+/* This file comes from bison-1.28.  */
 
 /* Skeleton output parser for bison,
    Copyright (C) 1984, 1989, 1990 Free Software Foundation, Inc.
@@ -426,47 +426,67 @@ static const short yycheck[] = {    29,
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.  */
 
 /* As a special exception, when this file is copied by Bison into a
    Bison output file, you may use that output file without restriction.
    This special exception was added by the Free Software Foundation
    in version 1.24 of Bison.  */
 
-#ifndef alloca
-#ifdef __GNUC__
-#define alloca __builtin_alloca
-#else /* not GNU C.  */
-#if (!defined (__STDC__) && defined (sparc)) || defined (__sparc__) || defined (__sparc) || defined (__sgi)
-#include <alloca.h>
-#else /* not sparc */
-#if defined (MSDOS) && !defined (__TURBOC__)
-#include <malloc.h>
-#else /* not MSDOS, or __TURBOC__ */
-#if defined(_AIX)
-#include <malloc.h>
- #pragma alloca
-#else /* not MSDOS, __TURBOC__, or _AIX */
-#ifdef __hpux
-#ifdef __cplusplus
-extern "C" {
-void *alloca (unsigned int);
-};
-#else /* not __cplusplus */
-void *alloca ();
-#endif /* not __cplusplus */
-#endif /* __hpux */
-#endif /* not _AIX */
-#endif /* not MSDOS, or __TURBOC__ */
-#endif /* not sparc.  */
-#endif /* not GNU C.  */
-#endif /* alloca not defined.  */
-
 /* This is the parser code that is written into each bison parser
   when the %semantic_parser declaration is not specified in the grammar.
   It was written by Richard Stallman by simplifying the hairy parser
   used when %semantic_parser is specified.  */
 
+#ifndef YYSTACK_USE_ALLOCA
+#ifdef alloca
+#define YYSTACK_USE_ALLOCA
+#else /* alloca not defined */
+#ifdef __GNUC__
+#define YYSTACK_USE_ALLOCA
+#define alloca __builtin_alloca
+#else /* not GNU C.  */
+#if (!defined (__STDC__) && defined (sparc)) || defined (__sparc__) || defined (__sparc) || defined (__sgi) || (defined (__sun) && defined (__i386))
+#define YYSTACK_USE_ALLOCA
+#include <alloca.h>
+#else /* not sparc */
+/* We think this test detects Watcom and Microsoft C.  */
+/* This used to test MSDOS, but that is a bad idea
+   since that symbol is in the user namespace.  */
+#if (defined (_MSDOS) || defined (_MSDOS_)) && !defined (__TURBOC__)
+#if 0 /* No need for malloc.h, which pollutes the namespace;
+	 instead, just don't use alloca.  */
+#include <malloc.h>
+#endif
+#else /* not MSDOS, or __TURBOC__ */
+#if defined(_AIX)
+/* I don't know what this was needed for, but it pollutes the namespace.
+   So I turned it off.   rms, 2 May 1997.  */
+/* #include <malloc.h>  */
+ #pragma alloca
+#define YYSTACK_USE_ALLOCA
+#else /* not MSDOS, or __TURBOC__, or _AIX */
+#if 0
+#ifdef __hpux /* haible@ilog.fr says this works for HPUX 9.05 and up,
+		 and on HPUX 10.  Eventually we can turn this on.  */
+#define YYSTACK_USE_ALLOCA
+#define alloca __builtin_alloca
+#endif /* __hpux */
+#endif
+#endif /* not _AIX */
+#endif /* not MSDOS, or __TURBOC__ */
+#endif /* not sparc */
+#endif /* not GNU C */
+#endif /* alloca not defined */
+#endif /* YYSTACK_USE_ALLOCA not defined */
+
+#ifdef YYSTACK_USE_ALLOCA
+#define YYSTACK_ALLOC alloca
+#else
+#define YYSTACK_ALLOC malloc
+#endif
+
 /* Note: there must be only one dollar sign in this file.
    It is replaced by the list of actions, each action
    as one case of the switch.  */
@@ -475,8 +495,8 @@ void *alloca ();
 #define yyclearin	(yychar = YYEMPTY)
 #define YYEMPTY		-2
 #define YYEOF		0
-#define YYACCEPT	return(0)
-#define YYABORT 	return(1)
+#define YYACCEPT	goto yyacceptlab
+#define YYABORT 	goto yyabortlab
 #define YYERROR		goto yyerrlab1
 /* Like YYERROR except do call yyerror.
    This remains here temporarily to ease the
@@ -557,12 +577,12 @@ int yydebug;			/*  nonzero means print parse trace	*/
 #ifndef YYMAXDEPTH
 #define YYMAXDEPTH 10000
 #endif
-
-/* Prevent warning if -Wstrict-prototypes.  */
-#ifdef __GNUC__
-int yyparse (void);
-#endif
 
+/* Define __yy_memcpy.  Note that the size argument
+   should be passed with type unsigned int, because that is what the non-GCC
+   definitions require.  With GCC, __builtin_memcpy takes an arg
+   of type size_t, but it can handle unsigned int.  */
+
 #if __GNUC__ > 1		/* GNU C and GNU C++ define this.  */
 #define __yy_memcpy(TO,FROM,COUNT)	__builtin_memcpy(TO,FROM,COUNT)
 #else				/* not GNU C or C++ */
@@ -574,7 +594,7 @@ static void
 __yy_memcpy (to, from, count)
      char *to;
      char *from;
-     int count;
+     unsigned int count;
 {
   register char *f = from;
   register char *t = to;
@@ -589,10 +609,10 @@ __yy_memcpy (to, from, count)
 /* This is the most reliable way to avoid incompatibilities
    in available built-in functions on various systems.  */
 static void
-__yy_memcpy (char *to, char *from, int count)
+__yy_memcpy (char *to, char *from, unsigned int count)
 {
-  register char *f = from;
   register char *t = to;
+  register char *f = from;
   register int i = count;
 
   while (i-- > 0)
@@ -602,7 +622,7 @@ __yy_memcpy (char *to, char *from, int count)
 #endif
 #endif
 
-#line 196 "/usr/local/share/bison.simple"
+#line 217 "/usr/share/misc/bison.simple"
 
 /* The user can define YYPARSE_PARAM as the name of an argument to be passed
    into yyparse.  The argument should have type void *.
@@ -623,6 +643,15 @@ __yy_memcpy (char *to, char *from, int count)
 #define YYPARSE_PARAM_DECL
 #endif /* not YYPARSE_PARAM */
 
+/* Prevent warning if -Wstrict-prototypes.  */
+#ifdef __GNUC__
+#ifdef YYPARSE_PARAM
+int yyparse (void *);
+#else
+int yyparse (void);
+#endif
+#endif
+
 int
 yyparse(YYPARSE_PARAM_ARG)
      YYPARSE_PARAM_DECL
@@ -651,6 +680,7 @@ yyparse(YYPARSE_PARAM_ARG)
 #endif
 
   int yystacksize = YYINITDEPTH;
+  int yyfree_stacks = 0;
 
 #ifdef YYPURE
   int yychar;
@@ -735,18 +765,32 @@ yynewstate:
       if (yystacksize >= YYMAXDEPTH)
 	{
 	  yyerror("parser stack overflow");
+	  if (yyfree_stacks)
+	    {
+	      free (yyss);
+	      free (yyvs);
+#ifdef YYLSP_NEEDED
+	      free (yyls);
+#endif
+	    }
 	  return 2;
 	}
       yystacksize *= 2;
       if (yystacksize > YYMAXDEPTH)
 	yystacksize = YYMAXDEPTH;
-      yyss = (short *) alloca (yystacksize * sizeof (*yyssp));
-      __yy_memcpy ((char *)yyss, (char *)yyss1, size * sizeof (*yyssp));
-      yyvs = (YYSTYPE *) alloca (yystacksize * sizeof (*yyvsp));
-      __yy_memcpy ((char *)yyvs, (char *)yyvs1, size * sizeof (*yyvsp));
+#ifndef YYSTACK_USE_ALLOCA
+      yyfree_stacks = 1;
+#endif
+      yyss = (short *) YYSTACK_ALLOC (yystacksize * sizeof (*yyssp));
+      __yy_memcpy ((char *)yyss, (char *)yyss1,
+		   size * (unsigned int) sizeof (*yyssp));
+      yyvs = (YYSTYPE *) YYSTACK_ALLOC (yystacksize * sizeof (*yyvsp));
+      __yy_memcpy ((char *)yyvs, (char *)yyvs1,
+		   size * (unsigned int) sizeof (*yyvsp));
 #ifdef YYLSP_NEEDED
-      yyls = (YYLTYPE *) alloca (yystacksize * sizeof (*yylsp));
-      __yy_memcpy ((char *)yyls, (char *)yyls1, size * sizeof (*yylsp));
+      yyls = (YYLTYPE *) YYSTACK_ALLOC (yystacksize * sizeof (*yylsp));
+      __yy_memcpy ((char *)yyls, (char *)yyls1,
+		   size * (unsigned int) sizeof (*yylsp));
 #endif
 #endif /* no yyoverflow */
 
@@ -997,7 +1041,7 @@ case 11:
 	  string_to_array (yyvsp[-3].sheet->alpha1, yyvsp[0].string);
 	  string_to_array (yyvsp[-3].sheet->alpha2, yyvsp[0].string);
 	  /* This is the syntax table used by regex */
-	  FREE (yyvsp[0].string);
+	  free (yyvsp[0].string);
 	  yyvsp[0].string = NULL;
 	  yyval.sheet = yyvsp[-3].sheet;
 	;
@@ -1007,7 +1051,7 @@ case 12:
 {
 	  string_to_array (yyvsp[-4].sheet->alpha1, yyvsp[0].string);
 	  /* This is the syntax table used by regex */
-	  FREE (yyvsp[0].string);
+	  free (yyvsp[0].string);
 	  yyvsp[0].string = NULL;
 	  yyval.sheet = yyvsp[-4].sheet;
 	;
@@ -1017,7 +1061,7 @@ case 13:
 {
 	  string_to_array (yyvsp[-4].sheet->alpha2, yyvsp[0].string);
 	  /* This is the syntax table used by regex */
-	  FREE (yyvsp[0].string);
+	  free (yyvsp[0].string);
 	  yyvsp[0].string = NULL;
 	  yyval.sheet = yyvsp[-4].sheet;
 	;
@@ -1083,10 +1127,10 @@ case 23:
 	  len1 = ustrlen (yyvsp[-1].string);
 	  yyvsp[-1].string[len1] = '\n';
 	  len2 = ustrlen (yyvsp[0].string);
-	  yyval.string = ALLOC (uchar, len1 + len2 + 2);
+	  yyval.string = XMALLOC (uchar, len1 + len2 + 2);
 	  ustpcpy (ustpncpy (yyval.string, yyvsp[-1].string, len1 + 1), yyvsp[0].string);
-	  FREE (yyvsp[-1].string);
-	  FREE (yyvsp[0].string);
+	  free (yyvsp[-1].string);
+	  free (yyvsp[0].string);
 	;
     break;}
 case 24:
@@ -1140,10 +1184,10 @@ case 32:
 {
 	  /* Concatenate $2 to $1 makes $$ */
 	  yyval.pattern = yyvsp[-1].pattern;
-	  yyval.pattern->pattern = REMALLOC (yyval.pattern->pattern, yyvsp[-1].pattern->len + yyvsp[0].pattern->len + 1);
+	  yyval.pattern->pattern = XREALLOC (yyval.pattern->pattern, char, yyvsp[-1].pattern->len + yyvsp[0].pattern->len + 1);
 	  strncpy (yyval.pattern->pattern + yyval.pattern->len, yyvsp[0].pattern->pattern, yyvsp[0].pattern->len);
 	  yyval.pattern->len += yyvsp[0].pattern->len;
-	  FREE (yyvsp[0].pattern->pattern);
+	  free (yyvsp[0].pattern->pattern);
 	;
     break;}
 case 33:
@@ -1260,100 +1304,106 @@ case 48:
 case 49:
 #line 427 "parsessh.y"
 {
-	  yyval.rule = rule_new (yyvsp[-1].string, NULL, yyvsp[0].array);
+	  yyval.rule = rule_new (yyvsp[-1].string, NULL, yyvsp[0].array,
+			 sshfilename, sshlineno);
 	;
     break;}
 case 50:
-#line 431 "parsessh.y"
+#line 432 "parsessh.y"
 {
 	  yyval.rule = rule_new (yyvsp[0].string, NULL,
-			   rhs_new_single (UNULL, 0, No_fface));
+			 rhs_new_single (UNULL, 0, No_fface),
+			 sshfilename, sshlineno);
 	;
     break;}
 case 51:
-#line 436 "parsessh.y"
+#line 438 "parsessh.y"
 {
-	  yyval.rule = rule_new (yyvsp[-2].string, NULL, yyvsp[-1].array);
+	  yyval.rule = rule_new (yyvsp[-2].string, NULL, yyvsp[-1].array,
+			 sshfilename, sshlineno);
 	;
     break;}
 case 52:
-#line 446 "parsessh.y"
+#line 449 "parsessh.y"
 {
 	  words_set_no_face (yyvsp[-1].words, yyvsp[-3].fface);
 	  yyval.words = yyvsp[-1].words;
 	;
     break;}
 case 53:
-#line 450 "parsessh.y"
+#line 453 "parsessh.y"
 {
   	  /* First of all, the No_face must be turned into Plain */
   	  yyval.words = yyvsp[-1].words;
 	;
     break;}
 case 54:
-#line 458 "parsessh.y"
+#line 461 "parsessh.y"
 {
 	  yyval.words = words_new ("Keywords: Strings", "Keywords: Regexps", 100, 100);
 	  words_add_string (yyval.words, yyvsp[0].rule);
 	;
     break;}
 case 55:
-#line 463 "parsessh.y"
+#line 466 "parsessh.y"
 {
 	  yyval.words = words_new ("Keywords: Strings", "Keywords: Regexps", 100, 100);
 	  words_add_regex (yyval.words, yyvsp[0].rule);
 	;
     break;}
 case 56:
-#line 468 "parsessh.y"
+#line 471 "parsessh.y"
 {
 	  words_add_string (yyvsp[-2].words, yyvsp[0].rule);
 	  yyval.words = yyvsp[-2].words;
 	;
     break;}
 case 57:
-#line 473 "parsessh.y"
+#line 476 "parsessh.y"
 {
 	  words_add_regex (yyvsp[-2].words, yyvsp[0].rule);
 	  yyval.words = yyvsp[-2].words;
 	;
     break;}
 case 58:
-#line 485 "parsessh.y"
+#line 488 "parsessh.y"
 {
-	  yyval.rule = keyword_rule_new (UNULL, yyvsp[-1].pattern, yyvsp[0].array);
+	  yyval.rule = keyword_rule_new (UNULL, yyvsp[-1].pattern, yyvsp[0].array,
+				 sshfilename, sshlineno);
 	;
     break;}
 case 59:
-#line 489 "parsessh.y"
+#line 493 "parsessh.y"
 {
 	  yyval.rule = keyword_rule_new (UNULL, yyvsp[0].pattern,
 				   rhs_new_single (UNULL, 0,
-							    No_fface));
+							    No_fface),
+				 sshfilename, sshlineno);
 	;
     break;}
 case 60:
-#line 495 "parsessh.y"
+#line 500 "parsessh.y"
 {
-	  yyval.rule = keyword_rule_new (UNULL, yyvsp[-2].pattern, yyvsp[-1].array);
+	  yyval.rule = keyword_rule_new (UNULL, yyvsp[-2].pattern, yyvsp[-1].array,
+				 sshfilename, sshlineno);
 	;
     break;}
 case 61:
-#line 503 "parsessh.y"
+#line 509 "parsessh.y"
 {
 	  words_set_no_face (yyvsp[-1].words, yyvsp[-3].fface);
 	  yyval.words = yyvsp[-1].words;
 	;
     break;}
 case 62:
-#line 507 "parsessh.y"
+#line 513 "parsessh.y"
 {
   	  /* First of all, the No_face must be turned into Plain */
   	  yyval.words = yyvsp[-1].words;
 	;
     break;}
 case 63:
-#line 515 "parsessh.y"
+#line 521 "parsessh.y"
 {
 	  yyval.words = words_new ("Operators: Strings", "Operators: Regexps",
 			  100, 100);
@@ -1361,7 +1411,7 @@ case 63:
 	;
     break;}
 case 64:
-#line 521 "parsessh.y"
+#line 527 "parsessh.y"
 {
 	  yyval.words = words_new ("Operators: Strings", "Operators: Regexps",
 			  100, 100);
@@ -1369,44 +1419,47 @@ case 64:
 	;
     break;}
 case 65:
-#line 527 "parsessh.y"
+#line 533 "parsessh.y"
 {
 	  words_add_string (yyvsp[-2].words, yyvsp[0].rule);
 	  yyval.words = yyvsp[-2].words;
 	;
     break;}
 case 66:
-#line 532 "parsessh.y"
+#line 538 "parsessh.y"
 {
 	  words_add_regex (yyvsp[-2].words, yyvsp[0].rule);
 	  yyval.words = yyvsp[-2].words;
 	;
     break;}
 case 67:
-#line 544 "parsessh.y"
+#line 550 "parsessh.y"
 {
-	  yyval.rule = rule_new (UNULL, yyvsp[-1].pattern, yyvsp[0].array);
+	  yyval.rule = rule_new (UNULL, yyvsp[-1].pattern, yyvsp[0].array,
+			 sshfilename, sshlineno);
 	;
     break;}
 case 68:
-#line 548 "parsessh.y"
+#line 555 "parsessh.y"
 {
 	  yyval.rule = rule_new (UNULL, yyvsp[0].pattern,
-			   rhs_new_single (UNULL, 0, No_fface));
+			   rhs_new_single (UNULL, 0, No_fface),
+			 sshfilename, sshlineno);
 	;
     break;}
 case 69:
-#line 553 "parsessh.y"
+#line 561 "parsessh.y"
 {
-	  yyval.rule = rule_new (UNULL, yyvsp[-2].pattern, yyvsp[-1].array);
+	  yyval.rule = rule_new (UNULL, yyvsp[-2].pattern, yyvsp[-1].array,
+			 sshfilename, sshlineno);
 	;
     break;}
 case 70:
-#line 561 "parsessh.y"
+#line 570 "parsessh.y"
 { yyval.array = yyvsp[-2].array; ;
     break;}
 case 71:
-#line 564 "parsessh.y"
+#line 573 "parsessh.y"
 {
 	  yyval.array = da_new ("Sequence tmp", 100,
 		       da_linear, 100,
@@ -1415,135 +1468,145 @@ case 71:
 	;
     break;}
 case 72:
-#line 570 "parsessh.y"
+#line 579 "parsessh.y"
 {
 	  da_append (yyvsp[-2].array, yyvsp[0].sequence);
 	  yyval.array = yyvsp[-2].array;
 	;
     break;}
 case 73:
-#line 594 "parsessh.y"
+#line 603 "parsessh.y"
 {
 	  struct rule * open_rule;
 	  open_rule = rule_new (yyvsp[-4].string, NULL,
-				    rhs_new_single (yyvsp[-3].string, 0,
-							     Symbol_fface));
+				rhs_new_single (yyvsp[-3].string, 0, Symbol_fface),
+				sshfilename, sshlineno);
 	  yyval.sequence = sequence_new (open_rule, yyvsp[-2].fface, yyvsp[-1].words, yyvsp[0].words);
 	;
     break;}
 case 74:
-#line 602 "parsessh.y"
+#line 611 "parsessh.y"
 {
 	  struct rule * open_rule;
 	  open_rule = rule_new (yyvsp[-5].string, NULL,
-				    rhs_new_single (yyvsp[-4].string, 0, yyvsp[-3].fface));
+				rhs_new_single (yyvsp[-4].string, 0, yyvsp[-3].fface),
+				sshfilename, sshlineno);
 	  yyval.sequence = sequence_new (open_rule, yyvsp[-2].fface, yyvsp[-1].words, yyvsp[0].words);
 	;
     break;}
 case 75:
-#line 609 "parsessh.y"
+#line 619 "parsessh.y"
 {
 	  struct rule * open_rule;
 	  open_rule = rule_new (yyvsp[-4].string, NULL,
-				    rhs_new_single (UNULL, 0, yyvsp[-3].fface));
+				rhs_new_single (UNULL, 0, yyvsp[-3].fface),
+				sshfilename, sshlineno);
 	  yyval.sequence = sequence_new (open_rule, yyvsp[-2].fface, yyvsp[-1].words, yyvsp[0].words);
 	;
     break;}
 case 76:
-#line 616 "parsessh.y"
+#line 627 "parsessh.y"
 {
 	  struct rule * open_rule;
 	  open_rule = rule_new (yyvsp[-4].string, NULL,
-				    rhs_new_single (yyvsp[-3].string, 0, yyvsp[-2].fface));
+				rhs_new_single (yyvsp[-3].string, 0, yyvsp[-2].fface),
+				sshfilename, sshlineno);
 	  yyval.sequence = sequence_new (open_rule, yyvsp[-2].fface, yyvsp[-1].words, yyvsp[0].words);
 	;
     break;}
 case 77:
-#line 623 "parsessh.y"
+#line 635 "parsessh.y"
 {
 	  struct rule * open_rule;
 	  open_rule = rule_new (yyvsp[-3].string, NULL,
-				    rhs_new_single (UNULL, 0, yyvsp[-2].fface));
+				rhs_new_single (UNULL, 0, yyvsp[-2].fface),
+				sshfilename, sshlineno);
 	  yyval.sequence = sequence_new (open_rule, yyvsp[-2].fface, yyvsp[-1].words, yyvsp[0].words);
 	;
     break;}
 case 78:
-#line 630 "parsessh.y"
+#line 643 "parsessh.y"
 {
 	  struct rule * open_rule;
 	  open_rule = rule_new (UNULL, yyvsp[-5].pattern,
-				    rhs_new_single (yyvsp[-4].string, 0, yyvsp[-3].fface));
+				rhs_new_single (yyvsp[-4].string, 0, yyvsp[-3].fface),
+				sshfilename, sshlineno);
 	  yyval.sequence = sequence_new (open_rule, yyvsp[-2].fface, yyvsp[-1].words, yyvsp[0].words);
 	;
     break;}
 case 79:
-#line 637 "parsessh.y"
+#line 651 "parsessh.y"
 {
 	  struct rule * open_rule;
 	  open_rule = rule_new (UNULL, yyvsp[-4].pattern,
-				    rhs_new_single (UNULL, 0, yyvsp[-3].fface));
+				rhs_new_single (UNULL, 0, yyvsp[-3].fface),
+				sshfilename, sshlineno);
 	  yyval.sequence = sequence_new (open_rule, yyvsp[-2].fface, yyvsp[-1].words, yyvsp[0].words);
 	;
     break;}
 case 80:
-#line 644 "parsessh.y"
+#line 659 "parsessh.y"
 {
 	  struct rule * open_rule;
 	  open_rule = rule_new (UNULL, yyvsp[-4].pattern,
-				    rhs_new_single (yyvsp[-3].string, 0, yyvsp[-2].fface));
+				rhs_new_single (yyvsp[-3].string, 0, yyvsp[-2].fface),
+				sshfilename, sshlineno);
 	  yyval.sequence = sequence_new (open_rule, yyvsp[-2].fface, yyvsp[-1].words, yyvsp[0].words);
 	;
     break;}
 case 81:
-#line 651 "parsessh.y"
+#line 667 "parsessh.y"
 {
 	  struct rule * open_rule;
 	  open_rule = rule_new (UNULL, yyvsp[-3].pattern,
-				    rhs_new_single (UNULL, 0,
-							     No_fface));
+				rhs_new_single (UNULL, 0, No_fface),
+				sshfilename, sshlineno);
 	  yyval.sequence = sequence_new (open_rule, yyvsp[-2].fface, yyvsp[-1].words, yyvsp[0].words);
 	;
     break;}
 case 82:
-#line 659 "parsessh.y"
+#line 675 "parsessh.y"
 {
 	  struct rule * open_rule;
-	  open_rule = rule_new (yyvsp[-5].string, NULL, yyvsp[-4].array);
+	  open_rule = rule_new (yyvsp[-5].string, NULL, yyvsp[-4].array,
+				sshfilename, sshlineno);
 	  yyval.sequence = sequence_new (open_rule, yyvsp[-2].fface, yyvsp[-1].words, yyvsp[0].words);
 	;
     break;}
 case 83:
-#line 665 "parsessh.y"
+#line 682 "parsessh.y"
 {
 	  struct rule * open_rule;
-	  open_rule = rule_new (UNULL, yyvsp[-5].pattern, yyvsp[-4].array);
+	  open_rule = rule_new (UNULL, yyvsp[-5].pattern, yyvsp[-4].array,
+				sshfilename, sshlineno);
 	  yyval.sequence = sequence_new (open_rule, yyvsp[-2].fface, yyvsp[-1].words, yyvsp[0].words);
 	;
     break;}
 case 84:
-#line 672 "parsessh.y"
+#line 690 "parsessh.y"
 {
 	  yyval.sequence = new_C_string_sequence ("\"");
 	;
     break;}
 case 85:
-#line 676 "parsessh.y"
+#line 694 "parsessh.y"
 {
 	  yyval.sequence = new_C_string_sequence ("\'");
 	;
     break;}
 case 86:
-#line 683 "parsessh.y"
+#line 701 "parsessh.y"
 {
 	  /* This is a shortcut which means "up to the end of the line". */
 	  yyval.words = words_new ("Closing: Strings", "Closing: Regexps", 2, 2);
 	  words_add_string (yyval.words, rule_new (xustrdup ("\n"), NULL,
 					  rhs_new_single (NULL, 0,
-							  No_fface)));
+							  No_fface),
+					  sshfilename, sshlineno));
 	;
     break;}
 case 87:
-#line 691 "parsessh.y"
+#line 710 "parsessh.y"
 {
 	  /* Only one */
 	  yyval.words = words_new ("Closing: Strings", "Closing: Regexps", 2, 2);
@@ -1551,7 +1614,7 @@ case 87:
 	;
     break;}
 case 88:
-#line 697 "parsessh.y"
+#line 716 "parsessh.y"
 {
 	  /* Only one */
 	  yyval.words = words_new ("Closing: Strings", "Closing: Regexps", 2, 2);
@@ -1559,27 +1622,27 @@ case 88:
 	;
     break;}
 case 89:
-#line 703 "parsessh.y"
+#line 722 "parsessh.y"
 {
 	  /* Several, comma separated, between () */
 	  yyval.words = yyvsp[-1].words;
 	;
     break;}
 case 90:
-#line 711 "parsessh.y"
+#line 730 "parsessh.y"
 {
 	  yyval.words = words_new ("Exceptions: Strings", "Exceptions: Regexps", 1, 1);
 	;
     break;}
 case 91:
-#line 715 "parsessh.y"
+#line 734 "parsessh.y"
 {
 	  yyval.words = yyvsp[-1].words;
 	;
     break;}
 }
    /* the action file gets copied in in place of this dollarsign */
-#line 498 "/usr/local/share/bison.simple"
+#line 543 "/usr/share/misc/bison.simple"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -1774,8 +1837,32 @@ yyerrhandle:
 
   yystate = yyn;
   goto yynewstate;
+
+ yyacceptlab:
+  /* YYACCEPT comes here.  */
+  if (yyfree_stacks)
+    {
+      free (yyss);
+      free (yyvs);
+#ifdef YYLSP_NEEDED
+      free (yyls);
+#endif
+    }
+  return 0;
+
+ yyabortlab:
+  /* YYABORT comes here.  */
+  if (yyfree_stacks)
+    {
+      free (yyss);
+      free (yyvs);
+#ifdef YYLSP_NEEDED
+      free (yyls);
+#endif
+    }
+  return 1;
 }
-#line 719 "parsessh.y"
+#line 738 "parsessh.y"
 
 
 void
@@ -1829,7 +1916,7 @@ parse_style_sheet (const char * filename)
   sshlex_initialize ();
 
   if (msg_test (msg_parse))
-    yydebug = TRUE;
+    yydebug = true;
   res = yyparse ();  /* FIXME: test the result of parsing */
 
   if (msg_test (msg_sheet)) {
