@@ -1,9 +1,6 @@
 /*
- * select.c
- *
- * Selection of a style sheet
- * Copyright (c) 1988, 89, 90, 91, 92, 93 Miguel Santana
- * Copyright (c) 1995, 96, 97, 98 Akim Demaille, Miguel Santana
+ * select.c -- Selection of a style sheet
+ * Copyright (c) 1995-99 Akim Demaille, Miguel Santana
  *
  */
 
@@ -26,16 +23,12 @@
  * Boston, MA 02111-1307, USA.
  */
 
-/*
- * $Id: select.c,v 1.51 1998/03/03 11:47:10 demaille Exp $
- */
-
 #include "a2ps.h"
 #include "select.h"
 #include "routines.h"
 #include "xfnmatch.h"
 #include "getshline.h"
-#include "pathconcat.h"
+#include "path-concat.h"
 #include "pathwalk.h"
 #include "filtdir.h"
 #include "message.h"
@@ -70,17 +63,19 @@ struct pattern_rule
   const char * pattern;
   const char * command;
   int on_file_verdict;
+  bool insensitive_p;
 };
 
-static struct pattern_rule *
-pattern_rule_new (const char * pattern, int on_file_verdict,
-		  const char * command)
+struct pattern_rule *
+pattern_rule_new (const char *pattern, int on_file_verdict, bool insensitive_p,
+		  const char *command)
 {
-  struct pattern_rule * res = ALLOC (struct pattern_rule, 1);
+  NEW (struct pattern_rule, res);
 
   res->pattern = pattern;
   res->on_file_verdict = on_file_verdict;
   res->command = command;
+  res->insensitive_p = insensitive_p;
 
   return res;
 }
@@ -88,15 +83,11 @@ pattern_rule_new (const char * pattern, int on_file_verdict,
 static void
 pattern_rule_self_print (struct pattern_rule * item, FILE * stream)
 {
-  switch (item->on_file_verdict)
-    {
-    case TRUE:
-      fprintf (stream, "file/%s: %s\n", item->pattern, item->command);
-      break;
-    case FALSE:
-      fprintf (stream, "name/%s: %s\n", item->pattern, item->command);
-      break;
-  }
+  fprintf (stream, "%s/%s: %s/%s\n",
+	   item->on_file_verdict ? "file" : "name",
+	   item->pattern,
+	   item->command,
+	   item->insensitive_p ? "i" : "");
 }
 
 struct darray *
@@ -107,72 +98,15 @@ sheets_map_new (void)
 		 (da_print_func_t) pattern_rule_self_print, NULL);
 }
 
-#define GET_TOKEN(from) (strtok ((from), " \t\n"))
-#define GET_LINE_TOKEN(from) (strtok ((from), "\n"))
-
-#define CHECK_TOKEN() 							\
-  if (token2 == NULL) 							\
-    error_at_line (1, 0, file, firstline, 				\
-		   _("missing style sheet name for pattern: %s"),	\
-		   quotearg (token));
-
-/*
- * Read a sheets map file
- */
-static int
-sheets_map_load (const char *file)
+void
+sheets_map_add (const char * pattern, int on_file_verdict, bool insensitive_p,
+		const char * key)
 {
-  FILE * fp;
-  char *buf = NULL;
-  size_t bufsiz = 0;
-  char *token, *token2;
-  int firstline = 0, lastline = 0;
-
-  message (msg_file, (stderr, "Loading sheets map `%s'\n", file));
-
-  fp = xrfopen (file);
-
-  while (getshline_numbered (&firstline, &lastline, &buf, &bufsiz, fp) != -1)
-    {
-      token = GET_TOKEN (buf);
-
-      if (!token)
-	/* Empty line */
-	continue;
-
-      if (strequ (token, "**"))
-	{
-	  /* Pattern on result of file(1) */
-	  token = GET_TOKEN (NULL);	/* Pattern	*/
-	  token2 = GET_TOKEN (NULL);	/* Name		*/
-	  CHECK_TOKEN ();
-	  da_append (sheets_map,
-		     pattern_rule_new (xstrdup (token), TRUE,
-				       xstrdup (token2)));
-	}
-      else if (strequ (token, "***"))
-	{
-	  /* Load another sheets map */
-	  token2 = GET_TOKEN (NULL);	/* Sheets.map path	*/
-	  CHECK_TOKEN ();
-	  sheets_map_load (token2);
-	}
-      else
-	{
-	  /* Pattern on the file's name */
-	  token2 = GET_TOKEN (NULL);	/* Name		*/
-	  CHECK_TOKEN ();
-	  da_append (sheets_map,
-		     pattern_rule_new (xstrdup (token), FALSE,
-				       xstrdup (token2)));
-	}
-    }
-
-  FREE (buf);
-  fclose (fp);
-  return 1;
+  da_append (sheets_map,
+	     pattern_rule_new (pattern, on_file_verdict, insensitive_p, key));
 }
 
+
 /*
  * Read the sheets.map file
  */
@@ -193,18 +127,18 @@ sheets_map_load_main (void)
 
   sheets_map_load (file);
 
-  FREE (file);
+  free (file);
   return 1;
 }
 
-/*
- * What says file about the type of a file (result is malloc'd)
- */
-char *
+/* What says file about the type of a file (result is malloc'd).  NULL
+  if could not be run.  */
+
+static char *
 file_verdict_on (const uchar *filename)
 {
-  char * res = NULL, * command;
-  char buf [1024], field1 [512], field2 [512];
+  char *cp = NULL, * command;
+  char buf [1024];
   FILE * file_out;
 
   if (IS_EMPTY (job->file_command))
@@ -232,26 +166,23 @@ file_verdict_on (const uchar *filename)
   pclose (file_out);
   message (msg_tool, (stderr, "file(1): %s", buf));
 
-  /* Treat the answer:
-   * the two first fields are of interest */
-  switch (sscanf (buf, "%*[^:]: %511s%511s", field1, field2))
+  /* File is expected to answer:
+     filename: file-answer. */
+  cp = buf;
+  while (*cp && *cp != ':')
+    cp++;
+  cp++;
+  while (*cp && ((*cp == ' ') || (*cp == '\t')))
+    cp++;
+
+  if (*cp)
     {
-    case 2:
-      res = MALLOC (strlen (field1) + strlen (field2) + 1);
-      sprintf (res, "%s%s", field1, field2);
-      break;
-
-    case 1:
-      res = xstrdup (field1);
-      break;
-
-    default:
-      message (msg_tool, (stderr, "sscanf failed\n"));
-      return NULL;
+      if (cp)
+	message (msg_tool, (stderr, "File's verdict: %s", cp));
+      /* Don't return the `\n'. */
+      return xstrndup (cp, strlen (cp) - 1);
     }
-  if (res)
-    message (msg_tool, (stderr, "File's verdict: `%s'\n", res));
-  return res;
+  return NULL;
 }
 
 /*
@@ -260,10 +191,11 @@ file_verdict_on (const uchar *filename)
  */
 #define rule(_i_) ((struct pattern_rule *)sheets_map->content[_i_])
 const char *
-get_command (const uchar * name_to_match, const uchar * name_to_file)
+get_command (const uchar *name_to_match, const uchar *name_to_file)
 {
   int i;
-  char * file_verdict;
+  char *file_verdict;
+  uchar *name_to_match_lc;
 
   /* We only want to read the sheets map if needed, hence,
    * from here (not needed if the sheet name is given by the
@@ -271,7 +203,15 @@ get_command (const uchar * name_to_match, const uchar * name_to_file)
   if (da_is_empty (sheets_map))
     sheets_map_load_main ();
 
+
+  /* Get file(1)'s verdict, and get a lowercase version of the
+     filename.  */
   file_verdict = file_verdict_on (name_to_file);
+  if (name_to_match)
+    {
+      name_to_match_lc = ALLOCA (char, strlen (name_to_match) + 1);
+      strcpylc (name_to_match_lc, name_to_match);
+    }
 
   /* We look from bottom up, so that most recently defined rules are
    * honored.  Make sure not to call fnmatch on an empty FILE_VERDICT
@@ -279,45 +219,31 @@ get_command (const uchar * name_to_match, const uchar * name_to_file)
    * Christian Mondrup <scancm@biobase.dk> and Jens Henrik Leonhard
    * Jensen recjhl@mediator.uni-c.dk) */
   /* The loop is split to speed up */
-  if (file_verdict && name_to_match)
-    {
-      for (i = sheets_map->len - 1 ; i >= 0 ; i--)
-	if (rule(i)->on_file_verdict)
+  for (i = sheets_map->len - 1 ; i >= 0 ; i--)
+    if (rule(i)->on_file_verdict)
+      {
+	/* Testing upon file's result */
+	if (file_verdict
+	    && !fnmatch (rule(i)->pattern, file_verdict, 0))
 	  {
-	    /* Testing upon file's result */
-	    if (!fnmatch (rule(i)->pattern, file_verdict, 0)) {
-	      XFREE (file_verdict);
-	      return rule(i)->command;
-	    }
-	  } else {
-	    /* Upon file name */
-	    if (!fnmatch (rule(i)->pattern, (const char *) name_to_match, 0)) {
-	      XFREE (file_verdict);
-	      return rule(i)->command;
-	    }
+	    free (file_verdict);
+	    return rule(i)->command;
 	  }
-      FREE (file_verdict);
-    }
-  else if (name_to_match)
-    {
-      for (i = sheets_map->len - 1 ; i >= 0 ; i--)
-	if (!rule(i)->on_file_verdict)
-	  /* Upon file name */
-	  if (!fnmatch (rule(i)->pattern, (const char *) name_to_match, 0)) {
+      }
+    else
+      {
+	/* Upon file name */
+	if (name_to_match
+	    && !fnmatch (rule(i)->pattern,
+			 (char *) (rule(i)->insensitive_p
+				   ? name_to_match_lc : name_to_match),
+			 0))
+	  {
 	    XFREE (file_verdict);
 	    return rule(i)->command;
 	  }
-    }
-  else if (file_verdict)
-    {
-      for (i = sheets_map->len - 1 ; i >= 0 ; i--)
-	if (rule(i)->on_file_verdict)
-	  /* Testing upon file's result */
-	  if (!fnmatch (rule(i)->pattern, file_verdict, 0)) {
-	    XFREE (file_verdict);
-	    return rule(i)->command;
-	  }
-    }
+      }
+  XFREE (file_verdict);
 
   return "plain";
 }
