@@ -1,10 +1,9 @@
 /*
- * ssheet.c
+ * ssheet.c -- definition of the languages style sheets
+ *
+ * Copyright (c) 1988-93 Miguel Santana
+ * Copyright (c) 1995-99 Akim Demaille, Miguel Santana
  *
- * definition of the languages style sheets
- * Copyright (c) 1988, 89, 90, 91, 92, 93 Miguel Santana
- * Copyright (c) 1995, 96, 97, 98 Akim Demaille, Miguel Santana
- * $Id: ssheet.c 1.2.1.3 Thu, 22 Oct 1998 14:21:51 +0200 demaille $
  */
 
 /*
@@ -33,7 +32,6 @@
 #include "jobs.h"
 #include "message.h"
 #include "filtdir.h"
-#include "xalloca.h"
 #include "versions.h"
 #include "document.h"
 #include "metaseq.h"
@@ -63,19 +61,17 @@ static inline void style_sheets_versions PARAMS ((struct darray * keys,
 						  int requirement [4]));
 
 /* return true iff OK */
-static boolean style_sheet_check PARAMS ((struct style_sheet * sheet));
+static bool style_sheet_check PARAMS ((struct style_sheet * sheet));
 
-/* We drop in the alphabets[0] a special value, which cannot
- * be defined by the definition of the alphabets.  It allows
- * to see if the alphabets were defined or not, so that
- * the default alphabets can be set when finalizing the sheet.
- * Note that we cannot set the default alphabets a priori,
- * because we need to be able to inherit from ancestors
- */
+/* We drop in the alphabets[0] an invalid value.  It allows to see if
+ * the alphabets were defined or not, so that the default alphabets
+ * can be set when finalizing the sheet.  Note that we cannot set the
+ * default alphabets a priori, because we need to be able to inherit
+ * from ancestors. */
 #define ALPHABET_UNDEFINED_TAG	127
 #define ALPHABET_IS_UNDEFINED(_alpha_)	\
 	((_alpha_)[0] == ALPHABET_UNDEFINED_TAG)
-#define UNDEFINE_ALPHABET(_alpha_)	\
+#define ALPHABET_UNDEFINE(_alpha_)	\
 	((_alpha_)[0] = ALPHABET_UNDEFINED_TAG)
 
 #define DEFAULT_ALPHA1 ((const uchar *) \
@@ -83,22 +79,29 @@ static boolean style_sheet_check PARAMS ((struct style_sheet * sheet));
 #define DEFAULT_ALPHA2 ((const uchar *) \
 	"abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ_0123456789")
 
-#define alpha_self_print(a,s)	\
-   do {				\
-     int c;			\
-     fputc ('\"', s);		\
-     for (c = 0 ; c < 256 ; c++)\
-       if (a [c])		\
-	 fputc (c, s);		\
-     fputs ("\"\n", s);		\
-   } while (0)
+static void
+alphabet_self_print (char *a, FILE *s)
+{
+  if (ALPHABET_IS_UNDEFINED (a))
+    fputs ("<undefined>\n", s);
+  else
+    {
+      int c;
+
+      fputc ('\"', s);
+      for (c = 0 ; c < 256 ; c++)
+	if (a [c])
+	  fputc (c, s);
+      fputs ("\"\n", s);
+    }
+}
 
 #define DEFAULT_SENSITIVENESS case_insensitive
 
 struct pattern *
 new_pattern (char * pattern, size_t len)
 {
-  struct pattern * res = ALLOC (struct pattern, 1);
+  struct pattern * res = XMALLOC (struct pattern, 1);
   res->pattern = pattern;
   res->len = len;
   return res;
@@ -110,7 +113,7 @@ new_pattern (char * pattern, size_t len)
 struct faced_string *
 faced_string_new (uchar * string, int reg_ref, struct fface_s face)
 {
-  struct faced_string * res = ALLOC (struct faced_string, 1);
+  struct faced_string * res = XMALLOC (struct faced_string, 1);
   res->string = string;
   res->reg_ref = reg_ref;
   res->face = face;
@@ -135,7 +138,7 @@ inline static void
 faced_string_free (struct faced_string * faced_string)
 {
   XFREE (faced_string->string);
-  FREE (faced_string);
+  free (faced_string);
 }
 
 /*
@@ -160,7 +163,7 @@ style_sheet_set_version (struct style_sheet * sheet,
 
 /*
  * Set the version of a2ps required for the processing of SHEET.
- * Return FALSE if the requirement is higher than VERSION.
+ * Return false if the requirement is higher than VERSION.
  */
 int
 style_sheet_set_requirement (struct style_sheet * sheet,
@@ -172,9 +175,9 @@ style_sheet_set_requirement (struct style_sheet * sheet,
   string_to_version (VERSION, a2ps_version);
 
   if (version_cmp (sheet->requirement, a2ps_version) > 0)
-    return FALSE;
+    return false;
 
-  return TRUE;
+  return true;
 }
 
 /************************************************************************/
@@ -251,10 +254,10 @@ rhs_self_print (struct darray * rhs, FILE * stream)
  * Dealing with the rules and operators
  */
 inline static struct rule *
-new_rule_internal_word (uchar * word,
-			  struct darray * rhs)
+rule_new_internal_word (uchar * word,
+			struct darray * rhs)
 {
-  struct rule * res = ALLOC (struct rule, 1);
+  struct rule * res = XMALLOC (struct rule, 1);
 
   res->word = word;
   res->regex = NULL;
@@ -266,30 +269,32 @@ new_rule_internal_word (uchar * word,
  * Dealing with the rules and operators
  */
 inline static struct rule *
-new_rule_internal_regexp (struct pattern * pattern,
-			  char * pattern_to_compile, int pattern_len,
-			  struct darray * rhs)
+rule_new_internal_regexp (struct pattern *pattern,
+			  char *regexp, int regexp_len,
+			  struct darray *rhs,
+			  const char *filename, size_t line)
 {
-  struct rule * res = ALLOC (struct rule, 1);
-  const char * error_msg;
+  struct rule *res = XMALLOC (struct rule, 1);
+  const char *error_msg;
+
   /* This is a regular expression.  We want to keep the original
    * pattern to ease the debugging of a style sheet */
   res->word = (uchar *) pattern->pattern;
 
   /* Build the regex structure, and compile the pattern */
-  res->regex = ALLOC (struct re_pattern_buffer, 1);
+  res->regex = XMALLOC (struct re_pattern_buffer, 1);
   res->regex->translate = NULL;
   res->regex->fastmap = NULL;
   res->regex->buffer = NULL;
   res->regex->allocated = 0;
 
-  error_msg = re_compile_pattern (pattern_to_compile, pattern_len,
-				  res->regex);
+  error_msg = re_compile_pattern (regexp, regexp_len, res->regex);
   /* The pattern is nul terminated, no fear to have */
   if (error_msg)
-    error (1, 0, _("cannot compile regular expression `%s': %s"),
-	   quotearg (pattern_to_compile), error_msg);
-  FREE (pattern);
+    error_at_line (1, 0, filename, line,
+		   _("cannot compile regular expression `%s': %s"),
+		   regexp, error_msg);
+  free (pattern);
   res->rhs = rhs;
   return res;
 }
@@ -299,47 +304,56 @@ new_rule_internal_regexp (struct pattern * pattern,
  */
 struct rule *
 rule_new (uchar * word, struct pattern * pattern,
-	    struct darray * rhs)
+	  struct darray * rhs,
+	  const char *filename, size_t line)
 {
   if (pattern)
-    return new_rule_internal_regexp (pattern,
-				       pattern->pattern, pattern->len,
-				       rhs);
+    return rule_new_internal_regexp (pattern,
+				     pattern->pattern, pattern->len,
+				     rhs,
+				     filename, line);
   else
-    return new_rule_internal_word (word,
-				     rhs);
+    return rule_new_internal_word (word,
+				   rhs);
 }
 
-/*
- * Dealing with the rules and operators
- * This is pretty much the same as the previous case,
- * but the difference is that the regexp much be built appending
- * a \\b at the end, to make sure that, for instance,
- * as a keyword matcher /c*f/ does not match "ccfe": the keyword
- * is not separated.
- */
+
+/*-------------------------------------------------------------------.
+| Dealing with the rules and operators.  This is pretty much the     |
+| same as the previous case, but the difference is that the regexp   |
+| must be built appending a `\\b' at the end, to make sure that, for |
+| instance, as a keyword matcher `/c*f/' does not match `ccfe': the  |
+| keyword is not separated.                                          |
+`-------------------------------------------------------------------*/
+
 struct rule *
 keyword_rule_new (uchar * word, struct pattern * pattern,
-		    struct darray * rhs)
+		  struct darray * rhs,
+		  const char *filename, size_t line)
 {
   int pattern_len = 0;
   char * pattern_to_compile = NULL;
 
   if (pattern)
     {
-      pattern_len = pattern->len + strlen ("\\b\\(\\)\\b");
+      pattern_len = pattern->len + strlen ("\\b()\\b");
       pattern_to_compile = ALLOCA (char, pattern_len + 1);
-      sprintf (pattern_to_compile, "\\b\\(%s\\)\\b", pattern->pattern);
-      return new_rule_internal_regexp (pattern,
-					 pattern_to_compile, pattern_len,
-					 rhs);
+      sprintf (pattern_to_compile, "\\b(%s)\\b", pattern->pattern);
+      return rule_new_internal_regexp (pattern,
+				       pattern_to_compile, pattern_len,
+				       rhs,
+				       filename, line);
     }
   else
-    return new_rule_internal_word (word,
-				     rhs);
+    return rule_new_internal_word (word,
+				   rhs);
 }
 
 
+/*--------------.
+| Free a rule.  |
+`--------------*/
+
 static void
 free_rule (struct rule * rule)
 {
@@ -347,10 +361,10 @@ free_rule (struct rule * rule)
   if (rule->regex)
     {
       regfree (rule->regex);
-      FREE (rule->regex);
+      free (rule->regex);
     }
   da_free (rule->rhs, (da_map_func_t) faced_string_free);
-  FREE (rule);
+  free (rule);
 }
 
 /*
@@ -406,7 +420,7 @@ words_new (/* Regular darray parameters */
 	      size_t size, size_t increment)
 {
   int c;
-  struct words * res = ALLOC (struct words, 1);
+  struct words * res = XMALLOC (struct words, 1);
 
   /* Initialize the underlying darray of strings */
   res->strings = da_new (name_strings, size,
@@ -434,7 +448,7 @@ words_erase (struct words * words)
   da_erase (words->strings);
   da_erase (words->regexps);
 
-  FREE (words);
+  free (words);
 }
 
 void
@@ -442,7 +456,7 @@ words_free (struct words * words)
 {
   da_free (words->strings, (da_map_func_t) free_rule);
   da_free (words->regexps, (da_map_func_t) free_rule);
-  FREE (words);
+  free (words);
 }
 
 static void
@@ -608,7 +622,7 @@ sequence_new (struct rule * Open,
 	      struct words * Close,
 	      struct words * exceptions)
 {
-  struct sequence * res = ALLOC (struct sequence, 1);
+  struct sequence * res = XMALLOC (struct sequence, 1);
 
   /* Make sure to set the face of those with No_fface */
   rule_set_no_face (Open, in_face);
@@ -635,7 +649,7 @@ free_sequence (struct sequence * sequence)
   free_rule (sequence->open);
   words_free (sequence->close);
   words_free (sequence->exceptions);
-  FREE (sequence);
+  free (sequence);
 }
 
 /*
@@ -644,8 +658,9 @@ free_sequence (struct sequence * sequence)
 #define C_add_exception(_excep_)					\
   words_add_string (res,						\
 	     rule_new (xustrdup (_excep_), NULL,			\
-			 rhs_new_single (xustrdup (_excep_), 0,\
-						 String_fface)));
+		       rhs_new_single (xustrdup (_excep_), 0, String_fface),\
+                       __FILE__, __LINE__));
+
 static struct words *
 new_C_exceptions (void)
 {
@@ -665,15 +680,17 @@ new_C_exceptions (void)
 struct sequence *
 new_C_string_sequence (const char * delimitor)
 {
-  struct sequence * res = ALLOC (struct sequence, 1);
+  struct sequence * res = XMALLOC (struct sequence, 1);
   res->open = rule_new (xustrdup (delimitor), NULL,
-			  rhs_new_single (NULL, 0, Plain_fface));
+			rhs_new_single (NULL, 0, Plain_fface),
+			__FILE__, __LINE__);
   res->face = String_fface;
   res->exceptions = new_C_exceptions ();
   res->close = words_new ("C Close: strings", "C Close: regex", 5, 5);
   words_add_string (res->close,
 		    rule_new (xustrdup (delimitor), NULL,
-			      rhs_new_single (NULL, 0, Plain_fface)));
+			      rhs_new_single (NULL, 0, Plain_fface),
+			      __FILE__, __LINE__));
   words_finalize (res->close);
   return res;
 }
@@ -708,8 +725,8 @@ new_style_sheet (const uchar * name)
   res->ancestors = ancestors_new ();
   res->sensitiveness = case_undefined;
 
-  UNDEFINE_ALPHABET (res->alpha1);
-  UNDEFINE_ALPHABET (res->alpha2);
+  ALPHABET_UNDEFINE (res->alpha1);
+  ALPHABET_UNDEFINE (res->alpha2);
 
   res->keywords =  words_new ("Keywords: Strings", "Keywords: Regexps",
 			      100, 100);
@@ -724,7 +741,10 @@ new_style_sheet (const uchar * name)
 }
 
 
-/* Build a style sheet which is only defined by ancestors. */
+/*---------------------------------------------------------.
+| Build a style sheet which is only defined by ancestors.  |
+`---------------------------------------------------------*/
+
 static char *
 style_sheet_mixed_new (const uchar * ancestors)
 {
@@ -734,7 +754,7 @@ style_sheet_mixed_new (const uchar * ancestors)
   struct darray *ancestors_array;
 
   /* It cannot be longer than ancestors_keys. */
-  key = ALLOCA (char, strlen (ancestors) + 1);
+  key = ALLOCA (char, ustrlen (ancestors) + 1);
   astrcpy (ancestors_keys, ancestors);
 
   /* Create the darray of ancestors keys, and build the final key. */
@@ -751,14 +771,14 @@ style_sheet_mixed_new (const uchar * ancestors)
       *cp++ =',';
       cp = stpcpy (cp, ancestor->key);
     }
-  *cp = NUL;
+  *cp = '\0';
   key = xstrdup (key);
 
   /* Create the style sheet. */
   message (msg_sheet,
 	   (stderr, "Creating a mixed style sheet \"%s\"\n", key));
   /* Its name is its key. */
-  sheet = new_style_sheet (key);
+  sheet = new_style_sheet ((uchar *) key);
   sheet->key = strdup (key);
   da_concat (sheet->ancestors, ancestors_array);
   da_erase (ancestors_array);
@@ -767,12 +787,13 @@ style_sheet_mixed_new (const uchar * ancestors)
   return key;
 }
 
-/*
- * Once a style sheet has been read, make it usable (sorts etc.)
- * NOTE: It must _not_ be called from the parser, since
- *       it may call another time the parser, in case one of
- *       the ancestors are not known.
- */
+/*-----------------------------------------------------------------.
+| Once a style sheet has been read, make it usable (sorts etc.).   |
+|                                                                  |
+| NOTE: It must _not_ be called from the parser, since it may call |
+| another time the parser, in case one of the ancestors are not    |
+| known.                                                           |
+`-----------------------------------------------------------------*/
 void
 style_sheet_finalize (struct style_sheet * sheet)
 {
@@ -846,7 +867,7 @@ load_style_sheet (const char * pseudo_key)
 	  return NULL;
 	}
       res = parse_style_sheet (path);
-      FREE (path);
+      free (path);
     }
 
   /* Now, finalize it, and store it in the hash tab */
@@ -886,8 +907,10 @@ style_sheet_self_print (struct style_sheet * sheet, FILE * stream)
       size_t i;
       fprintf (stream, "It inherits from: ");
       for (i = 0 ; i < sheet->ancestors->len ; i++)
-	fprintf (stream, "%s ", (char *) sheet->ancestors->content [i]);
-      fputs ("\n", stream);
+	fprintf (stream, "%s%s",
+		 i ? ", " : "",
+		 (char *) sheet->ancestors->content [i]);
+      fputs (".\n", stream);
     }
 
   fprintf (stream, "Case %ssensitive\n",
@@ -895,16 +918,9 @@ style_sheet_self_print (struct style_sheet * sheet, FILE * stream)
 
   /* Alphabets */
   fputs ("First alphabet is ", stream);
-  if (ALPHABET_IS_UNDEFINED (sheet->alpha1))
-    fputs ("<undefined>\n", stream);
-  else
-    alpha_self_print (sheet->alpha1, stream);
-
+  alphabet_self_print (sheet->alpha1, stream);
   fputs ("Second alphabet is ", stream);
-  if (ALPHABET_IS_UNDEFINED (sheet->alpha2))
-    fputs ("<undefined>\n", stream);
-  else
-    alpha_self_print (sheet->alpha2, stream);
+  alphabet_self_print (sheet->alpha2, stream);
 
   words_self_print (sheet->keywords, stream);
   words_self_print (sheet->operators, stream);
@@ -920,7 +936,7 @@ style_sheet_print_signature (FILE * stream, struct style_sheet * sheet)
 {
   int i, title_bar_len;
 
-  if (!version_is_null (sheet->version))
+  if (!version_null_p (sheet->version))
     {
       title_bar_len = (strlen (" (.ssh version )")
 		       + ustrlen (sheet->name)
@@ -997,36 +1013,42 @@ list_style_sheets_long (FILE * stream)
 static void
 style_sheet_html_print_signature (FILE * stream, struct style_sheet * sheet)
 {
-  if (version_is_null (sheet->version))
+  if (version_null_p (sheet->version))
     fprintf (stream,
 	     "<li><p><strong><a href=\"%s.ssh\" name=\"%s\">%s</a></strong>.</p>\n",
 	     sheet->key, sheet->key, sheet->name);
-  else {
-    fprintf (stream,
-	     "<li><p><strong><a href=\"%s.ssh\" name=\"%s\">%s</a></strong> version ",
-	     sheet->key, sheet->key, sheet->name);
-    version_self_print (sheet->version, stream);
-    fputs (".</p>\n", stream);
-  }
+  else
+    {
+      fprintf (stream,
+	       "<li><p><strong><a href=\"%s.ssh\" name=\"%s\">%s</a></strong> version ",
+	       sheet->key, sheet->key, sheet->name);
+      version_self_print (sheet->version, stream);
+      fputs (".</p>\n", stream);
+    }
 
   if (!IS_EMPTY(sheet->author)
-      || !version_is_null(sheet->requirement)
+      || !version_null_p(sheet->requirement)
       || (sheet->ancestors->len > 0))
     {
       fputs ("<p>", stream);
       authors_print_html (sheet->author, stream, "Written by ");
-      if (!version_is_null (sheet->requirement)) {
-	fputs ("It requires a2ps version ", stream);
-	version_self_print (sheet->requirement, stream);
-	fputs (".\n", stream);
-      }
-      if (sheet->ancestors->len > 0) {
-	size_t i;
-	fputs ("It inherits from: ", stream);
-	for (i = 0 ; i < sheet->ancestors->len ; i++)
-	  fprintf (stream, "%s.ssh ", (char *) sheet->ancestors->content [i]);
-	fputs (".  \n", stream);
-      }
+      if (!version_null_p (sheet->requirement))
+	{
+	  fputs ("It requires a2ps version ", stream);
+	  version_self_print (sheet->requirement, stream);
+	  fputs (".\n", stream);
+	}
+      if (sheet->ancestors->len > 0)
+	{
+	  size_t i;
+	  fputs ("It inherits from: ", stream);
+	  for (i = 0 ; i < sheet->ancestors->len ; i++)
+	    fprintf (stream, "%s<a href=\"#%s\">%s.ssh</a>",
+		     i ? ", " : "",
+		     (char *) sheet->ancestors->content [i],
+		     (char *) sheet->ancestors->content [i]);
+	  fputs (".\n", stream);
+	}
       fputs ("</p>", stream);
     }
 
@@ -1045,7 +1067,8 @@ list_style_sheets_html (FILE * stream)
   struct style_sheet * sheet;
   struct darray * entries;
   size_t i;
-  int version_index[4], requirement [4], rows;
+  version_t version_index, requirement;
+  int rows;
 
   entries = pw_glob_on_suffix (job->common.path, SSH_SUFFIX);
 
@@ -1058,7 +1081,9 @@ list_style_sheets_html (FILE * stream)
   /*
    * The HTML header.  It should definitely be taken out of here.
    */
-  fputs (expand_user_string (job, CURRENT_FILE (job), "sheets.html generation",
+  fputs ((char *) expand_user_string (job,
+				      CURRENT_FILE (job),
+				      "sheets.html generation",
 "<html>\n\
 #{html.begin.hook}\n\
 <head>\n\
@@ -1075,7 +1100,9 @@ list_style_sheets_html (FILE * stream)
   /*
    * The short list, presented as a table
    */
-  fputs (expand_user_string (job, CURRENT_FILE (job), "sheets.html generation",
+  fputs ((char *) expand_user_string (job,
+				      CURRENT_FILE (job),
+				      "sheets.html generation",
 "\
 #{html.hline:-<hline>}\n\
 <h2>Sumary of current style sheets</h2>\n\
@@ -1110,7 +1137,9 @@ them all.  Its index (sum of the style sheets version number) is \
   /*
    * The real detail list
    */
-  fputs (expand_user_string (job, CURRENT_FILE (job), "sheets.html generation",
+  fputs ((char *) expand_user_string (job,
+				      CURRENT_FILE (job),
+				      "sheets.html generation",
 "\
 #{html.hline:-<hline>}\n\
 <h2>Detailed list of current style sheets</h2>\n"), stream);
@@ -1124,7 +1153,9 @@ them all.  Its index (sum of the style sheets version number) is \
     }
   fputs ("</ul>\n", stream);
 
-  fputs (expand_user_string (job, CURRENT_FILE (job), "sheets.html generation",
+  fputs ((char *) expand_user_string (job,
+				      CURRENT_FILE (job),
+				      "sheets.html generation",
 "\
 #{html.end.hook}\n\
 </body>\n\
@@ -1152,13 +1183,13 @@ style_sheet_texinfo_print_signature (FILE * stream,
    * verbose mode for sheets */
   if (!IS_EMPTY(sheet->author)
       || (msg_test (msg_sheet)
-	  && (!version_is_null (sheet->requirement)
+	  && (!version_null_p (sheet->requirement)
 	      || (sheet->ancestors->len > 0))))
     {
       authors_print_texinfo (sheet->author, stream, "Written by ");
       if (msg_test (msg_sheet))
 	{
-	  if (!version_is_null (sheet->requirement))
+	  if (!version_null_p (sheet->requirement))
 	    {
 	      fputs ("It requires @code{a2ps} version ", stream);
 	      version_self_print (sheet->requirement, stream);
@@ -1191,7 +1222,7 @@ list_style_sheets_texinfo (FILE * stream)
   struct style_sheet * sheet;
   struct darray * entries;
   size_t i;
-  int version_index[4], requirement[4];
+  version_t version_index, requirement;
 
   entries = pw_glob_on_suffix (job->common.path, SSH_SUFFIX);
 
@@ -1227,20 +1258,20 @@ The current index (sum of all the style sheets version number) is ", stream);
 /************************************************************************/
 /*
  * Check that a darray of rules is in lower case
- * (TRUE for success)
+ * (true for success)
  */
-static boolean
+static bool
 check_rules_lower_case (const char * name, struct darray * rules)
 {
   size_t i;
-  boolean res = true;
+  bool res = true;
 
   for (i = 0 ; i < rules->len ; i++)
     if (!is_strlower (((struct rule *) rules->content[i])->word)) {
       error (0, 0,
 	     "%s.ssh:`%s' uses upper case characters",
 	     name, ((struct rule *) rules->content[i])->word);
-      res = FALSE;
+      res = false;
     }
   return res;
 }
@@ -1248,7 +1279,7 @@ check_rules_lower_case (const char * name, struct darray * rules)
 /*
  * Check that WORDS is all in lower case
  */
-static boolean
+static bool
 check_words_lower_case (const char * name, struct words * words)
 {
   return (check_rules_lower_case (name, words->strings)
@@ -1258,16 +1289,16 @@ check_words_lower_case (const char * name, struct words * words)
 /*
  * Check that SEQUENCE is all in lower case
  */
-static boolean
+static bool
 check_sequence_lower_case (const char * name, struct sequence * sequence)
 {
-  boolean res = true;
+  bool res = true;
 
   if (!is_strlower (sequence->open->word)) {
     error (0, 0,
 	   "%s.ssh:`%s' uses upper case characters",
 	   name, sequence->open->word);
-    res = FALSE;
+    res = false;
   }
 
   res &= check_words_lower_case (name, sequence->exceptions);
@@ -1276,11 +1307,11 @@ check_sequence_lower_case (const char * name, struct sequence * sequence)
   return res;
 }
 
-static boolean
+static bool
 check_sequences_lower_case (const char * name, struct darray * sequences)
 {
   size_t i;
-  boolean res = true;
+  bool res = true;
 
   for (i = 0 ; i < sequences->len ; i++)
     res &= check_sequence_lower_case (name,
@@ -1293,19 +1324,19 @@ check_sequences_lower_case (const char * name, struct darray * sequences)
  * Check that keywords are in lower case when lang is
  * case insensitive (returns 0 for failure)
  */
-static boolean
+static bool
 check_sensitivity (struct style_sheet * sheet)
 {
-  boolean res = true;
+  bool res = true;
 
   if (sheet->sensitiveness == case_sensitive)
-    return TRUE;
+    return true;
 
   /* The language is case insensitive: there should be only
    * lower case rules.
    * I know \B is legal in the regex.  But I prefer still
    * making the test: those who know how to use \B will have
-   * no problems to understand that the test is wrong, not them */
+   * no problems to understand that the test is wrong, not them. */
   res &= check_words_lower_case (sheet->key, sheet->keywords);
   res &= check_words_lower_case (sheet->key, sheet->operators);
   res &= check_sequences_lower_case (sheet->key, sheet->sequences);
@@ -1314,11 +1345,11 @@ check_sensitivity (struct style_sheet * sheet)
 }
 
 
-static boolean
+static bool
 check_rules_doubles (const char * name, struct darray * rules)
 {
   size_t i;
-  boolean res = true;
+  bool res = true;
 
   for (i = 1 ; i < rules->len ; i++)
     if (!ustrcmp (((struct rule *) rules->content [i - 1])->word,
@@ -1332,7 +1363,7 @@ check_rules_doubles (const char * name, struct darray * rules)
 }
 
 
-static boolean
+static bool
 check_words_doubles (const char * name, struct words * words)
 {
   return (check_rules_doubles (name, words->strings)
@@ -1342,10 +1373,10 @@ check_words_doubles (const char * name, struct words * words)
 /*
  * Check that there are no doublons in the style sheets
  */
-static boolean
+static bool
 check_doubles (struct style_sheet * sheet)
 {
-  boolean res = true;
+  bool res = true;
 
   res &= check_words_doubles (sheet->key, sheet->keywords);
   res &= check_words_doubles (sheet->key, sheet->operators);
@@ -1357,7 +1388,7 @@ check_doubles (struct style_sheet * sheet)
  * Return a correctness result upon SHEET
  * (0: failure, 1: correct)
  */
-static boolean
+static bool
 style_sheet_check (struct style_sheet * sheet)
 {
   return check_doubles (sheet) && check_sensitivity (sheet);
@@ -1396,7 +1427,7 @@ struct hash_table_s *
 new_style_sheets (void)
 {
   struct hash_table_s * res;
-  res = ALLOC (hash_table, 1);
+  res = XMALLOC (hash_table, 1);
   hash_init (res, 8,
              sheet_hash_1, sheet_hash_2, sheet_hash_cmp);
   return res;
@@ -1495,5 +1526,4 @@ style_sheets_versions (struct darray * keys,
       if (version_cmp (sheet->requirement, requirement) > 0)
 	version_cpy (requirement, sheet->requirement);
     }
-
 }
