@@ -66,10 +66,15 @@ struct faced_string
   struct fface_s face;
 };
 
+
+/*--------------------------------------.
+| A rule is composed of its lhs and rhs |
+`--------------------------------------*/
+
 struct rule
 {
-  uchar * word;
-  struct re_pattern_buffer * regex;
+  uchar *word;
+  struct re_pattern_buffer *regex;
   struct darray * rhs;
 };
 
@@ -172,10 +177,12 @@ void rhs_self_print PARAMS ((struct darray * rhs, FILE * stream));
  */
 struct rule * rule_new PARAMS ((uchar * word,
 				struct pattern * pattern,
-				struct darray * destination));
+				struct darray * destination,
+				const char *filename, size_t line));
 struct rule * keyword_rule_new PARAMS ((uchar * word,
 					struct pattern * pattern,
-					struct darray * destination));
+					struct darray * destination,
+					const char *filename, size_t line));
 
 /*
  * Dealing with the sequences
