@@ -78,10 +78,10 @@ struct token
 static inline struct token *
 token_new (void)
 {
-  struct token *res = ALLOC (struct token, 1);
-  res->registers = ALLOC (struct re_registers, 1);
-  res->registers->start = ALLOC (regoff_t, 30);
-  res->registers->end = ALLOC (regoff_t, 30);
+  struct token *res = XMALLOC (struct token, 1);
+  res->registers = XMALLOC (struct re_registers, 1);
+  res->registers->start = XMALLOC (regoff_t, 30);
+  res->registers->end = XMALLOC (regoff_t, 30);
   return res;
 }
 
@@ -94,7 +94,7 @@ rhs_plain_new (void)
 static inline void
 token_free (struct token *token)
 {
-  FREE (token);
+  free (token);
 }
 
 /* Where the token and its attributes are stored */
@@ -142,7 +142,7 @@ match_word (buffer_t * buffer, struct style_sheet *sheet)
 #define word_regexp(_i_)	\
    (((struct rule *) words->regexps->content[_i_]))
 /*
- * Return TRUE if there is a element of WORDS which keywords-match
+ * Return true if there is a element of WORDS which keywords-match
  * current point of BUFFER.  Fill TOKEN with the matching part.
  */
 static inline int
@@ -195,7 +195,7 @@ match_keyword (buffer_t * buffer,
 }
 
 /*
- * Return TRUE if there is a element of WORDS which operators-match
+ * Return true if there is a element of WORDS which operators-match
  * current point of BUFFER.  Fill TOKEN with the matching part.
  */
 static inline int
@@ -303,7 +303,7 @@ match_sequence (buffer_t * buffer, struct style_sheet *sheet)
 static inline int
 ssh_get_token (buffer_t * buffer, struct style_sheet *sheet)
 {
-  static int return_to_plain = FALSE;
+  static int return_to_plain = false;
   /* NULL if not in a sequence currently */
   static struct sequence *sequence = NULL;
 
@@ -323,14 +323,14 @@ ssh_get_token (buffer_t * buffer, struct style_sheet *sheet)
 	  /* If this is a new file, it must not depend on the trailling
 	   * parameters of the previous file */
 	  sequence = NULL;
-	  return_to_plain = FALSE;
+	  return_to_plain = false;
 	  return 0;
 	}
     }
 
   if (return_to_plain)
     {
-      return_to_plain = FALSE;
+      return_to_plain = false;
       token->rhs = plain_rhs;
       token_dest (0)->face = Plain_fface;
     }
@@ -343,7 +343,7 @@ ssh_get_token (buffer_t * buffer, struct style_sheet *sheet)
       /* end of sequence ? */
       if (match_operator (buffer, sequence->close))
 	{
-	  return_to_plain = TRUE;
+	  return_to_plain = true;
 	  sequence = NULL;
 	  return 1;
 	}
@@ -366,7 +366,7 @@ ssh_get_token (buffer_t * buffer, struct style_sheet *sheet)
 	  if (match_keyword (buffer, sheet->keywords, sheet->alpha2)
 	      || match_operator (buffer, sheet->operators))
 	    {
-	      return_to_plain = TRUE;
+	      return_to_plain = true;
 	      return 1;
 	    }
 	  else
@@ -382,7 +382,7 @@ ssh_get_token (buffer_t * buffer, struct style_sheet *sheet)
 	}
       else if (match_operator (buffer, sheet->operators))
 	{
-	  return_to_plain = TRUE;
+	  return_to_plain = true;
 	  return 1;
 	}
     }
@@ -412,10 +412,10 @@ ssh_print_postscript (struct a2ps_job *Job,
   struct fface_s fface;
   /* To grab the encoding switching instruction */
   uchar bufenc[512];
-  int grabbing_encoding = FALSE;
+  int grabbing_encoding = false;
   size_t i;
 
-  *bufenc = NUL;
+  *bufenc = '\0';
   fface = Plain_fface;
 
   /* I must do this because of the broken handling of the registers in
@@ -435,13 +435,13 @@ ssh_print_postscript (struct a2ps_job *Job,
 	  {
 	    /* Reset dynamic markers */
 	    if (token_dest_fflags (i) & ff_Tag1)
-	      *Job->tag1 = NUL;
+	      *Job->tag1 = '\0';
 	    if (token_dest_fflags (i) & ff_Tag2)
-	      *Job->tag2 = NUL;
+	      *Job->tag2 = '\0';
 	    if (token_dest_fflags (i) & ff_Tag3)
-	      *Job->tag3 = NUL;
+	      *Job->tag3 = '\0';
 	    if (token_dest_fflags (i) & ff_Tag4)
-	      *Job->tag4 = NUL;
+	      *Job->tag4 = '\0';
 	    if (grabbing_encoding
 		&& (!(token_dest_fflags (i) & ff_Encoding)))
 	      {
@@ -451,11 +451,11 @@ ssh_print_postscript (struct a2ps_job *Job,
 /*          encoding_build_faces_wx (job, newenc); */
 		if (!newenc)
 		  error (0, 0, _ ("unknown encoding `%s', ignored"),
-			 quotearg (bufenc));
+			 quotearg ((char *) bufenc));
 		else
 		  ps_switch_encoding (Job, newenc);
-		*bufenc = NUL;
-		grabbing_encoding = FALSE;
+		*bufenc = '\0';
+		grabbing_encoding = false;
 	      }
 	    fface = token_dest (i)->face;
 	  }
@@ -474,7 +474,7 @@ ssh_print_postscript (struct a2ps_job *Job,
 	    /* Grab the dynamic encodings */
 	    if (fface_get_flags (fface) & ff_Encoding)
 	      {
-		grabbing_encoding = TRUE;
+		grabbing_encoding = true;
 		ustrcat (bufenc, token_dest (i)->string);
 	      }
 	  }
@@ -491,7 +491,7 @@ ssh_print_postscript (struct a2ps_job *Job,
 	    /* Grab the dynamic encodings */
 	    if (fface_get_flags (fface) & ff_Encoding)
 	      {
-		grabbing_encoding = TRUE;
+		grabbing_encoding = true;
 		GRAB_TAG (bufenc);
 	      }
 	  }
