@@ -1,10 +1,8 @@
 /*
- * ssheet.c
- *
- * definition of the languages style sheets
+ * versions.c -- Handling standard version numbers
  * Copyright (c) 1988, 89, 90, 91, 92, 93 Miguel Santana
- * Copyright (c) 1995, 96, 97, 98, 99 Akim Demaille, Miguel Santana
- * $Id: versions.c,v 1.4 1998/03/03 15:52:23 demaille Exp $
+ * Copyright (c) 1995, 96, 97, 98 Akim Demaille, Miguel Santana
+ *
  */
 
 /*
@@ -34,35 +32,31 @@
 /*	The version handling						*/
 /************************************************************************/
 void
-version_set_to_null (int version [4])
+version_set_to_null (version_t version)
 {
-  int n;
+  size_t n;
 
-  for (n = 0 ; n < 4 ; n++)
+  for (n = 0 ; n < VERSION_LENGTH ; n++)
     version[n] = 0;
 }
 
-static inline int
-_version_is_null (int version [4])
+bool
+version_null_p (version_t version)
 {
-  return ((version [0] == 0)
-	  && (version [1] == 0)
-	  && (version [2] == 0)
-	  && (version [3] == 0));
+  size_t n;
+
+  for (n = 0 ; n < VERSION_LENGTH ; n++)
+    if (version[n])
+      return false;
+  return true;
 }
 
 int
-version_is_null (int version [4])
-{
-  return _version_is_null (version);
-}
-
-int
-version_cmp (int v1[4], int v2[4])
+version_cmp (version_t v1, version_t v2)
 {
   int n;
 
-  for (n = 0 ; n < 4 ; n++)
+  for (n = 0 ; n < VERSION_LENGTH ; n++)
     if (v1[n] < v2[n])
       return -1;
     else if (v1[n] > v2[n])
@@ -72,81 +66,67 @@ version_cmp (int v1[4], int v2[4])
 }
 
 void
-version_cpy (int d[4], int s[4])
+version_cpy (version_t d, version_t s)
 {
-  memcpy (d, s, 4 * sizeof(s[0]));
+  memcpy (d, s, VERSION_LENGTH * sizeof(s[0]));
 }
 
 void
-version_self_print (int version [4], FILE * stream)
+version_self_print (version_t version, FILE * stream)
 {
-  if (version [3])
-    fprintf (stream, "%d.%d.%d%c",
-	     version [0], version [1], version [2], version [3] + 'a');
-  else if (version [2])
-    fprintf (stream, "%d.%d.%d",
-	     version [0], version [1], version [2]);
+  if (version[2])
+    fprintf (stream, "%d.%d%c",
+	     version[0], version[1], version[2]);
   else
     fprintf (stream, "%d.%d",
-	     version [0], version [1]);
+	     version[0], version[1]);
 }
 
 /*
  * Return the length occupied by this version number once printed
  */
 int
-version_length (int version [4])
+version_length (version_t version)
 {
 #define short_int_len(_i_) ((_i_) < 10 ? 1 : 2)
-  if (version [3])
+  if (version[2])
     return 2
-      + short_int_len(version [0])
-      + short_int_len(version [1])
-      + short_int_len(version [2])
+      + short_int_len(version[0])
+      + short_int_len(version[1])
       + 1;
-  else if (version [2])
-    return 2
-      + short_int_len(version [0])
-      + short_int_len(version [1])
-      + short_int_len(version [2]);
   else
     return 1
-      + short_int_len(version [0])
-      + short_int_len(version [1]);
+      + short_int_len(version[0])
+      + short_int_len(version[1]);
 }
 
 void
-version_add (int v1[4], int v2[4])
+version_add (version_t v1, version_t v2)
 {
   int n;
 
-  for (n = 0 ; n < 4 ; n++)
-    v1 [n] += v2 [n];
+  for (n = 0 ; n < VERSION_LENGTH ; n++)
+    v1[n] += v2[n];
 }
 
 /*
  * Valid versions numbers are:
  * digit.digit
- * digit.digit.digit
- * digit.digit.digitchar
+ * digit.digitchar
  */
 void
-string_to_version (const char * version_string, int version [4])
+string_to_version (const char * version_string, version_t version)
 {
   char d;
 
-  switch (sscanf (version_string, "%d.%d.%d%c",
-		  &(version[0]), &(version[1]), &(version[2]), &d))
+  switch (sscanf (version_string, "%d.%d%c",
+		  &(version[0]), &(version[1]), &d))
     {
     case 2:
       version[2] = 0;
-      /* FALLTHRU */
-    case 3:
-      version[3] = 0;
-      /* Nothing */
       break;
-    case 4:
-      version[3] = d - 'a' + 1;
+    case VERSION_LENGTH:
+      version[2] = d - 'a' + 1;
       break;
     default:
       error (1, 0,
